@@ -63,7 +63,7 @@ class IPInsights(AmazonAlgorithmEstimatorBase):
 
     def __init__(
         self,
-        role: str,
+        role: Optional[Union[str, PipelineVariable]] = None,
         instance_count: Optional[Union[int, PipelineVariable]] = None,
         instance_type: Optional[Union[str, PipelineVariable]] = None,
         num_entity_vectors: Optional[int] = None,
@@ -75,7 +75,7 @@ class IPInsights(AmazonAlgorithmEstimatorBase):
         random_negative_sampling_rate: Optional[int] = None,
         shuffled_negative_sampling_rate: Optional[int] = None,
         weight_decay: Optional[float] = None,
-        **kwargs
+        **kwargs,
     ):
         """This estimator is for IP Insights.
 
@@ -168,7 +168,7 @@ class IPInsights(AmazonAlgorithmEstimatorBase):
             self.role,
             sagemaker_session=self.sagemaker_session,
             vpc_config=self.get_vpc_config(vpc_config_override),
-            **kwargs
+            **kwargs,
         )
 
     def _prepare_for_training(self, records, mini_batch_size=None, job_name=None):
@@ -196,6 +196,7 @@ class IPInsightsPredictor(Predictor):
         sagemaker_session=None,
         serializer=CSVSerializer(),
         deserializer=JSONDeserializer(),
+        component_name=None,
     ):
         """Creates object to be used to get dot product of entity nad IP address.
 
@@ -208,14 +209,17 @@ class IPInsightsPredictor(Predictor):
                 chain.
             serializer (sagemaker.serializers.BaseSerializer): Optional. Default
                 serializes input data to text/csv.
-            deserializer (callable): Optional. Default parses JSON responses
+            deserializer (Callable): Optional. Default parses JSON responses
                 using ``json.load(...)``.
+            component_name (str): Optional. Name of the Amazon SageMaker inference
+                component corresponding the predictor.
         """
         super(IPInsightsPredictor, self).__init__(
             endpoint_name,
             sagemaker_session,
             serializer=serializer,
             deserializer=deserializer,
+            component_name=component_name,
         )
 
 
@@ -229,9 +233,9 @@ class IPInsightsModel(Model):
     def __init__(
         self,
         model_data: Union[str, PipelineVariable],
-        role: str,
+        role: Optional[str] = None,
         sagemaker_session: Optional[Session] = None,
-        **kwargs
+        **kwargs,
     ):
         """Creates object to get insights on S3 model data.
 
@@ -264,5 +268,5 @@ class IPInsightsModel(Model):
             role,
             predictor_cls=IPInsightsPredictor,
             sagemaker_session=sagemaker_session,
-            **kwargs
+            **kwargs,
         )
