@@ -17,11 +17,18 @@ import logging
 from typing import Optional, List, Dict
 from six import string_types
 
-from sagemaker import Model, PipelineModel
+from sagemaker import Model, PipelineModel, s3
 from sagemaker.automl.candidate_estimator import CandidateEstimator
+from sagemaker.config import (
+    AUTO_ML_ROLE_ARN_PATH,
+    AUTO_ML_KMS_KEY_ID_PATH,
+    AUTO_ML_VPC_CONFIG_PATH,
+    AUTO_ML_VOLUME_KMS_KEY_ID_PATH,
+    AUTO_ML_INTER_CONTAINER_ENCRYPTION_PATH,
+)
 from sagemaker.job import _Job
 from sagemaker.session import Session
-from sagemaker.utils import name_from_base
+from sagemaker.utils import name_from_base, resolve_value_from_config, format_tags, Tags
 from sagemaker.workflow.entities import PipelineVariable
 from sagemaker.workflow.pipeline_context import runnable_by_pipeline
 
@@ -42,6 +49,7 @@ class AutoMLInput(object):
         channel_type=None,
         content_type=None,
         s3_data_type=None,
+        sample_weight_attribute_name=None,
     ):
         """Convert an S3 Uri or a list of S3 Uri to an AutoMLInput object.
 
@@ -60,6 +68,8 @@ class AutoMLInput(object):
                 The content type of the data from the input source.
             s3_data_type (str, PipelineVariable): The data type for S3 data source.
                 Valid values: ManifestFile or S3Prefix.
+            sample_weight_attribute_name (str, PipelineVariable):
+                the name of the dataset column representing sample weights
         """
         self.inputs = inputs
         self.target_attribute_name = target_attribute_name
@@ -67,6 +77,7 @@ class AutoMLInput(object):
         self.channel_type = channel_type
         self.content_type = content_type
         self.s3_data_type = s3_data_type
+        self.sample_weight_attribute_name = sample_weight_attribute_name
 
     def to_request_dict(self):
         """Generates a request dictionary using the parameters provided to the class."""
@@ -89,6 +100,8 @@ class AutoMLInput(object):
                 input_entry["ContentType"] = self.content_type
             if self.s3_data_type is not None:
                 input_entry["DataSource"]["S3DataSource"]["S3DataType"] = self.s3_data_type
+            if self.sample_weight_attribute_name is not None:
+                input_entry["SampleWeightAttributeName"] = self.sample_weight_attribute_name
             auto_ml_input.append(input_entry)
         return auto_ml_input
 
@@ -98,15 +111,15 @@ class AutoML(object):
 
     def __init__(
         self,
-        role: str,
-        target_attribute_name: str,
+        role: Optional[str] = None,
+        target_attribute_name: str = None,
         output_kms_key: Optional[str] = None,
         output_path: Optional[str] = None,
         base_job_name: Optional[str] = None,
         compression_type: Optional[str] = None,
         sagemaker_session: Optional[Session] = None,
         volume_kms_key: Optional[str] = None,
-        encrypt_inter_container_traffic: Optional[bool] = False,
+        encrypt_inter_container_traffic: Optional[bool] = None,
         vpc_config: Optional[Dict[str, List]] = None,
         problem_type: Optional[str] = None,
         max_candidates: Optional[int] = None,
@@ -114,7 +127,7 @@ class AutoML(object):
         total_job_runtime_in_seconds: Optional[int] = None,
         job_objective: Optional[Dict[str, str]] = None,
         generate_candidate_definitions_only: Optional[bool] = False,
-        tags: Optional[List[Dict[str, str]]] = None,
+        tags: Optional[Tags] = None,
         content_type: Optional[str] = None,
         s3_data_type: Optional[str] = None,
         feature_specification_s3_uri: Optional[str] = None,
@@ -122,6 +135,7 @@ class AutoML(object):
         mode: Optional[str] = None,
         auto_generate_endpoint_name: Optional[bool] = None,
         endpoint_name: Optional[str] = None,
+        sample_weight_attribute_name: str = None,
     ):
         """Initialize the an AutoML object.
 
@@ -153,8 +167,7 @@ class AutoML(object):
                 In the format of: {"MetricName": str}
             generate_candidate_definitions_only (bool): Whether to generates
                 possible candidates without training the models.
-            tags (List[dict[str, str]]): The list of tags to attach to this
-                specific endpoint.
+            tags (Optional[Tags]): Tags to attach to this specific endpoint.
             content_type (str): The content type of the data from the input source.
             s3_data_type (str): The data type for S3 data source.
                 Valid values: ManifestFile or S3Prefix.
@@ -172,18 +185,16 @@ class AutoML(object):
                 model deployment if the endpoint name is not generated automatically.
                 Specify the endpoint_name if and only if
                 auto_generate_endpoint_name is set to False
+            sample_weight_attribute_name (str): The name of dataset column representing
+                sample weights.
 
         Returns:
             AutoML object.
         """
-        self.role = role
-        self.output_kms_key = output_kms_key
         self.output_path = output_path
         self.base_job_name = base_job_name
         self.compression_type = compression_type
-        self.volume_kms_key = volume_kms_key
         self.encrypt_inter_container_traffic = encrypt_inter_container_traffic
-        self.vpc_config = vpc_config
         self.problem_type = problem_type
         self.max_candidate = max_candidates
         self.max_runtime_per_training_job_in_seconds = max_runtime_per_training_job_in_seconds
@@ -191,7 +202,7 @@ class AutoML(object):
         self.target_attribute_name = target_attribute_name
         self.job_objective = job_objective
         self.generate_candidate_definitions_only = generate_candidate_definitions_only
-        self.tags = tags
+        self.tags = format_tags(tags)
         self.content_type = content_type
         self.s3_data_type = s3_data_type
         self.feature_specification_s3_uri = feature_specification_s3_uri
@@ -204,8 +215,34 @@ class AutoML(object):
         self._auto_ml_job_desc = None
         self._best_candidate = None
         self.sagemaker_session = sagemaker_session or Session()
+        self.vpc_config = resolve_value_from_config(
+            vpc_config, AUTO_ML_VPC_CONFIG_PATH, sagemaker_session=self.sagemaker_session
+        )
+        self.volume_kms_key = resolve_value_from_config(
+            volume_kms_key, AUTO_ML_VOLUME_KMS_KEY_ID_PATH, sagemaker_session=self.sagemaker_session
+        )
+        self.output_kms_key = resolve_value_from_config(
+            output_kms_key, AUTO_ML_KMS_KEY_ID_PATH, sagemaker_session=self.sagemaker_session
+        )
+        self.role = resolve_value_from_config(
+            role, AUTO_ML_ROLE_ARN_PATH, sagemaker_session=self.sagemaker_session
+        )
+        if not self.role:
+            # Originally IAM role was a required parameter.
+            # Now we marked that as Optional because we can fetch it from SageMakerConfig
+            # Because of marking that parameter as optional, we should validate if it is None, even
+            # after fetching the config.
+            raise ValueError("An AWS IAM role is required to create an AutoML job.")
+
+        self.encrypt_inter_container_traffic = resolve_value_from_config(
+            direct_input=encrypt_inter_container_traffic,
+            config_path=AUTO_ML_INTER_CONTAINER_ENCRYPTION_PATH,
+            default_value=False,
+            sagemaker_session=self.sagemaker_session,
+        )
 
         self._check_problem_type_and_job_objective(self.problem_type, self.job_objective)
+        self.sample_weight_attribute_name = sample_weight_attribute_name
 
     @runnable_by_pipeline
     def fit(self, inputs=None, wait=True, logs=True, job_name=None):
@@ -276,6 +313,8 @@ class AutoML(object):
             volume_kms_key=auto_ml_job_desc.get("AutoMLJobConfig", {})
             .get("SecurityConfig", {})
             .get("VolumeKmsKeyId"),
+            # Do not override encrypt_inter_container_traffic from config because this info
+            # is pulled from an existing automl job
             encrypt_inter_container_traffic=auto_ml_job_desc.get("AutoMLJobConfig", {})
             .get("SecurityConfig", {})
             .get("EnableInterContainerTrafficEncryption", False),
@@ -292,7 +331,7 @@ class AutoML(object):
             total_job_runtime_in_seconds=auto_ml_job_desc.get("AutoMLJobConfig", {})
             .get("CompletionCriteria", {})
             .get("MaxAutoMLJobRuntimeInSeconds"),
-            job_objective=auto_ml_job_desc.get("AutoMLJobObjective", {}).get("MetricName"),
+            job_objective=auto_ml_job_desc.get("AutoMLJobObjective", {}),
             generate_candidate_definitions_only=auto_ml_job_desc.get(
                 "GenerateCandidateDefinitionsOnly", False
             ),
@@ -312,6 +351,9 @@ class AutoML(object):
                 "AutoGenerateEndpointName", False
             ),
             endpoint_name=auto_ml_job_desc.get("ModelDeployConfig", {}).get("EndpointName"),
+            sample_weight_attribute_name=auto_ml_job_desc["InputDataConfig"][0].get(
+                "SampleWeightAttributeName", None
+            ),
         )
         amlj.current_job_name = auto_ml_job_name
         amlj.latest_auto_ml_job = auto_ml_job_name  # pylint: disable=W0201
@@ -436,7 +478,7 @@ class AutoML(object):
                 training cluster for distributed training. Default: False
             model_kms_key (str): KMS key ARN used to encrypt the repacked
                 model archive file if the model is repacked
-            predictor_cls (callable[string, sagemaker.session.Session]): A
+            Callable[[string, sagemaker.session.Session], Any]: A
                 function to call to create a predictor (default: None). If
                 specified, ``deploy()``  returns the result of invoking this
                 function on the created endpoint name.
@@ -538,7 +580,7 @@ class AutoML(object):
                 be selected on each ``deploy``.
             endpoint_name (str): The name of the endpoint to create (default:
                 None). If not specified, a unique endpoint name will be created.
-            tags (List[dict[str, str]]): The list of tags to attach to this
+            tags (Optional[Tags]): The list of tags to attach to this
                 specific endpoint.
             wait (bool): Whether the call should wait until the deployment of
                 model completes (default: True).
@@ -549,7 +591,7 @@ class AutoML(object):
                 training cluster for distributed training. Default: False
             model_kms_key (str): KMS key ARN used to encrypt the repacked
                 model archive file if the model is repacked
-            predictor_cls (callable[string, sagemaker.session.Session]): A
+            predictor_cls (Callable[[string, sagemaker.session.Session], Any]): A
                 function to call to create a predictor (default: None). If
                 specified, ``deploy()``  returns the result of invoking this
                 function on the created endpoint name.
@@ -567,7 +609,7 @@ class AutoML(object):
                 https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-inference-code.html#your-algorithms-inference-algo-ping-requests
 
         Returns:
-            callable[string, sagemaker.session.Session] or ``None``:
+            Optional[Callable[[string, sagemaker.session.Session], Any]]:
                 If ``predictor_cls`` is specified, the invocation of ``self.predictor_cls`` on
                 the created endpoint name. Otherwise, ``None``.
         """
@@ -590,7 +632,7 @@ class AutoML(object):
             deserializer=deserializer,
             endpoint_name=endpoint_name,
             kms_key=model_kms_key,
-            tags=tags,
+            tags=format_tags(tags),
             wait=wait,
             volume_size=volume_size,
             model_data_download_timeout=model_data_download_timeout,
@@ -633,7 +675,12 @@ class AutoML(object):
             self.current_job_name = name_from_base(base_name, max_length=32)
 
         if self.output_path is None:
-            self.output_path = "s3://{}/".format(self.sagemaker_session.default_bucket())
+            self.output_path = s3.s3_path_join(
+                "s3://",
+                self.sagemaker_session.default_bucket(),
+                self.sagemaker_session.default_bucket_prefix,
+                with_end_slash=True,
+            )
 
     @classmethod
     def _get_supported_inference_keys(cls, container, default=None):
@@ -837,6 +884,7 @@ class AutoMLJob(_Job):
                 auto_ml.target_attribute_name,
                 auto_ml.content_type,
                 auto_ml.s3_data_type,
+                auto_ml.sample_weight_attribute_name,
             )
         output_config = _Job._prepare_output_config(auto_ml.output_path, auto_ml.output_kms_key)
 
@@ -882,9 +930,9 @@ class AutoMLJob(_Job):
 
         auto_ml_model_deploy_config = {}
         if auto_ml.auto_generate_endpoint_name is not None:
-            auto_ml_model_deploy_config[
-                "AutoGenerateEndpointName"
-            ] = auto_ml.auto_generate_endpoint_name
+            auto_ml_model_deploy_config["AutoGenerateEndpointName"] = (
+                auto_ml.auto_generate_endpoint_name
+            )
         if not auto_ml.auto_generate_endpoint_name and auto_ml.endpoint_name is not None:
             auto_ml_model_deploy_config["EndpointName"] = auto_ml.endpoint_name
 
@@ -902,6 +950,7 @@ class AutoMLJob(_Job):
         target_attribute_name=None,
         content_type=None,
         s3_data_type=None,
+        sample_weight_attribute_name=None,
     ):
         """Convert inputs to AutoML InputDataConfig.
 
@@ -931,6 +980,8 @@ class AutoMLJob(_Job):
                 channel["ContentType"] = content_type
             if s3_data_type is not None:
                 channel["DataSource"]["S3DataSource"]["S3DataType"] = s3_data_type
+            if sample_weight_attribute_name is not None:
+                channel["SampleWeightAttributeName"] = sample_weight_attribute_name
             channels.append(channel)
         elif isinstance(inputs, list):
             for input_entry in inputs:
@@ -944,6 +995,8 @@ class AutoMLJob(_Job):
                     channel["ContentType"] = content_type
                 if s3_data_type is not None:
                     channel["DataSource"]["S3DataSource"]["S3DataType"] = s3_data_type
+                if sample_weight_attribute_name is not None:
+                    channel["SampleWeightAttributeName"] = sample_weight_attribute_name
                 channels.append(channel)
         else:
             msg = (
@@ -981,9 +1034,9 @@ class AutoMLJob(_Job):
         if max_candidates is not None:
             stopping_condition["MaxCandidates"] = max_candidates
         if max_runtime_per_training_job_in_seconds is not None:
-            stopping_condition[
-                "MaxRuntimePerTrainingJobInSeconds"
-            ] = max_runtime_per_training_job_in_seconds
+            stopping_condition["MaxRuntimePerTrainingJobInSeconds"] = (
+                max_runtime_per_training_job_in_seconds
+            )
         if total_job_runtime_in_seconds is not None:
             stopping_condition["MaxAutoMLJobRuntimeInSeconds"] = total_job_runtime_in_seconds
 
