@@ -77,3 +77,32 @@ class AutoMLStepInvalidModeError(Exception):
         msg = self.fmt.format(**kwargs)
         Exception.__init__(self, msg)
         self.kwargs = kwargs
+
+
+class AsyncInferenceModelError(AsyncInferenceError):
+    """Raised when model returns errors for failed requests"""
+
+    fmt = "Model returned error: {message} "
+
+    def __init__(self, message):
+        super().__init__(message=message)
+
+
+class ModelStreamError(Exception):
+    """Raised when invoke_endpoint_with_response_stream Response returns ModelStreamError"""
+
+    def __init__(self, message="An error occurred", code=None):
+        self.message = message
+        self.code = code
+        if code is not None:
+            super().__init__(f"{message} (Code: {code})")
+        else:
+            super().__init__(message)
+
+
+class InternalStreamFailure(Exception):
+    """Raised when invoke_endpoint_with_response_stream Response returns InternalStreamFailure"""
+
+    def __init__(self, message="An error occurred"):
+        self.message = message
+        super().__init__(self.message)
