@@ -197,8 +197,8 @@ class _SyncMetricsSink(object):
             response = self._metrics_client.batch_put_metrics(**request)
             errors = response["Errors"] if "Errors" in response else None
             if errors:
-                message = errors[0]["Message"]
-                raise Exception(f'{len(errors)} errors with message "{message}"')
+                error_code = errors[0]["Code"]
+                raise Exception(f'{len(errors)} errors with error code "{error_code}"')
 
     def _construct_batch_put_metrics_request(self, batch):
         """Creates dictionary object used as request to metrics service."""
