@@ -20,13 +20,16 @@ from botocore.exceptions import ClientError
 from sagemaker.apiutils import _base_types
 from sagemaker.experiments.trial import _Trial
 from sagemaker.experiments.trial_component import _TrialComponent
+from sagemaker.utils import format_tags
+from sagemaker.telemetry.telemetry_logging import _telemetry_emitter
+from sagemaker.telemetry.constants import Feature
 
 
-class _Experiment(_base_types.Record):
+class Experiment(_base_types.Record):
     """An Amazon SageMaker experiment, which is a collection of related trials.
 
-    New experiments are created by calling `experiments.experiment._Experiment.create`.
-    Existing experiments can be reloaded by calling `experiments.experiment._Experiment.load`.
+    New experiments are created by calling `experiments.experiment.Experiment.create`.
+    Existing experiments can be reloaded by calling `experiments.experiment.Experiment.load`.
 
     Attributes:
         experiment_name (str): The name of the experiment. The name must be unique
@@ -73,7 +76,7 @@ class _Experiment(_base_types.Record):
 
     @classmethod
     def load(cls, experiment_name, sagemaker_session=None):
-        """Load an existing experiment and return an `_Experiment` object representing it.
+        """Load an existing experiment and return an `Experiment` object representing it.
 
         Args:
             experiment_name: (str): Name of the experiment
@@ -83,7 +86,7 @@ class _Experiment(_base_types.Record):
                 default AWS configuration chain.
 
         Returns:
-            experiments.experiment._Experiment: A SageMaker `_Experiment` object
+            experiments.experiment.Experiment: A SageMaker `Experiment` object
         """
         return cls._construct(
             cls._boto_load_method,
@@ -92,6 +95,7 @@ class _Experiment(_base_types.Record):
         )
 
     @classmethod
+    @_telemetry_emitter(feature=Feature.MLOPS, func_name="experiment.create")
     def create(
         cls,
         experiment_name,
@@ -100,7 +104,7 @@ class _Experiment(_base_types.Record):
         tags=None,
         sagemaker_session=None,
     ):
-        """Create a new experiment in SageMaker and return an `_Experiment` object.
+        """Create a new experiment in SageMaker and return an `Experiment` object.
 
         Args:
             experiment_name: (str): Name of the experiment. Must be unique. Required.
@@ -111,18 +115,18 @@ class _Experiment(_base_types.Record):
                 manages interactions with Amazon SageMaker APIs and any other
                 AWS services needed. If not specified, one is created using the
                 default AWS configuration chain.
-            tags (List[Dict[str, str]]): A list of tags to associate with the experiment
+            tags (Optional[Tags]): A list of tags to associate with the experiment
                 (default: None).
 
         Returns:
-            experiments.experiment._Experiment: A SageMaker `_Experiment` object
+            experiments.experiment.Experiment: A SageMaker `Experiment` object
         """
         return cls._construct(
             cls._boto_create_method,
             experiment_name=experiment_name,
             display_name=display_name,
             description=description,
-            tags=tags,
+            tags=format_tags(tags),
             sagemaker_session=sagemaker_session,
         )
 
@@ -149,19 +153,19 @@ class _Experiment(_base_types.Record):
                 manages interactions with Amazon SageMaker APIs and any other
                 AWS services needed. If not specified, one is created using the
                 default AWS configuration chain.
-            tags (List[Dict[str, str]]): A list of tags to associate with the experiment
+            tags (Optional[Tags]): A list of tags to associate with the experiment
                 (default: None). This is used only when the given `experiment_name` does not
                 exist and a new experiment has to be created.
 
         Returns:
-            experiments.experiment._Experiment: A SageMaker `_Experiment` object
+            experiments.experiment.Experiment: A SageMaker `Experiment` object
         """
         try:
-            experiment = _Experiment.create(
+            experiment = Experiment.create(
                 experiment_name=experiment_name,
                 display_name=display_name,
                 description=description,
-                tags=tags,
+                tags=format_tags(tags),
                 sagemaker_session=sagemaker_session,
             )
         except ClientError as ce:
@@ -170,7 +174,7 @@ class _Experiment(_base_types.Record):
             if not (error_code == "ValidationException" and "already exists" in error_message):
                 raise ce
             # already exists
-            experiment = _Experiment.load(experiment_name, sagemaker_session)
+            experiment = Experiment.load(experiment_name, sagemaker_session)
         return experiment
 
     def list_trials(self, created_before=None, created_after=None, sort_by=None, sort_order=None):
