@@ -84,6 +84,51 @@ class OnlineStoreSecurityConfig(Config):
         return Config.construct_dict(KmsKeyId=self.kms_key_id)
 
 
+@attr.s
+class TtlDuration(Config):
+    """TtlDuration for records in online FeatureStore.
+
+    Attributes:
+        unit (str): time unit.
+        value (int): time value.
+    """
+
+    unit: str = attr.ib()
+    value: int = attr.ib()
+
+    def to_dict(self) -> Dict[str, Any]:
+        """Construct a dictionary based on the attributes.
+
+        Returns:
+            dict represents the attributes.
+        """
+        return Config.construct_dict(
+            Unit=self.unit,
+            Value=self.value,
+        )
+
+
+@attr.s
+class TargetStoreEnum(Enum):
+    """Enum of store types for put record.
+
+    The store types can be Standard or InMemory.
+    """
+
+    ONLINE_STORE = "OnlineStore"
+    OFFLINE_STORE = "OfflineStore"
+
+
+class OnlineStoreStorageTypeEnum(Enum):
+    """Enum of storage types for online store.
+
+    The online store storage types can be Standard or InMemory.
+    """
+
+    STANDARD = "Standard"
+    IN_MEMORY = "InMemory"
+
+
 @attr.s
 class OnlineStoreConfig(Config):
     """OnlineStoreConfig for FeatureStore.
@@ -91,10 +136,13 @@ class OnlineStoreConfig(Config):
     Attributes:
         enable_online_store (bool): whether to enable the online store.
         online_store_security_config (OnlineStoreSecurityConfig): configuration of security setting.
+        ttl_duration (TtlDuration): Default time to live duration for records.
     """
 
     enable_online_store: bool = attr.ib(default=True)
     online_store_security_config: OnlineStoreSecurityConfig = attr.ib(default=None)
+    ttl_duration: TtlDuration = attr.ib(default=None)
+    storage_type: OnlineStoreStorageTypeEnum = attr.ib(default=None)
 
     def to_dict(self) -> Dict[str, Any]:
         """Construct a dictionary based on the attributes.
@@ -105,6 +153,29 @@ class OnlineStoreConfig(Config):
         return Config.construct_dict(
             EnableOnlineStore=self.enable_online_store,
             SecurityConfig=self.online_store_security_config,
+            TtlDuration=self.ttl_duration,
+            StorageType=self.storage_type.value if self.storage_type else None,
+        )
+
+
+@attr.s
+class OnlineStoreConfigUpdate(Config):
+    """OnlineStoreConfigUpdate for FeatureStore.
+
+    Attributes:
+        ttl_duration (TtlDuration): Default time to live duration for records.
+    """
+
+    ttl_duration: TtlDuration = attr.ib(default=None)
+
+    def to_dict(self) -> Dict[str, Any]:
+        """Construct a dictionary based on the attributes.
+
+        Returns:
+            dict represents the attributes.
+        """
+        return Config.construct_dict(
+            TtlDuration=self.ttl_duration,
         )
 
 
@@ -206,10 +277,13 @@ class FeatureValue(Config):
     Attributes:
         feature_name (str): name of the Feature.
         value_as_string (str): value of the Feature in string form.
+        value_as_string_list (List[str]): value of the Feature in string list
+        form used for collection type.
     """
 
     feature_name: str = attr.ib(default=None)
     value_as_string: str = attr.ib(default=None)
+    value_as_string_list: List[str] = attr.ib(default=None)
 
     def to_dict(self) -> Dict[str, Any]:
         """Construct a dictionary based on the attributes provided.
@@ -220,6 +294,7 @@ class FeatureValue(Config):
         return Config.construct_dict(
             FeatureName=self.feature_name,
             ValueAsString=self.value_as_string,
+            ValueAsStringList=self.value_as_string_list,
         )
 
 
@@ -369,3 +444,99 @@ class Identifier(Config):
             RecordIdentifiersValueAsString=self.record_identifiers_value_as_string,
             FeatureNames=None if not self.feature_names else self.feature_names,
         )
+
+
+class DeletionModeEnum(Enum):
+    """Enum of deletion modes.
+
+    The deletion mode for deleting records can be SoftDelete or HardDelete.
+    """
+
+    SOFT_DELETE = "SoftDelete"
+    HARD_DELETE = "HardDelete"
+
+
+class ExpirationTimeResponseEnum(Enum):
+    """Enum of toggling the response of ExpiresAt.
+
+    The ExpirationTimeResponse for toggling the response of ExpiresAt can be Disabled or Enabled.
+    """
+
+    DISABLED = "Disabled"
+    ENABLED = "Enabled"
+
+
+class ThroughputModeEnum(Enum):
+    """Enum of throughput modes supported by feature group.
+
+    Throughput mode of feature group can be ON_DEMAND or PROVISIONED.
+    """
+
+    ON_DEMAND = "OnDemand"
+    PROVISIONED = "Provisioned"
+
+
+@attr.s
+class ThroughputConfig(Config):
+    """Throughput configuration of the feature group.
+
+    Throughput configuration can be ON_DEMAND, or PROVISIONED with valid values for
+    read and write capacity units. ON_DEMAND works best for less predictable traffic,
+    while PROVISIONED works best for consistent and predictable traffic.
+
+    Attributes:
+        mode (ThroughputModeEnum): Throughput mode
+        provisioned_read_capacity_units (int): For provisioned feature groups, this indicates
+            the read throughput you are billed for and can consume without throttling.
+        provisioned_write_capacity_units (int):  For provisioned feature groups, this indicates
+            the write throughput you are billed for and can consume without throttling.
+    """
+
+    mode: ThroughputModeEnum = attr.ib(default=None)
+    provisioned_read_capacity_units: int = attr.ib(default=None)
+    provisioned_write_capacity_units: int = attr.ib(default=None)
+
+    def to_dict(self) -> Dict[str, Any]:
+        """Construct a dictionary based on the attributes provided.
+
+        Returns:
+            dict represents the attributes.
+        """
+        return Config.construct_dict(
+            ThroughputMode=self.mode.value if self.mode else None,
+            ProvisionedReadCapacityUnits=self.provisioned_read_capacity_units,
+            ProvisionedWriteCapacityUnits=self.provisioned_write_capacity_units,
+        )
+
+
+@attr.s
+class ThroughputConfigUpdate(Config):
+    """Target throughput configuration for the feature group.
+
+    Target throughput configuration can be ON_DEMAND, or PROVISIONED with valid values for
+    read and write capacity units. ON_DEMAND works best for less predictable traffic,
+    while PROVISIONED works best for consistent and predictable traffic.
+
+    Attributes:
+        mode (ThroughputModeEnum): Target throughput mode
+        provisioned_read_capacity_units (int): For provisioned feature groups, this indicates
+            the read throughput you are billed for and can consume without throttling.
+        provisioned_write_capacity_units (int):  For provisioned feature groups, this indicates
+            the write throughput you are billed for and can consume without throttling.
+    """
+
+    mode: ThroughputModeEnum = attr.ib(default=None)
+    provisioned_read_capacity_units: int = attr.ib(default=None)
+    provisioned_write_capacity_units: int = attr.ib(default=None)
+
+    def to_dict(self) -> Dict[str, Any]:
+        """Construct a dictionary based on the attributes provided.
+
+        Returns:
+            dict represents the attributes.
+        """
+        return Config.construct_dict(
+            ThroughputMode=self.mode.value if self.mode else None,
+            ProvisionedReadCapacityUnits=self.provisioned_read_capacity_units,
+            ProvisionedWriteCapacityUnits=self.provisioned_write_capacity_units,
+        )
