@@ -10,33 +10,37 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""Utility methods used by framework classes"""
+"""Utility methods used by framework classes."""
 from __future__ import absolute_import
 
 import json
 import logging
 import os
 import re
-import time
 import shutil
 import tempfile
+import time
 from collections import namedtuple
-from typing import Optional, Union, Dict
+from typing import Dict, List, Optional, Union
+
+from packaging import version
 
 import sagemaker.image_uris
-from sagemaker.session_settings import SessionSettings
 import sagemaker.utils
+from sagemaker.deprecations import deprecation_warn_base, renamed_kwargs, renamed_warning
+from sagemaker.instance_group import InstanceGroup
+from sagemaker.s3_utils import s3_path_join
+from sagemaker.session_settings import SessionSettings
 from sagemaker.workflow import is_pipeline_variable
-
-from sagemaker.deprecations import renamed_warning, renamed_kwargs
 from sagemaker.workflow.entities import PipelineVariable
 
 logger = logging.getLogger(__name__)
 
 _TAR_SOURCE_FILENAME = "source.tar.gz"
 
-UploadedCode = namedtuple("UserCode", ["s3_prefix", "script_name"])
-"""sagemaker.fw_utils.UserCode: An object containing the S3 prefix and script name.
+UploadedCode = namedtuple("UploadedCode", ["s3_prefix", "script_name"])
+"""sagemaker.fw_utils.UploadedCode: An object containing the S3 prefix and script name.
+
 This is for the source code used for the entry point with an ``Estimator``. It can be
 instantiated with positional or keyword arguments.
 """
@@ -86,6 +90,7 @@ SM_DATAPARALLEL_SUPPORTED_INSTANCE_TYPES = (
     "local_gpu",
 )
 SM_DATAPARALLEL_SUPPORTED_FRAMEWORK_VERSIONS = {
+    # tf 2.12 should not be supported: smdataparallel excludes support for tf>=2.12.
     "tensorflow": [
         "2.3",
         "2.3.1",
@@ -132,24 +137,27 @@ SM_DATAPARALLEL_SUPPORTED_FRAMEWORK_VERSIONS = {
         "1.12.0",
         "1.12.1",
         "1.13.1",
+        "2.0.0",
+        "2.0.1",
+        "2.1.0",
+        "2.1.2",
+        "2.2.0",
     ],
 }
 
-PYTORCHDDP_SUPPORTED_FRAMEWORK_VERSIONS = [
-    "1.10",
-    "1.10.0",
-    "1.10.2",
-    "1.11",
-    "1.11.0",
-    "1.12",
-    "1.12.0",
-    "1.12.1",
+TORCH_DISTRIBUTED_GPU_SUPPORTED_FRAMEWORK_VERSIONS = [
     "1.13.1",
+    "2.0.0",
+    "2.0.1",
+    "2.1.0",
+    "2.1.2",
+    "2.2.0",
+    "2.3.0",
+    "2.3.1",
+    "2.4.1",
+    "2.5.1",
 ]
 
-
-TORCH_DISTRIBUTED_GPU_SUPPORTED_FRAMEWORK_VERSIONS = ["1.13.1"]
-
 TRAINIUM_SUPPORTED_DISTRIBUTION_STRATEGIES = ["torch_distributed"]
 TRAINIUM_SUPPORTED_TORCH_DISTRIBUTED_FRAMEWORK_VERSIONS = [
     "1.11",
@@ -158,6 +166,7 @@ TRAINIUM_SUPPORTED_TORCH_DISTRIBUTED_FRAMEWORK_VERSIONS = [
     "1.12.0",
     "1.12.1",
     "1.13.1",
+    "2.0.0",
 ]
 
 SMDISTRIBUTED_SUPPORTED_STRATEGIES = ["dataparallel", "modelparallel"]
@@ -203,7 +212,7 @@ def validate_source_code_input_against_pipeline_variables(
     git_config: Optional[Dict[str, str]] = None,
     enable_network_isolation: Union[bool, PipelineVariable] = False,
 ):
-    """Validate source code input against pipeline variables
+    """Validate source code input against pipeline variables.
 
     Args:
         entry_point (str or PipelineVariable): The path to the local Python source file that
@@ -244,7 +253,7 @@ def validate_source_code_input_against_pipeline_variables(
         logger.warning(
             "The source_dir is a pipeline variable: %s. During pipeline execution, "
             "the interpreted value of source_dir has to be an S3 URI and "
-            "must point to a tar.gz file",
+            "must point to a file with name ``sourcedir.tar.gz``",
             type(source_dir),
         )
 
@@ -316,9 +325,6 @@ def validate_mp_config(config):
         ValueError: If any of the keys have incorrect values.
     """
 
-    if "partitions" not in config:
-        raise ValueError("'partitions' is a required parameter.")
-
     def validate_positive(key):
         try:
             if not isinstance(config[key], int) or config[key] < 1:
@@ -392,7 +398,7 @@ def tar_and_upload_dir(
     kms_key=None,
     s3_resource=None,
     settings: Optional[SessionSettings] = None,
-):
+) -> UploadedCode:
     """Package source files and upload a compress tar file to S3.
 
     The S3 location will be ``s3://<bucket>/s3_key_prefix/sourcedir.tar.gz``.
@@ -423,7 +429,7 @@ def tar_and_upload_dir(
             of the SageMaker ``Session``, can be used to override the default encryption
             behavior (default: None).
     Returns:
-        sagemaker.fw_utils.UserCode: An object with the S3 bucket and key (S3 prefix) and
+        sagemaker.fw_utils.UploadedCode: An object with the S3 bucket and key (S3 prefix) and
             script name.
     """
     if directory and (is_pipeline_variable(directory) or directory.lower().startswith("s3://")):
@@ -466,7 +472,7 @@ def tar_and_upload_dir(
         if s3_resource is None:
             s3_resource = session.resource("s3", region_name=session.region_name)
         else:
-            print("Using provided s3_resource")
+            logger.debug("Using provided s3_resource")
 
         s3_resource.Object(bucket, key).upload_file(tar_file, ExtraArgs=extra_args)
     finally:
@@ -476,7 +482,7 @@ def tar_and_upload_dir(
 
 
 def _list_files_to_compress(script, directory):
-    """Placeholder docstring"""
+    """Placeholder docstring."""
     if directory is None:
         return [script]
 
@@ -580,7 +586,6 @@ def model_code_key_prefix(code_location_key_prefix, model_name, image):
     The location returned is a potential concatenation of 2 parts
         1. code_location_key_prefix if it exists
         2. model_name or a name derived from the image
-
     Args:
         code_location_key_prefix (str): the s3 key prefix from code_location
         model_name (str): the name of the model
@@ -592,7 +597,7 @@ def model_code_key_prefix(code_location_key_prefix, model_name, image):
     name_from_image = f"/model_code/{int(time.time())}"
     if not is_pipeline_variable(image):
         name_from_image = sagemaker.utils.name_from_image(image)
-    return "/".join(filter(None, [code_location_key_prefix, model_name or name_from_image]))
+    return s3_path_join(code_location_key_prefix, model_name or name_from_image)
 
 
 def warn_if_parameter_server_with_multi_gpu(training_instance_type, distribution):
@@ -615,8 +620,6 @@ def warn_if_parameter_server_with_multi_gpu(training_instance_type, distribution
                         "enabled": True
                     }
                 }
-
-
     """
     if training_instance_type == "local" or distribution is None:
         return
@@ -638,6 +641,35 @@ def warn_if_parameter_server_with_multi_gpu(training_instance_type, distribution
         logger.warning(PARAMETER_SERVER_MULTI_GPU_WARNING)
 
 
+def profiler_config_deprecation_warning(
+    profiler_config, image_uri, framework_name, framework_version
+):
+    """Deprecation message if framework profiling is specified TF >= 2.12 and PT >= 2.0."""
+    if profiler_config is None or profiler_config.framework_profile_params is None:
+        return
+
+    if framework_name not in ("pytorch", "tensorflow"):
+        return
+
+    if framework_version is None:
+        framework_name, _, image_tag, _ = framework_name_from_image(image_uri)
+
+        if image_tag is not None:
+            framework_version = framework_version_from_tag(image_tag)
+
+    if framework_version is not None:
+        framework_profile_thresh = (
+            version.parse("2.0") if framework_name == "pytorch" else version.parse("2.12")
+        )
+        framework_profile = version.parse(framework_version)
+        if framework_profile >= framework_profile_thresh:
+            deprecation_warn_base(
+                f"Framework profiling is deprecated from\
+                 {framework_name} version {framework_version}.\
+                 No framework metrics will be collected"
+            )
+
+
 def validate_smdistributed(
     instance_type, framework_name, framework_version, py_version, distribution, image_uri=None
 ):
@@ -658,6 +690,7 @@ def validate_smdistributed(
         framework_name (str): A string representing the name of framework selected.
         framework_version (str): A string representing the framework version selected.
         py_version (str): A string representing the python version selected.
+        Ex: `py38, py39, py310, py311`
         distribution (dict): A dictionary with information to enable distributed training.
             (Defaults to None if distributed training is not enabled.) For example:
 
@@ -729,7 +762,8 @@ def _validate_smdataparallel_args(
         instance_type (str): A string representing the type of training instance selected. Ex: `ml.p3.16xlarge`
         framework_name (str): A string representing the name of framework selected. Ex: `tensorflow`
         framework_version (str): A string representing the framework version selected. Ex: `2.3.1`
-        py_version (str): A string representing the python version selected. Ex: `py3`
+        py_version (str): A string representing the python version selected.
+        Ex: `py38, py39, py310, py311`
         distribution (dict): A dictionary with information to enable distributed training.
             (Defaults to None if distributed training is not enabled.) Ex:
 
@@ -746,7 +780,6 @@ def _validate_smdataparallel_args(
 
     Raises:
         ValueError: if
-            (`instance_type` is not in SM_DATAPARALLEL_SUPPORTED_INSTANCE_TYPES or
             `py_version` is not python3 or
             `framework_version` is not in SM_DATAPARALLEL_SUPPORTED_FRAMEWORK_VERSION
     """
@@ -757,17 +790,10 @@ def _validate_smdataparallel_args(
     if not smdataparallel_enabled:
         return
 
-    is_instance_type_supported = instance_type in SM_DATAPARALLEL_SUPPORTED_INSTANCE_TYPES
-
     err_msg = ""
 
-    if not is_instance_type_supported:
-        # instance_type is required
-        err_msg += (
-            f"Provided instance_type {instance_type} is not supported by smdataparallel.\n"
-            "Please specify one of the supported instance types:"
-            f"{SM_DATAPARALLEL_SUPPORTED_INSTANCE_TYPES}\n"
-        )
+    if not instance_type:
+        err_msg += "Please specify an instance_type for smdataparallel.\n"
 
     if not image_uri:
         # ignore framework_version & py_version if image_uri is set
@@ -791,14 +817,14 @@ def _validate_smdataparallel_args(
 
 
 def validate_distribution(
-    distribution,
-    instance_groups,
-    framework_name,
-    framework_version,
-    py_version,
-    image_uri,
-    kwargs,
-):
+    distribution: Dict,
+    instance_groups: List[InstanceGroup],
+    framework_name: str,
+    framework_version: str,
+    py_version: str,
+    image_uri: str,
+    kwargs: Dict,
+) -> Dict:
     """Check if distribution strategy is correctly invoked by the user.
 
     Currently, check for `dataparallel`, `modelparallel` and heterogeneous cluster set up.
@@ -821,6 +847,7 @@ def validate_distribution(
         framework_name (str): A string representing the name of framework selected.
         framework_version (str): A string representing the framework version selected.
         py_version (str): A string representing the python version selected.
+        Ex: `py38, py39, py310, py311`
         image_uri (str): A string representing a Docker image URI.
         kwargs(dict): Additional kwargs passed to this function
 
@@ -835,7 +862,9 @@ def validate_distribution(
             strategy-specific inputs are incorrect/unsupported or
             heterogeneous cluster set up is incorrect
     """
-    train_instance_groups = distribution.get("instance_groups", [])
+    validated_distribution = dict(distribution)
+
+    train_instance_groups = validated_distribution.get("instance_groups", [])
     if instance_groups is None:
         if len(train_instance_groups) >= 1:
             # if estimator's instance_groups is not defined but
@@ -865,39 +894,32 @@ def validate_distribution(
             instance_type = train_instance_group.instance_type
             validate_distribution_for_instance_type(
                 instance_type=instance_type,
-                distribution=distribution,
+                distribution=validated_distribution,
             )
             validate_smdistributed(
                 instance_type=instance_type,
                 framework_name=framework_name,
                 framework_version=framework_version,
                 py_version=py_version,
-                distribution=distribution,
+                distribution=validated_distribution,
                 image_uri=image_uri,
             )
             if framework_name and framework_name == "pytorch":
                 # We need to validate only for PyTorch framework
-                validate_pytorch_distribution(
-                    distribution=distribution,
-                    framework_name=framework_name,
-                    framework_version=framework_version,
-                    py_version=py_version,
-                    image_uri=image_uri,
-                )
                 validate_torch_distributed_distribution(
                     instance_type=instance_type,
-                    distribution=distribution,
+                    distribution=validated_distribution,
                     framework_version=framework_version,
                     py_version=py_version,
                     image_uri=image_uri,
                     entry_point=kwargs["entry_point"],
                 )
             warn_if_parameter_server_with_multi_gpu(
-                training_instance_type=instance_type, distribution=distribution
+                training_instance_type=instance_type, distribution=validated_distribution
             )
             # get instance group names
             instance_group_names.append(train_instance_group.instance_group_name)
-        distribution["instance_groups"] = instance_group_names
+        validated_distribution["instance_groups"] = instance_group_names
     else:
         # in this case, we are handling a normal training job (without heterogeneous cluster)
         instance_type = renamed_kwargs(
@@ -905,41 +927,34 @@ def validate_distribution(
         )
         validate_distribution_for_instance_type(
             instance_type=instance_type,
-            distribution=distribution,
+            distribution=validated_distribution,
         )
         validate_smdistributed(
             instance_type=instance_type,
             framework_name=framework_name,
             framework_version=framework_version,
             py_version=py_version,
-            distribution=distribution,
+            distribution=validated_distribution,
             image_uri=image_uri,
         )
         if framework_name and framework_name == "pytorch":
             # We need to validate only for PyTorch framework
-            validate_pytorch_distribution(
-                distribution=distribution,
-                framework_name=framework_name,
-                framework_version=framework_version,
-                py_version=py_version,
-                image_uri=image_uri,
-            )
             validate_torch_distributed_distribution(
                 instance_type=instance_type,
-                distribution=distribution,
+                distribution=validated_distribution,
                 framework_version=framework_version,
                 py_version=py_version,
                 image_uri=image_uri,
                 entry_point=kwargs["entry_point"],
             )
         warn_if_parameter_server_with_multi_gpu(
-            training_instance_type=instance_type, distribution=distribution
+            training_instance_type=instance_type, distribution=validated_distribution
         )
-    return distribution
+    return validated_distribution
 
 
 def validate_distribution_for_instance_type(instance_type, distribution):
-    """Check if the provided distribution strategy is supported for the instance_type
+    """Check if the provided distribution strategy is supported for the instance_type.
 
     Args:
         instance_type (str): A string representing the type of training instance selected.
@@ -947,7 +962,7 @@ def validate_distribution_for_instance_type(instance_type, distribution):
     """
     err_msg = ""
     if isinstance(instance_type, str):
-        match = re.match(r"^ml[\._]([a-z\d]+)\.?\w*$", instance_type)
+        match = re.match(r"^ml[\._]([a-z\d\-]+)\.?\w*$", instance_type)
         if match and match[1].startswith("trn"):
             keys = list(distribution.keys())
             if len(keys) == 0:
@@ -972,63 +987,6 @@ def validate_distribution_for_instance_type(instance_type, distribution):
         raise ValueError(err_msg)
 
 
-def validate_pytorch_distribution(
-    distribution, framework_name, framework_version, py_version, image_uri
-):
-    """Check if pytorch distribution strategy is correctly invoked by the user.
-
-    Args:
-        distribution (dict): A dictionary with information to enable distributed training.
-            (Defaults to None if distributed training is not enabled.) For example:
-
-            .. code:: python
-
-                {
-                    "pytorchddp": {
-                        "enabled": True
-                    }
-                }
-        framework_name (str): A string representing the name of framework selected.
-        framework_version (str): A string representing the framework version selected.
-        py_version (str): A string representing the python version selected.
-        image_uri (str): A string representing a Docker image URI.
-
-    Raises:
-        ValueError: if
-            `py_version` is not python3 or
-            `framework_version` is not in PYTORCHDDP_SUPPORTED_FRAMEWORK_VERSIONS
-    """
-    if framework_name and framework_name != "pytorch":
-        # We need to validate only for PyTorch framework
-        return
-
-    pytorch_ddp_enabled = False
-    if "pytorchddp" in distribution:
-        pytorch_ddp_enabled = distribution.get("pytorchddp").get("enabled", False)
-    if not pytorch_ddp_enabled:
-        # Distribution strategy other than pytorchddp is selected
-        return
-
-    err_msg = ""
-    if not image_uri:
-        # ignore framework_version and py_version if image_uri is set
-        # in case image_uri is not set, then both are mandatory
-        if framework_version not in PYTORCHDDP_SUPPORTED_FRAMEWORK_VERSIONS:
-            err_msg += (
-                f"Provided framework_version {framework_version} is not supported by"
-                " pytorchddp.\n"
-                "Please specify one of the supported framework versions:"
-                f" {PYTORCHDDP_SUPPORTED_FRAMEWORK_VERSIONS} \n"
-            )
-        if "py3" not in py_version:
-            err_msg += (
-                f"Provided py_version {py_version} is not supported by pytorchddp.\n"
-                "Please specify py_version>=py3"
-            )
-    if err_msg:
-        raise ValueError(err_msg)
-
-
 def validate_torch_distributed_distribution(
     instance_type,
     distribution,
@@ -1053,6 +1011,7 @@ def validate_torch_distributed_distribution(
                 }
         framework_version (str): A string representing the framework version selected.
         py_version (str): A string representing the python version selected.
+        Ex: `py38, py39, py310, py311`
         image_uri (str): A string representing a Docker image URI.
         entry_point (str or PipelineVariable): The absolute or relative path to the local Python
             source file that should be executed as the entry point to
@@ -1104,7 +1063,7 @@ def validate_torch_distributed_distribution(
             )
 
     # Check entry point type
-    if not entry_point.endswith(".py"):
+    if entry_point is not None and not entry_point.endswith(".py"):
         err_msg += (
             "Unsupported entry point type for the distribution torch_distributed.\n"
             "Only python programs (*.py) are supported."
@@ -1115,7 +1074,7 @@ def validate_torch_distributed_distribution(
 
 
 def _is_gpu_instance(instance_type):
-    """Returns bool indicating whether instance_type supports GPU
+    """Returns bool indicating whether instance_type supports GPU.
 
     Args:
         instance_type (str): Name of the instance_type to check against.
@@ -1124,7 +1083,7 @@ def _is_gpu_instance(instance_type):
         bool: Whether or not the instance_type supports GPU
     """
     if isinstance(instance_type, str):
-        match = re.match(r"^ml[\._]([a-z\d]+)\.?\w*$", instance_type)
+        match = re.match(r"^ml[\._]([a-z\d\-]+)\.?\w*$", instance_type)
         if match:
             if match[1].startswith("p") or match[1].startswith("g"):
                 return True
@@ -1134,7 +1093,7 @@ def _is_gpu_instance(instance_type):
 
 
 def _is_trainium_instance(instance_type):
-    """Returns bool indicating whether instance_type is a Trainium instance
+    """Returns bool indicating whether instance_type is a Trainium instance.
 
     Args:
         instance_type (str): Name of the instance_type to check against.
@@ -1143,14 +1102,14 @@ def _is_trainium_instance(instance_type):
         bool: Whether or not the instance_type is a Trainium instance
     """
     if isinstance(instance_type, str):
-        match = re.match(r"^ml[\._]([a-z\d]+)\.?\w*$", instance_type)
+        match = re.match(r"^ml[\._]([a-z\d\-]+)\.?\w*$", instance_type)
         if match and match[1].startswith("trn"):
             return True
     return False
 
 
 def python_deprecation_warning(framework, latest_supported_version):
-    """Placeholder docstring"""
+    """Placeholder docstring."""
     return PYTHON_2_DEPRECATION_WARNING.format(
         framework=framework, latest_supported_version=latest_supported_version
     )
@@ -1164,7 +1123,6 @@ def _region_supports_debugger(region_name):
 
     Returns:
         bool: Whether or not the region supports Amazon SageMaker Debugger.
-
     """
     return region_name.lower() not in DEBUGGER_UNSUPPORTED_REGIONS
 
@@ -1177,7 +1135,6 @@ def _region_supports_profiler(region_name):
 
     Returns:
         bool: Whether or not the region supports Amazon SageMaker Debugger profiling feature.
-
     """
     return region_name.lower() not in PROFILER_UNSUPPORTED_REGIONS
 
@@ -1192,7 +1149,7 @@ def _instance_type_supports_profiler(instance_type):
         bool: Whether or not the region supports Amazon SageMaker Debugger profiling feature.
     """
     if isinstance(instance_type, str):
-        match = re.match(r"^ml[\._]([a-z\d]+)\.?\w*$", instance_type)
+        match = re.match(r"^ml[\._]([a-z\d\-]+)\.?\w*$", instance_type)
         if match and match[1].startswith("trn"):
             return True
     return False
@@ -1205,7 +1162,8 @@ def validate_version_or_image_args(framework_version, py_version, image_uri):
 
     Args:
         framework_version (str): The version of the framework.
-        py_version (str): The version of Python.
+        py_version (str): A string representing the python version selected.
+        Ex: `py38, py39, py310, py311`
         image_uri (str): The URI of the image.
 
     Raises:
@@ -1237,9 +1195,8 @@ def create_image_uri(
         instance_type (str): SageMaker instance type. Used to determine device
             type (cpu/gpu/family-specific optimized).
         framework_version (str): The version of the framework.
-        py_version (str): Optional. Python version. If specified, should be one
-            of 'py2' or 'py3'. If not specified, image uri will not include a
-            python component.
+        py_version (str): Optional. Python version Ex: `py38, py39, py310, py311`.
+            If not specified, image uri will not include a python component.
         account (str): AWS account that contains the image. (default:
             '520713654638')
         accelerator_type (str): SageMaker Elastic Inference accelerator type.
