@@ -25,6 +25,7 @@ from sagemaker.processing import FrameworkProcessor
 from sagemaker.huggingface.estimator import HuggingFace
 
 from sagemaker.workflow.entities import PipelineVariable
+from sagemaker.utils import format_tags, Tags
 
 
 class HuggingFaceProcessor(FrameworkProcessor):
@@ -34,9 +35,9 @@ class HuggingFaceProcessor(FrameworkProcessor):
 
     def __init__(
         self,
-        role: str,
-        instance_count: Union[int, PipelineVariable],
-        instance_type: Union[str, PipelineVariable],
+        role: Optional[Union[str, PipelineVariable]] = None,
+        instance_count: Union[int, PipelineVariable] = None,
+        instance_type: Union[str, PipelineVariable] = None,
         transformers_version: Optional[str] = None,
         tensorflow_version: Optional[str] = None,
         pytorch_version: Optional[str] = None,
@@ -51,7 +52,7 @@ class HuggingFaceProcessor(FrameworkProcessor):
         base_job_name: Optional[str] = None,
         sagemaker_session: Optional[Session] = None,
         env: Optional[Dict[str, Union[str, PipelineVariable]]] = None,
-        tags: Optional[List[Dict[str, Union[str, PipelineVariable]]]] = None,
+        tags: Optional[Tags] = None,
         network_config: Optional[NetworkConfig] = None,
     ):
         """This processor executes a Python script in a HuggingFace execution environment.
@@ -68,10 +69,10 @@ class HuggingFaceProcessor(FrameworkProcessor):
                 ``image_uri`` is provided. The current supported version is ``4.4.2``.
             tensorflow_version (str): TensorFlow version you want to use for
                 executing your model training code. Defaults to ``None``. Required unless
-                ``pytorch_version`` is provided. The current supported version is ``1.6.0``.
+                ``pytorch_version`` is provided. The current supported version is ``2.4.1``.
             pytorch_version (str): PyTorch version you want to use for
                 executing your model training code. Defaults to ``None``. Required unless
-                ``tensorflow_version`` is provided. The current supported version is ``2.4.1``.
+                ``tensorflow_version`` is provided. The current supported version is ``1.6.0``.
             py_version (str): Python version you want to use for executing your model training
                 code. Defaults to ``None``. Required unless ``image_uri`` is provided.  If
                 using PyTorch, the current supported version is ``py36``. If using TensorFlow,
@@ -101,7 +102,7 @@ class HuggingFaceProcessor(FrameworkProcessor):
             base_job_name,
             sagemaker_session,
             env,
-            tags,
+            format_tags(tags),
             network_config,
         )
 
