@@ -28,7 +28,8 @@ INFERENCE_RECOMMENDER_FRAMEWORK_MAPPING = {
     "mxnet": "MXNET",
 }
 
-LOGGER = logging.getLogger("sagemaker")
+# Setting LOGGER for backward compatibility, in case users import it...
+logger = LOGGER = logging.getLogger("sagemaker")
 
 
 class Phase:
@@ -145,10 +146,10 @@ class InferenceRecommenderMixin:
         )
 
         if endpoint_configurations or traffic_pattern or stopping_conditions or resource_limit:
-            LOGGER.info("Advance Job parameters were specified. Running Advanced job...")
+            logger.info("Advanced Job parameters were specified. Running Advanced job...")
             job_type = "Advanced"
         else:
-            LOGGER.info("Advance Job parameters were not specified. Running Default job...")
+            logger.info("Advanced Job parameters were not specified. Running Default job...")
             job_type = "Default"
 
         self._init_sagemaker_session_if_does_not_exist()
@@ -173,7 +174,7 @@ class InferenceRecommenderMixin:
                 vpc_config=self.vpc_config,
                 enable_network_isolation=self.enable_network_isolation(),
             )
-            LOGGER.warning("Attempting to create new model with name %s", self.name)
+            logger.warning("Attempting to create new model with name %s", self.name)
             self.sagemaker_session.create_model(**create_model_args)
 
         ret_name = self.sagemaker_session.create_inference_recommendations_job(
@@ -215,6 +216,7 @@ class InferenceRecommenderMixin:
         accelerator_type = kwargs["accelerator_type"]
         async_inference_config = kwargs["async_inference_config"]
         serverless_inference_config = kwargs["serverless_inference_config"]
+        explainer_config = kwargs["explainer_config"]
         inference_recommendation_id = kwargs["inference_recommendation_id"]
         inference_recommender_job_results = kwargs["inference_recommender_job_results"]
         if inference_recommendation_id is not None:
@@ -225,6 +227,7 @@ class InferenceRecommenderMixin:
                 async_inference_config=async_inference_config,
                 serverless_inference_config=serverless_inference_config,
                 inference_recommendation_id=inference_recommendation_id,
+                explainer_config=explainer_config,
             )
         elif inference_recommender_job_results is not None:
             inference_recommendation = self._update_params_for_right_size(
@@ -233,8 +236,14 @@ class InferenceRecommenderMixin:
                 accelerator_type,
                 serverless_inference_config,
                 async_inference_config,
+                explainer_config,
             )
-        return inference_recommendation or (instance_type, initial_instance_count)
+
+        return (
+            inference_recommendation
+            if inference_recommendation
+            else (instance_type, initial_instance_count)
+        )
 
     def _update_params_for_right_size(
         self,
@@ -243,6 +252,7 @@ class InferenceRecommenderMixin:
         accelerator_type=None,
         serverless_inference_config=None,
         async_inference_config=None,
+        explainer_config=None,
     ):
         """Validates that Inference Recommendation parameters can be used in `model.deploy()`
 
@@ -262,6 +272,8 @@ class InferenceRecommenderMixin:
                 whether serverless_inference_config has been passed into `model.deploy()`.
             async_inference_config (sagemaker.model_monitor.AsyncInferenceConfig):
                 whether async_inference_config has been passed into `model.deploy()`.
+            explainer_config (sagemaker.explainer.ExplainerConfig): whether explainer_config
+                has been passed into `model.deploy()`.
 
         Returns:
             (string, int) or None: Top instance_type and associated initial_instance_count
@@ -270,27 +282,28 @@ class InferenceRecommenderMixin:
         if accelerator_type:
             raise ValueError("accelerator_type is not compatible with right_size().")
         if instance_type or initial_instance_count:
-            LOGGER.warning(
+            logger.warning(
                 "instance_type or initial_instance_count specified."
                 "Overriding right_size() recommendations."
             )
             return None
         if async_inference_config:
-            LOGGER.warning(
+            logger.warning(
                 "async_inference_config is specified. Overriding right_size() recommendations."
             )
             return None
         if serverless_inference_config:
-            LOGGER.warning(
+            logger.warning(
                 "serverless_inference_config is specified. Overriding right_size() recommendations."
             )
             return None
+        if explainer_config:
+            logger.warning(
+                "explainer_config is specified. Overriding right_size() recommendations."
+            )
+            return None
 
-        instance_type = self.inference_recommendations[0]["EndpointConfiguration"]["InstanceType"]
-        initial_instance_count = self.inference_recommendations[0]["EndpointConfiguration"][
-            "InitialInstanceCount"
-        ]
-        return (instance_type, initial_instance_count)
+        return self._filter_recommendations_for_realtime()
 
     def _update_params_for_recommendation_id(
         self,
@@ -300,6 +313,7 @@ class InferenceRecommenderMixin:
         async_inference_config,
         serverless_inference_config,
         inference_recommendation_id,
+        explainer_config,
     ):
         """Update parameters with inference recommendation results.
 
@@ -332,6 +346,8 @@ class InferenceRecommenderMixin:
                 the recommendation you picked from inference recommendation job
                 results and would like to deploy the model and endpoint with
                 recommended parameters.
+            explainer_config (sagemaker.explainer.ExplainerConfig): Specifies online explainability
+                configuration for use with Amazon SageMaker Clarify. Default: None.
         Raises:
             ValueError: If arguments combination check failed in these circumstances:
                 - If only one of instance type or instance count specified or
@@ -344,19 +360,13 @@ class InferenceRecommenderMixin:
         """
 
         if instance_type is not None and initial_instance_count is not None:
-            LOGGER.warning(
+            logger.warning(
                 "Both instance_type and initial_instance_count are specified,"
                 "overriding the recommendation result."
             )
             return (instance_type, initial_instance_count)
 
         # Validate non-compatible parameters with recommendation id
-        if bool(instance_type) != bool(initial_instance_count):
-            raise ValueError(
-                "Please either do not specify instance_type and initial_instance_count"
-                "since they are in recommendation, or specify both of them if you want"
-                "to override the recommendation."
-            )
         if accelerator_type is not None:
             raise ValueError("accelerator_type is not compatible with inference_recommendation_id.")
         if async_inference_config is not None:
@@ -367,33 +377,43 @@ class InferenceRecommenderMixin:
             raise ValueError(
                 "serverless_inference_config is not compatible with inference_recommendation_id."
             )
+        if explainer_config is not None:
+            raise ValueError("explainer_config is not compatible with inference_recommendation_id.")
 
         # Validate recommendation id
         if not re.match(r"[a-zA-Z0-9](-*[a-zA-Z0-9]){0,63}\/\w{8}$", inference_recommendation_id):
-            raise ValueError("Inference Recommendation id is not valid")
-        recommendation_job_name = inference_recommendation_id.split("/")[0]
+            raise ValueError("inference_recommendation_id is not valid")
+        job_or_model_name = inference_recommendation_id.split("/")[0]
 
         sage_client = self.sagemaker_session.sagemaker_client
-        recommendation_res = sage_client.describe_inference_recommendations_job(
-            JobName=recommendation_job_name
-        )
-        input_config = recommendation_res["InputConfig"]
-
-        recommendation = next(
-            (
-                rec
-                for rec in recommendation_res["InferenceRecommendations"]
-                if rec["RecommendationId"] == inference_recommendation_id
-            ),
-            None,
+        # Get recommendation from right size job and model
+        (
+            right_size_recommendation,
+            model_recommendation,
+            right_size_job_res,
+        ) = self._get_recommendation(
+            sage_client=sage_client,
+            job_or_model_name=job_or_model_name,
+            inference_recommendation_id=inference_recommendation_id,
         )
 
-        if not recommendation:
+        # Update params beased on model recommendation
+        if model_recommendation:
+            if initial_instance_count is None:
+                raise ValueError("Must specify model recommendation id and instance count.")
+            self.env.update(model_recommendation["Environment"])
+            instance_type = model_recommendation["InstanceType"]
+            return (instance_type, initial_instance_count)
+
+        # Update params based on default inference recommendation
+        if bool(instance_type) != bool(initial_instance_count):
             raise ValueError(
-                "inference_recommendation_id does not exist in InferenceRecommendations list"
+                "instance_type and initial_instance_count are mutually exclusive with"
+                "recommendation id since they are in recommendation."
+                "Please specify both of them if you want to override the recommendation."
             )
-
-        model_config = recommendation["ModelConfiguration"]
+        input_config = right_size_job_res["InputConfig"]
+        model_config = right_size_recommendation["ModelConfiguration"]
         envs = (
             model_config["EnvironmentParameters"]
             if "EnvironmentParameters" in model_config
@@ -442,8 +462,10 @@ class InferenceRecommenderMixin:
                 self.model_data = compilation_res["ModelArtifacts"]["S3ModelArtifacts"]
                 self.image_uri = compilation_res["InferenceImage"]
 
-        instance_type = recommendation["EndpointConfiguration"]["InstanceType"]
-        initial_instance_count = recommendation["EndpointConfiguration"]["InitialInstanceCount"]
+        instance_type = right_size_recommendation["EndpointConfiguration"]["InstanceType"]
+        initial_instance_count = right_size_recommendation["EndpointConfiguration"][
+            "InitialInstanceCount"
+        ]
 
         return (instance_type, initial_instance_count)
 
@@ -511,3 +533,90 @@ class InferenceRecommenderMixin:
                 threshold.to_json for threshold in model_latency_thresholds
             ]
         return stopping_conditions
+
+    def _get_recommendation(self, sage_client, job_or_model_name, inference_recommendation_id):
+        """Get recommendation from right size job and model"""
+        right_size_recommendation, model_recommendation, right_size_job_res = None, None, None
+        right_size_recommendation, right_size_job_res = self._get_right_size_recommendation(
+            sage_client=sage_client,
+            job_or_model_name=job_or_model_name,
+            inference_recommendation_id=inference_recommendation_id,
+        )
+        if right_size_recommendation is None:
+            model_recommendation = self._get_model_recommendation(
+                sage_client=sage_client,
+                job_or_model_name=job_or_model_name,
+                inference_recommendation_id=inference_recommendation_id,
+            )
+            if model_recommendation is None:
+                raise ValueError("inference_recommendation_id is not valid")
+
+        return right_size_recommendation, model_recommendation, right_size_job_res
+
+    def _get_right_size_recommendation(
+        self,
+        sage_client,
+        job_or_model_name,
+        inference_recommendation_id,
+    ):
+        """Get recommendation from right size job"""
+        right_size_recommendation, right_size_job_res = None, None
+        try:
+            right_size_job_res = sage_client.describe_inference_recommendations_job(
+                JobName=job_or_model_name
+            )
+            if right_size_job_res:
+                right_size_recommendation = self._search_recommendation(
+                    recommendation_list=right_size_job_res["InferenceRecommendations"],
+                    inference_recommendation_id=inference_recommendation_id,
+                )
+        except sage_client.exceptions.ResourceNotFound:
+            pass
+
+        return right_size_recommendation, right_size_job_res
+
+    def _get_model_recommendation(
+        self,
+        sage_client,
+        job_or_model_name,
+        inference_recommendation_id,
+    ):
+        """Get recommendation from model"""
+        model_recommendation = None
+        try:
+            model_res = sage_client.describe_model(ModelName=job_or_model_name)
+            if model_res:
+                model_recommendation = self._search_recommendation(
+                    recommendation_list=model_res["DeploymentRecommendation"][
+                        "RealTimeInferenceRecommendations"
+                    ],
+                    inference_recommendation_id=inference_recommendation_id,
+                )
+        except sage_client.exceptions.ResourceNotFound:
+            pass
+
+        return model_recommendation
+
+    def _search_recommendation(self, recommendation_list, inference_recommendation_id):
+        """Search recommendation based on recommendation id"""
+        return next(
+            (
+                rec
+                for rec in recommendation_list
+                if rec["RecommendationId"] == inference_recommendation_id
+            ),
+            None,
+        )
+
+    # TODO: until we have bandwidth to integrate right_size + deploy with serverless
+    def _filter_recommendations_for_realtime(self):
+        """Filter recommendations list to find a realtime instance"""
+        instance_type = None
+        initial_instance_count = None
+        for recommendations in self.inference_recommendations:
+            if "ServerlessConfig" not in recommendations["EndpointConfiguration"]:
+                instance_type = recommendations["EndpointConfiguration"]["InstanceType"]
+                initial_instance_count = recommendations["EndpointConfiguration"][
+                    "InitialInstanceCount"
+                ]
+        return (instance_type, initial_instance_count)
