@@ -43,6 +43,8 @@ class TrainingInput(object):
         attribute_names: Optional[List[Union[str, PipelineVariable]]] = None,
         target_attribute_name: Optional[Union[str, PipelineVariable]] = None,
         shuffle_config: Optional["ShuffleConfig"] = None,
+        hub_access_config: Optional[dict] = None,
+        model_access_config: Optional[dict] = None,
     ):
         r"""Create a definition for input data used by an SageMaker training job.
 
@@ -102,6 +104,13 @@ class TrainingInput(object):
             shuffle_config (sagemaker.inputs.ShuffleConfig): If specified this configuration enables
                 shuffling on this channel. See the SageMaker API documentation for more info:
                 https://docs.aws.amazon.com/sagemaker/latest/dg/API_ShuffleConfig.html
+            hub_access_config (dict): Specify the HubAccessConfig of a
+                Model Reference for which a training job is being created for.
+            model_access_config (dict): For models that require a Model Access Config, specify True
+                or False for to indicate whether model terms of use have been accepted.
+                The `accept_eula` value must be explicitly defined as `True` in order to
+                accept the end-user license agreement (EULA) that some
+                models require. (Default: None).
         """
         self.config = {
             "DataSource": {"S3DataSource": {"S3DataType": s3_data_type, "S3Uri": s3_data}}
@@ -129,6 +138,27 @@ class TrainingInput(object):
             self.config["TargetAttributeName"] = target_attribute_name
         if shuffle_config is not None:
             self.config["ShuffleConfig"] = {"Seed": shuffle_config.seed}
+        self.add_hub_access_config(hub_access_config)
+        self.add_model_access_config(model_access_config)
+
+    def add_hub_access_config(self, hub_access_config=None):
+        """Add Hub Access Config to the channel's configuration.
+
+        Args:
+            hub_access_config (dict): The HubAccessConfig to be added to the
+            channel's configuration.
+        """
+        if hub_access_config is not None:
+            self.config["DataSource"]["S3DataSource"]["HubAccessConfig"] = hub_access_config
+
+    def add_model_access_config(self, model_access_config=None):
+        """Add Model Access Config to the channel's configuration.
+
+        Args:
+            model_access_config (dict): Whether model terms of use have been accepted.
+        """
+        if model_access_config is not None:
+            self.config["DataSource"]["S3DataSource"]["ModelAccessConfig"] = model_access_config
 
 
 class ShuffleConfig(object):
@@ -162,9 +192,68 @@ class CreateModelInput(object):
 
 @attr.s
 class TransformInput(object):
-    """Create a class containing all the parameters.
+    """Creates a class containing parameters for configuring input data for a batch tramsform job.
 
     It can be used when calling ``sagemaker.transformer.Transformer.transform()``
+
+    Args:
+        data (str): The S3 location of the input data that the model can consume.
+        data_type (str): The data type for a batch transform job.
+            (default: ``'S3Prefix'``)
+        content_type (str): The multi-purpose internet email extension (MIME) type of the data.
+            (default: None)
+        compression_type (str): If your transform data is compressed, specify the compression type.
+            Valid values: ``'Gzip'``, ``None``
+            (default: None)
+        split_type (str): The method to use to split the transform job's data files into smaller
+            batches.
+            Valid values: ``'Line'``, ``RecordIO``, ``'TFRecord'``, None
+            (default: None)
+        input_filter (str): A JSONPath expression for selecting a portion of the input data to pass
+            to the algorithm. For example, you can use this parameter to exclude fields, such as an
+            ID column, from the input. If you want SageMaker to pass the entire input dataset to the
+            algorithm, accept the default value ``$``. For more information on batch transform data
+            processing, input, join, and output, see
+            `Associate Prediction Results with Input Records
+            <https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html?>`_
+            in the *Amazon SageMaker developer guide*.
+            Example value: ``$``. For more information about valid values for this parameter, see
+            `JSONPath Operators
+            <https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html#data-processing-operators>`_
+            in the *Amazon SageMaker developer guide*.
+            (default: ``$``)
+        output_filter (str): A JSONPath expression for selecting a portion of the joined dataset to
+            save in the output file for a batch transform job. If you want SageMaker to store the
+            entire input dataset in the output file, leave the default value, $. If you specify
+            indexes that aren't within the dimension size of the joined dataset, you get an error.
+            Example value: ``$``. For more information about valid values for this parameter, see
+            `JSONPath Operators
+            <https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html#data-processing-operators>`_
+            in the *Amazon SageMaker developer guide*.
+            (default: ``$``)
+        join_source (str): Specifies the source of the data to join with the transformed data.
+            The default value is ``None``, which specifies not to join the input with the
+            transformed data. If you want the batch transform job to join the original input data
+            with the transformed data, set to ``Input``.
+            Valid values: ``None``, ``Input``
+            (default: None)
+        model_client_config (dict): Configures the timeout and maximum number of retries for
+            processing a transform job invocation.
+
+                * ``'InvocationsTimeoutInSeconds'`` (int) - The timeout value in seconds for an
+                  invocation request. The default value is 600.
+                * ``'InvocationsMaxRetries'`` (int) - The maximum number of retries when invocation
+                  requests are failing.
+
+            (default: ``{600,3}``)
+        batch_data_capture_config (dict): The dict is an object of `BatchDataCaptureConfig
+            <https://sagemaker.readthedocs.io/en/stable/api/utility/inputs.html#sagemaker.inputs.BatchDataCaptureConfig>`_
+            and specifies configuration related to batch transform job
+            for use with Amazon SageMaker Model Monitoring. For more information,
+            see `Capture data from batch transform job
+            <https://docs.aws.amazon.com/sagemaker/latest/dg/model-monitor-data-capture-batch.html>`_
+            in the *Amazon SageMaker developer guide*.
+            (default: None)
     """
 
     data: str = attr.ib()
