@@ -14,20 +14,37 @@
 from __future__ import absolute_import
 import copy
 
+from concurrent.futures import ThreadPoolExecutor, as_completed
+
 from functools import cmp_to_key
+import json
 from typing import Any, Generator, List, Optional, Tuple, Union, Set, Dict
 from packaging.version import Version
 from sagemaker.jumpstart import accessors
-from sagemaker.jumpstart.constants import JUMPSTART_DEFAULT_REGION_NAME
-from sagemaker.jumpstart.enums import JumpStartScriptScope
+from sagemaker.jumpstart.constants import (
+    DEFAULT_JUMPSTART_SAGEMAKER_SESSION,
+    PROPRIETARY_MODEL_SPEC_PREFIX,
+)
+from sagemaker.jumpstart.enums import JumpStartScriptScope, JumpStartModelType
 from sagemaker.jumpstart.filters import (
     SPECIAL_SUPPORTED_FILTER_KEYS,
+    ProprietaryModelFilterIdentifiers,
     BooleanValues,
     Identity,
     SpecialSupportedFilterKeys,
 )
 from sagemaker.jumpstart.filters import Constant, ModelFilter, Operator, evaluate_filter_expression
-from sagemaker.jumpstart.utils import get_sagemaker_version
+from sagemaker.jumpstart.types import JumpStartModelHeader, JumpStartModelSpecs
+from sagemaker.jumpstart.utils import (
+    get_jumpstart_content_bucket,
+    get_region_fallback,
+    get_sagemaker_version,
+    verify_model_region_and_return_specs,
+    validate_model_id_and_get_type,
+)
+from sagemaker.session import Session
+
+MAX_SEARCH_WORKERS = int(100 * 1e6 / 25 * 1e3)  # max 100MB total memory, 25kB per thread)
 
 
 def _compare_model_version_tuples(  # pylint: disable=too-many-return-statements
@@ -110,15 +127,11 @@ def extract_framework_task_model(model_id: str) -> Tuple[str, str, str]:
 
     Args:
         model_id (str): The model ID for which to extract the framework/task/model.
-
-    Raises:
-        ValueError: If the model ID cannot be parsed into at least 3 components seperated by
-            "-" character.
     """
     _id_parts = model_id.split("-")
 
     if len(_id_parts) < 3:
-        raise ValueError(f"incorrect model ID: {model_id}.")
+        return "", "", ""
 
     framework = _id_parts[0]
     task = _id_parts[1]
@@ -127,9 +140,24 @@ def extract_framework_task_model(model_id: str) -> Tuple[str, str, str]:
     return framework, task, name
 
 
+def extract_model_type_filter_representation(spec_key: str) -> str:
+    """Parses model spec key, determine if the model is proprietary or open weight.
+
+    Args:
+        spek_key (str): The model spec key for which to extract the model type.
+    """
+    model_spec_prefix = spec_key.split("/")[0]
+
+    if model_spec_prefix == PROPRIETARY_MODEL_SPEC_PREFIX:
+        return JumpStartModelType.PROPRIETARY.value
+
+    return JumpStartModelType.OPEN_WEIGHTS.value
+
+
 def list_jumpstart_tasks(  # pylint: disable=redefined-builtin
     filter: Union[Operator, str] = Constant(BooleanValues.TRUE),
-    region: str = JUMPSTART_DEFAULT_REGION_NAME,
+    region: Optional[str] = None,
+    sagemaker_session: Session = DEFAULT_JUMPSTART_SAGEMAKER_SESSION,
 ) -> List[str]:
     """List tasks for JumpStart, and optionally apply filters to result.
 
@@ -140,11 +168,21 @@ def list_jumpstart_tasks(  # pylint: disable=redefined-builtin
             (e.g. ``"task == ic"``). If this argument is not supplied, all tasks will be listed.
             (Default: Constant(BooleanValues.TRUE)).
         region (str): Optional. The AWS region from which to retrieve JumpStart metadata regarding
-            models. (Default: JUMPSTART_DEFAULT_REGION_NAME).
+            models. (Default: None).
+        sagemaker_session (sagemaker.session.Session): Optional. The SageMaker Session to
+            use to perform the model search. (Default: DEFAULT_JUMPSTART_SAGEMAKER_SESSION).
     """
 
+    region = region or get_region_fallback(
+        sagemaker_session=sagemaker_session,
+    )
     tasks: Set[str] = set()
-    for model_id, _ in _generate_jumpstart_model_versions(filter=filter, region=region):
+    for model_id, _ in _generate_jumpstart_model_versions(
+        filter=filter,
+        region=region,
+        sagemaker_session=sagemaker_session,
+        model_type=JumpStartModelType.OPEN_WEIGHTS,
+    ):
         _, task, _ = extract_framework_task_model(model_id)
         tasks.add(task)
     return sorted(list(tasks))
@@ -152,7 +190,8 @@ def list_jumpstart_tasks(  # pylint: disable=redefined-builtin
 
 def list_jumpstart_frameworks(  # pylint: disable=redefined-builtin
     filter: Union[Operator, str] = Constant(BooleanValues.TRUE),
-    region: str = JUMPSTART_DEFAULT_REGION_NAME,
+    region: Optional[str] = None,
+    sagemaker_session: Session = DEFAULT_JUMPSTART_SAGEMAKER_SESSION,
 ) -> List[str]:
     """List frameworks for JumpStart, and optionally apply filters to result.
 
@@ -163,11 +202,21 @@ def list_jumpstart_frameworks(  # pylint: disable=redefined-builtin
             (eg. ``"task == ic"``). If this argument is not supplied, all frameworks will be listed.
             (Default: Constant(BooleanValues.TRUE)).
         region (str): Optional. The AWS region from which to retrieve JumpStart metadata regarding
-            models. (Default: JUMPSTART_DEFAULT_REGION_NAME).
+            models. (Default: None).
+        sagemaker_session (sagemaker.session.Session): Optional. The SageMaker Session
+            to use to perform the model search. (Default: DEFAULT_JUMPSTART_SAGEMAKER_SESSION).
     """
 
+    region = region or get_region_fallback(
+        sagemaker_session=sagemaker_session,
+    )
     frameworks: Set[str] = set()
-    for model_id, _ in _generate_jumpstart_model_versions(filter=filter, region=region):
+    for model_id, _ in _generate_jumpstart_model_versions(
+        filter=filter,
+        region=region,
+        sagemaker_session=sagemaker_session,
+        model_type=JumpStartModelType.OPEN_WEIGHTS,
+    ):
         framework, _, _ = extract_framework_task_model(model_id)
         frameworks.add(framework)
     return sorted(list(frameworks))
@@ -175,7 +224,8 @@ def list_jumpstart_frameworks(  # pylint: disable=redefined-builtin
 
 def list_jumpstart_scripts(  # pylint: disable=redefined-builtin
     filter: Union[Operator, str] = Constant(BooleanValues.TRUE),
-    region: str = JUMPSTART_DEFAULT_REGION_NAME,
+    region: Optional[str] = None,
+    sagemaker_session: Session = DEFAULT_JUMPSTART_SAGEMAKER_SESSION,
 ) -> List[str]:
     """List scripts for JumpStart, and optionally apply filters to result.
 
@@ -186,20 +236,32 @@ def list_jumpstart_scripts(  # pylint: disable=redefined-builtin
             (e.g. ``"task == ic"``). If this argument is not supplied, all scripts will be listed.
             (Default: Constant(BooleanValues.TRUE)).
         region (str): Optional. The AWS region from which to retrieve JumpStart metadata regarding
-            models. (Default: JUMPSTART_DEFAULT_REGION_NAME).
+            models. (Default: None).
+        sagemaker_session (sagemaker.session.Session): Optional. The SageMaker Session to
+            use to perform the model search. (Default: DEFAULT_JUMPSTART_SAGEMAKER_SESSION).
     """
+    region = region or get_region_fallback(
+        sagemaker_session=sagemaker_session,
+    )
     if (isinstance(filter, Constant) and filter.resolved_value == BooleanValues.TRUE) or (
         isinstance(filter, str) and filter.lower() == BooleanValues.TRUE.lower()
     ):
         return sorted([e.value for e in JumpStartScriptScope])
 
     scripts: Set[str] = set()
-    for model_id, version in _generate_jumpstart_model_versions(filter=filter, region=region):
+    for model_id, version in _generate_jumpstart_model_versions(
+        filter=filter,
+        region=region,
+        sagemaker_session=sagemaker_session,
+        model_type=JumpStartModelType.OPEN_WEIGHTS,
+    ):
         scripts.add(JumpStartScriptScope.INFERENCE)
-        model_specs = accessors.JumpStartModelsAccessor.get_model_specs(
+        model_specs = verify_model_region_and_return_specs(
             region=region,
             model_id=model_id,
             version=version,
+            sagemaker_session=sagemaker_session,
+            scope=JumpStartScriptScope.INFERENCE,
         )
         if model_specs.training_supported:
             scripts.add(JumpStartScriptScope.TRAINING)
@@ -209,12 +271,22 @@ def list_jumpstart_scripts(  # pylint: disable=redefined-builtin
     return sorted(list(scripts))
 
 
+def _is_valid_version(version: str) -> bool:
+    """Checks if the version is convertable to Version class."""
+    try:
+        Version(version)
+        return True
+    except Exception:  # pylint: disable=broad-except
+        return False
+
+
 def list_jumpstart_models(  # pylint: disable=redefined-builtin
     filter: Union[Operator, str] = Constant(BooleanValues.TRUE),
-    region: str = JUMPSTART_DEFAULT_REGION_NAME,
+    region: Optional[str] = None,
     list_incomplete_models: bool = False,
     list_old_models: bool = False,
     list_versions: bool = False,
+    sagemaker_session: Session = DEFAULT_JUMPSTART_SAGEMAKER_SESSION,
 ) -> List[Union[Tuple[str], Tuple[str, str]]]:
     """List models for JumpStart, and optionally apply filters to result.
 
@@ -225,7 +297,7 @@ def list_jumpstart_models(  # pylint: disable=redefined-builtin
             (e.g. ``"task == ic"``). If this argument is not supplied, all models will be listed.
             (Default: Constant(BooleanValues.TRUE)).
         region (str): Optional. The AWS region from which to retrieve JumpStart metadata regarding
-            models. (Default: JUMPSTART_DEFAULT_REGION_NAME).
+            models. (Default: None).
         list_incomplete_models (bool): Optional. If a model does not contain metadata fields
             requested by the filter, and the filter cannot be resolved to a include/not include,
             whether the model should be included. By default, these models are omitted from results.
@@ -234,23 +306,35 @@ def list_jumpstart_models(  # pylint: disable=redefined-builtin
             versions should be included in the returned result. (Default: False).
         list_versions (bool): Optional. True if versions for models should be returned in addition
             to the id of the model. (Default: False).
+        sagemaker_session (sagemaker.session.Session): Optional. The SageMaker Session to use
+            to perform the model search. (Default: DEFAULT_JUMPSTART_SAGEMAKER_SESSION).
     """
 
+    region = region or get_region_fallback(
+        sagemaker_session=sagemaker_session,
+    )
     model_id_version_dict: Dict[str, List[str]] = dict()
     for model_id, version in _generate_jumpstart_model_versions(
-        filter=filter, region=region, list_incomplete_models=list_incomplete_models
+        filter=filter,
+        region=region,
+        list_incomplete_models=list_incomplete_models,
+        sagemaker_session=sagemaker_session,
     ):
         if model_id not in model_id_version_dict:
             model_id_version_dict[model_id] = list()
-        model_id_version_dict[model_id].append(Version(version))
+        model_version = Version(version) if _is_valid_version(version) else version
+        model_id_version_dict[model_id].append(model_version)
 
     if not list_versions:
         return sorted(list(model_id_version_dict.keys()))
 
     if not list_old_models:
-        model_id_version_dict = {
-            model_id: set([max(versions)]) for model_id, versions in model_id_version_dict.items()
-        }
+        for model_id, versions in model_id_version_dict.items():
+            try:
+                model_id_version_dict.update({model_id: set([max(versions)])})
+            except TypeError:
+                versions = [str(v) for v in versions]
+                model_id_version_dict.update({model_id: set([max(versions)])})
 
     model_id_version_set: Set[Tuple[str, str]] = set()
     for model_id in model_id_version_dict:
@@ -262,8 +346,10 @@ def list_jumpstart_models(  # pylint: disable=redefined-builtin
 
 def _generate_jumpstart_model_versions(  # pylint: disable=redefined-builtin
     filter: Union[Operator, str] = Constant(BooleanValues.TRUE),
-    region: str = JUMPSTART_DEFAULT_REGION_NAME,
+    region: Optional[str] = None,
     list_incomplete_models: bool = False,
+    sagemaker_session: Session = DEFAULT_JUMPSTART_SAGEMAKER_SESSION,
+    model_type: Optional[JumpStartModelType] = None,
 ) -> Generator:
     """Generate models for JumpStart, and optionally apply filters to result.
 
@@ -274,18 +360,45 @@ def _generate_jumpstart_model_versions(  # pylint: disable=redefined-builtin
             (e.g. ``"task == ic"``). If this argument is not supplied, all models will be generated.
             (Default: Constant(BooleanValues.TRUE)).
         region (str): Optional. The AWS region from which to retrieve JumpStart metadata regarding
-            models. (Default: JUMPSTART_DEFAULT_REGION_NAME).
+            models. (Default: None).
         list_incomplete_models (bool): Optional. If a model does not contain metadata fields
             requested by the filter, and the filter cannot be resolved to a include/not include,
             whether the model should be included. By default, these models are omitted from
             results. (Default: False).
+        sagemaker_session (sagemaker.session.Session): Optional. The SageMaker Session
+            to use to perform the model search. (Default: DEFAULT_JUMPSTART_SAGEMAKER_SESSION).
     """
 
+    region = region or get_region_fallback(
+        sagemaker_session=sagemaker_session,
+    )
+
+    prop_models_manifest_list = accessors.JumpStartModelsAccessor._get_manifest(
+        region=region,
+        s3_client=sagemaker_session.s3_client,
+        model_type=JumpStartModelType.PROPRIETARY,
+    )
+    open_weight_manifest_list = accessors.JumpStartModelsAccessor._get_manifest(
+        region=region,
+        s3_client=sagemaker_session.s3_client,
+        model_type=JumpStartModelType.OPEN_WEIGHTS,
+    )
+    models_manifest_list = (
+        open_weight_manifest_list
+        if model_type == JumpStartModelType.OPEN_WEIGHTS
+        else (
+            prop_models_manifest_list
+            if model_type == JumpStartModelType.PROPRIETARY
+            else open_weight_manifest_list + prop_models_manifest_list
+        )
+    )
+
     if isinstance(filter, str):
         filter = Identity(filter)
 
-    models_manifest_list = accessors.JumpStartModelsAccessor._get_manifest(region=region)
-    manifest_keys = set(models_manifest_list[0].__slots__)
+    manifest_keys = set(
+        open_weight_manifest_list[0].__slots__ + prop_models_manifest_list[0].__slots__
+    )
 
     all_keys: Set[str] = set()
 
@@ -295,6 +408,10 @@ def _generate_jumpstart_model_versions(  # pylint: disable=redefined-builtin
         model_filter = operator.unresolved_value
         key = model_filter.key
         all_keys.add(key)
+        if model_filter.key == SpecialSupportedFilterKeys.MODEL_TYPE and model_filter.value in {
+            identifier.value for identifier in ProprietaryModelFilterIdentifiers
+        }:
+            model_filter.set_value(JumpStartModelType.PROPRIETARY.value)
         model_filters.add(model_filter)
 
     for key in all_keys:
@@ -306,13 +423,11 @@ def _generate_jumpstart_model_versions(  # pylint: disable=redefined-builtin
     required_manifest_keys = manifest_keys.intersection(metadata_filter_keys)
     possible_spec_keys = metadata_filter_keys - manifest_keys
 
-    unrecognized_keys: Set[str] = set()
-
     is_task_filter = SpecialSupportedFilterKeys.TASK in all_keys
     is_framework_filter = SpecialSupportedFilterKeys.FRAMEWORK in all_keys
-    is_supported_model_filter = SpecialSupportedFilterKeys.SUPPORTED_MODEL in all_keys
+    is_model_type_filter = SpecialSupportedFilterKeys.MODEL_TYPE in all_keys
 
-    for model_manifest in models_manifest_list:
+    def evaluate_model(model_manifest: JumpStartModelHeader) -> Optional[Tuple[str, str]]:
 
         copied_filter = copy.deepcopy(filter)
 
@@ -324,19 +439,22 @@ def _generate_jumpstart_model_versions(  # pylint: disable=redefined-builtin
             manifest_specs_cached_values[val] = getattr(model_manifest, val)
 
         if is_task_filter:
-            manifest_specs_cached_values[
-                SpecialSupportedFilterKeys.TASK
-            ] = extract_framework_task_model(model_manifest.model_id)[1]
+            manifest_specs_cached_values[SpecialSupportedFilterKeys.TASK] = (
+                extract_framework_task_model(model_manifest.model_id)[1]
+            )
 
         if is_framework_filter:
-            manifest_specs_cached_values[
-                SpecialSupportedFilterKeys.FRAMEWORK
-            ] = extract_framework_task_model(model_manifest.model_id)[0]
+            manifest_specs_cached_values[SpecialSupportedFilterKeys.FRAMEWORK] = (
+                extract_framework_task_model(model_manifest.model_id)[0]
+            )
 
-        if is_supported_model_filter:
-            manifest_specs_cached_values[SpecialSupportedFilterKeys.SUPPORTED_MODEL] = Version(
-                model_manifest.min_version
-            ) <= Version(get_sagemaker_version())
+        if is_model_type_filter:
+            manifest_specs_cached_values[SpecialSupportedFilterKeys.MODEL_TYPE] = (
+                extract_model_type_filter_representation(model_manifest.spec_key)
+            )
+
+        if Version(model_manifest.min_version) > Version(get_sagemaker_version()):
+            return None
 
         _populate_model_filters_to_resolved_values(
             manifest_specs_cached_values,
@@ -350,29 +468,28 @@ def _generate_jumpstart_model_versions(  # pylint: disable=redefined-builtin
 
         if copied_filter.resolved_value in [BooleanValues.TRUE, BooleanValues.FALSE]:
             if copied_filter.resolved_value == BooleanValues.TRUE:
-                yield (model_manifest.model_id, model_manifest.version)
-            continue
+                return (model_manifest.model_id, model_manifest.version)
+            return None
 
         if copied_filter.resolved_value == BooleanValues.UNEVALUATED:
             raise RuntimeError(
-                "Filter expression in unevaluated state after using values from model manifest. "
-                "Model ID and version that is failing: "
-                f"{(model_manifest.model_id, model_manifest.version)}."
+                "Filter expression in unevaluated state after using "
+                "values from model manifest. Model ID and version that "
+                f"is failing: {(model_manifest.model_id, model_manifest.version)}."
             )
         copied_filter_2 = copy.deepcopy(filter)
 
-        model_specs = accessors.JumpStartModelsAccessor.get_model_specs(
-            region=region,
-            model_id=model_manifest.model_id,
-            version=model_manifest.version,
+        # spec is downloaded to thread's memory. since each thread
+        # accesses a unique s3 spec, there is no need to use the JS caching utils.
+        # spec only stays in memory for lifecycle of thread.
+        model_specs = JumpStartModelSpecs(
+            json.loads(
+                sagemaker_session.read_s3_file(
+                    get_jumpstart_content_bucket(region), model_manifest.spec_key
+                )
+            )
         )
 
-        model_specs_keys = set(model_specs.__slots__)
-
-        unrecognized_keys -= model_specs_keys
-        unrecognized_keys_for_single_spec = possible_spec_keys - model_specs_keys
-        unrecognized_keys.update(unrecognized_keys_for_single_spec)
-
         for val in possible_spec_keys:
             if hasattr(model_specs, val):
                 manifest_specs_cached_values[val] = getattr(model_specs, val)
@@ -390,8 +507,8 @@ def _generate_jumpstart_model_versions(  # pylint: disable=redefined-builtin
             if copied_filter_2.resolved_value == BooleanValues.TRUE or (
                 BooleanValues.UNKNOWN and list_incomplete_models
             ):
-                yield (model_manifest.model_id, model_manifest.version)
-            continue
+                return (model_manifest.model_id, model_manifest.version)
+            return None
 
         raise RuntimeError(
             "Filter expression in unevaluated state after using values from model specs. "
@@ -399,12 +516,26 @@ def _generate_jumpstart_model_versions(  # pylint: disable=redefined-builtin
             f"{(model_manifest.model_id, model_manifest.version)}."
         )
 
-    if len(unrecognized_keys) > 0:
-        raise RuntimeError(f"Unrecognized keys: {str(unrecognized_keys)}")
+    with ThreadPoolExecutor(max_workers=MAX_SEARCH_WORKERS) as executor:
+        futures = []
+        for header in models_manifest_list:
+            futures.append(executor.submit(evaluate_model, header))
+
+        for future in as_completed(futures):
+            error = future.exception()
+            if error:
+                raise error
+            result = future.result()
+            if result:
+                yield result
 
 
 def get_model_url(
-    model_id: str, model_version: str, region: str = JUMPSTART_DEFAULT_REGION_NAME
+    model_id: str,
+    model_version: str,
+    region: Optional[str] = None,
+    sagemaker_session: Session = DEFAULT_JUMPSTART_SAGEMAKER_SESSION,
+    config_name: Optional[str] = None,
 ) -> str:
     """Retrieve web url describing pretrained model.
 
@@ -412,10 +543,27 @@ def get_model_url(
         model_id (str): The model ID for which to retrieve the url.
         model_version (str): The model version for which to retrieve the url.
         region (str): Optional. The region from which to retrieve metadata.
-            (Default: JUMPSTART_DEFAULT_REGION_NAME)
+            (Default: None)
+        sagemaker_session (sagemaker.session.Session): Optional. The SageMaker Session to use
+            to retrieve the model url.
     """
+    model_type = validate_model_id_and_get_type(
+        model_id=model_id,
+        model_version=model_version,
+        region=region,
+        sagemaker_session=sagemaker_session,
+    )
 
-    model_specs = accessors.JumpStartModelsAccessor.get_model_specs(
-        region=region, model_id=model_id, version=model_version
+    region = region or get_region_fallback(
+        sagemaker_session=sagemaker_session,
+    )
+    model_specs = verify_model_region_and_return_specs(
+        region=region,
+        model_id=model_id,
+        version=model_version,
+        sagemaker_session=sagemaker_session,
+        scope=JumpStartScriptScope.INFERENCE,
+        model_type=model_type,
+        config_name=config_name,
     )
     return model_specs.url
