@@ -17,6 +17,8 @@ from io import BytesIO
 import zipfile
 import time
 from botocore.exceptions import ClientError
+
+from sagemaker import s3
 from sagemaker.session import Session
 
 
@@ -36,6 +38,9 @@ class Lambda:
         timeout: int = 120,
         memory_size: int = 128,
         runtime: str = "python3.8",
+        vpc_config: dict = None,
+        environment: dict = None,
+        layers: list = None,
     ):
         """Constructs a Lambda instance.
 
@@ -66,6 +71,9 @@ class Lambda:
             timeout (int): Timeout of the Lambda function in seconds. Default is 120 seconds.
             memory_size (int): Memory of the Lambda function in megabytes. Default is 128 MB.
             runtime (str): Runtime of the Lambda function. Default is set to python3.8.
+            vpc_config (dict): VPC to deploy the Lambda function to. Default is None.
+            environment (dict): Environment Variables for the Lambda function. Default is None.
+            layers (list): List of Lambda layers for the Lambda function. Default is None.
         """
         self.function_arn = function_arn
         self.function_name = function_name
@@ -78,6 +86,9 @@ class Lambda:
         self.timeout = timeout
         self.memory_size = memory_size
         self.runtime = runtime
+        self.vpc_config = vpc_config or {}
+        self.environment = environment or {}
+        self.layers = layers or []
 
         if function_arn is None and function_name is None:
             raise ValueError("Either function_arn or function_name must be provided.")
@@ -109,12 +120,15 @@ class Lambda:
         if self.script is not None:
             code = {"ZipFile": _zip_lambda_code(self.script)}
         else:
-            bucket = self.s3_bucket or self.session.default_bucket()
+            bucket, key_prefix = s3.determine_bucket_and_prefix(
+                bucket=self.s3_bucket, key_prefix=None, sagemaker_session=self.session
+            )
             key = _upload_to_s3(
                 s3_client=_get_s3_client(self.session),
                 function_name=self.function_name,
                 zipped_code_dir=self.zipped_code_dir,
                 s3_bucket=bucket,
+                s3_key_prefix=key_prefix,
             )
             code = {"S3Bucket": bucket, "S3Key": key}
 
@@ -127,6 +141,9 @@ class Lambda:
                 Code=code,
                 Timeout=self.timeout,
                 MemorySize=self.memory_size,
+                VpcConfig=self.vpc_config,
+                Environment=self.environment,
+                Layers=self.layers,
             )
             return response
         except ClientError as e:
@@ -148,7 +165,10 @@ class Lambda:
                         ZipFile=_zip_lambda_code(self.script),
                     )
                 else:
-                    bucket = self.s3_bucket or self.session.default_bucket()
+                    bucket, key_prefix = s3.determine_bucket_and_prefix(
+                        bucket=self.s3_bucket, key_prefix=None, sagemaker_session=self.session
+                    )
+
                     # get function name to be used in S3 upload path
                     if self.function_arn:
                         versioned_function_name = self.function_arn.split("funtion:")[-1]
@@ -167,6 +187,7 @@ class Lambda:
                             function_name=function_name_for_s3,
                             zipped_code_dir=self.zipped_code_dir,
                             s3_bucket=bucket,
+                            s3_key_prefix=key_prefix,
                         ),
                     )
                 return response
@@ -255,7 +276,7 @@ def _get_lambda_client(session):
     return lambda_client
 
 
-def _upload_to_s3(s3_client, function_name, zipped_code_dir, s3_bucket):
+def _upload_to_s3(s3_client, function_name, zipped_code_dir, s3_bucket, s3_key_prefix=None):
     """Upload the zipped code to S3 bucket provided in the Lambda instance.
 
     Lambda instance must have a path to the zipped code folder and a S3 bucket to upload
@@ -264,7 +285,13 @@ def _upload_to_s3(s3_client, function_name, zipped_code_dir, s3_bucket):
 
     Returns: the S3 key where the code is uploaded.
     """
-    key = "{}/{}/{}".format("lambda", function_name, "code")
+
+    key = s3.s3_path_join(
+        s3_key_prefix,
+        "lambda",
+        function_name,
+        "code",
+    )
     s3_client.upload_file(zipped_code_dir, s3_bucket, key)
     return key
 
