@@ -28,6 +28,8 @@ from sagemaker.model_card.model_card import (  # noqa: F401 # pylint: disable=un
     EvaluationJob,
     AdditionalInformation,
     ModelCard,
+    ModelPackage,
+    ModelPackageModelCard,
 )
 
 from sagemaker.model_card.schema_constraints import (  # noqa: F401 # pylint: disable=unused-import
