@@ -25,10 +25,12 @@ import uuid
 from sagemaker.model_monitor import model_monitoring as mm
 from sagemaker import image_uris, s3
 from sagemaker.session import Session
-from sagemaker.utils import name_from_base
+from sagemaker.utils import name_from_base, format_tags
 from sagemaker.clarify import SageMakerClarifyProcessor, ModelPredictedLabelConfig
+from sagemaker.lineage._utils import get_resource_name_from_arn
 
-_LOGGER = logging.getLogger(__name__)
+# Setting _LOGGER for backward compatibility, in case users import it...
+logger = _LOGGER = logging.getLogger(__name__)
 
 
 class ClarifyModelMonitor(mm.ModelMonitor):
@@ -40,7 +42,7 @@ class ClarifyModelMonitor(mm.ModelMonitor):
 
     def __init__(
         self,
-        role,
+        role=None,
         instance_count=1,
         instance_type="ml.m5.xlarge",
         volume_size_in_gb=30,
@@ -79,16 +81,14 @@ class ClarifyModelMonitor(mm.ModelMonitor):
                 AWS services needed. If not specified, one is created using
                 the default AWS configuration chain.
             env (dict): Environment variables to be passed to the job.
-            tags ([dict]): List of tags to be passed to the job.
+            tags (Optional[Tags]): List of tags to be passed to the job.
             network_config (sagemaker.network.NetworkConfig): A NetworkConfig
                 object that configures network isolation, encryption of
                 inter-container traffic, security group IDs, and subnets.
         """
-        if type(self) == __class__:  # pylint: disable=unidiomatic-typecheck
+        if self.__class__ is __class__:
             raise TypeError(
-                "{} is abstract, please instantiate its subclasses instead.".format(
-                    __class__.__name__
-                )
+                f"{__class__.__name__} is abstract, please instantiate its subclasses instead."
             )
 
         session = sagemaker_session or Session()
@@ -106,7 +106,7 @@ class ClarifyModelMonitor(mm.ModelMonitor):
             base_job_name=base_job_name,
             sagemaker_session=session,
             env=env,
-            tags=tags,
+            tags=format_tags(tags),
             network_config=network_config,
         )
         self.latest_baselining_job_config = None
@@ -154,6 +154,29 @@ class ClarifyModelMonitor(mm.ModelMonitor):
             for execution in executions
         ]
 
+    def get_latest_execution_logs(self, wait=False):
+        """Get the processing job logs for the most recent monitoring execution
+
+        Args:
+            wait (bool): Whether the call should wait until the job completes (default: False).
+
+        Raises:
+            ValueError: If no execution job or processing job for the last execution has run
+
+        Returns: None
+        """
+        monitoring_executions = self.sagemaker_session.list_monitoring_executions(
+            monitoring_schedule_name=self.monitoring_schedule_name
+        )
+        if len(monitoring_executions["MonitoringExecutionSummaries"]) == 0:
+            raise ValueError("No execution jobs were kicked off.")
+        if "ProcessingJobArn" not in monitoring_executions["MonitoringExecutionSummaries"][0]:
+            raise ValueError("Processing Job did not run for the last execution")
+        job_arn = monitoring_executions["MonitoringExecutionSummaries"][0]["ProcessingJobArn"]
+        self.sagemaker_session.logs_for_processing_job(
+            job_name=get_resource_name_from_arn(job_arn), wait=wait
+        )
+
     def _create_baselining_processor(self):
         """Create and return a SageMakerClarifyProcessor object which will run the baselining job.
 
@@ -175,9 +198,10 @@ class ClarifyModelMonitor(mm.ModelMonitor):
             network_config=self.network_config,
         )
         baselining_processor.image_uri = self.image_uri
+        baselining_processor.base_job_name = self.base_job_name
         return baselining_processor
 
-    def _upload_analysis_config(self, analysis_config, output_s3_uri, job_definition_name):
+    def _upload_analysis_config(self, analysis_config, output_s3_uri, job_definition_name, kms_key):
         """Upload analysis config to s3://<output path>/<job name>/analysis_config.json
 
         Args:
@@ -186,6 +210,8 @@ class ClarifyModelMonitor(mm.ModelMonitor):
                 Default: "s3://<default_session_bucket>/<job_name>/output"
             job_definition_name (str): Job definition name.
                 If not specified then a default one will be generated.
+            kms_key( str): The ARN of the KMS key that is used to encrypt the
+            user code file (default: None).
 
         Returns:
             str: The S3 uri of the uploaded file(s).
@@ -196,11 +222,12 @@ class ClarifyModelMonitor(mm.ModelMonitor):
             str(uuid.uuid4()),
             "analysis_config.json",
         )
-        _LOGGER.info("Uploading analysis config to {s3_uri}.")
+        logger.info("Uploading analysis config to {s3_uri}.")
         return s3.S3Uploader.upload_string_as_file_body(
             json.dumps(analysis_config),
             desired_s3_uri=s3_uri,
             sagemaker_session=self.sagemaker_session,
+            kms_key=kms_key,
         )
 
     def _build_create_job_definition_request(
@@ -267,7 +294,7 @@ class ClarifyModelMonitor(mm.ModelMonitor):
                 time, Amazon SageMaker terminates the job regardless of its current status.
                 Default: 3600
             env (dict): Environment variables to be passed to the job.
-            tags ([dict]): List of tags to be passed to the job.
+            tags (Optional[Tags]): List of tags to be passed to the job.
             network_config (sagemaker.network.NetworkConfig): A NetworkConfig
                 object that configures network isolation, encryption of
                 inter-container traffic, security group IDs, and subnets.
@@ -322,7 +349,7 @@ class ClarifyModelMonitor(mm.ModelMonitor):
             analysis_config_uri = analysis_config
         else:
             analysis_config_uri = self._upload_analysis_config(
-                analysis_config._to_dict(), output_s3_uri, job_definition_name
+                analysis_config._to_dict(), output_s3_uri, job_definition_name, output_kms_key
             )
         app_specification["ConfigUri"] = analysis_config_uri
         app_specification["ImageUri"] = image_uri
@@ -429,7 +456,7 @@ class ClarifyModelMonitor(mm.ModelMonitor):
             request_dict["StoppingCondition"] = stop_condition
 
         if tags is not None:
-            request_dict["Tags"] = tags
+            request_dict["Tags"] = format_tags(tags)
 
         return request_dict
 
@@ -533,6 +560,8 @@ class ModelBiasMonitor(ClarifyModelMonitor):
         schedule_cron_expression=None,
         enable_cloudwatch_metrics=True,
         batch_transform_input=None,
+        data_analysis_start_time=None,
+        data_analysis_end_time=None,
     ):
         """Creates a monitoring schedule.
 
@@ -558,6 +587,10 @@ class ModelBiasMonitor(ClarifyModelMonitor):
                 the baselining or monitoring jobs. (default: True)
             batch_transform_input (sagemaker.model_monitor.BatchTransformInput): Inputs to run
                 the monitoring schedule on the batch transform (default: None)
+            data_analysis_start_time (str): Start time for the data analysis window
+                for the one time monitoring schedule (NOW), e.g. "-PT1H" (default: None)
+            data_analysis_end_time (str): End time for the data analysis window
+                for the one time monitoring schedule (NOW), e.g. "-PT1H" (default: None)
         """
         # we default ground_truth_input to None in the function signature
         # but verify they are giving here for positional argument
@@ -570,7 +603,7 @@ class ModelBiasMonitor(ClarifyModelMonitor):
                 "Monitoring Schedule. To create another, first delete the existing one "
                 "using my_monitor.delete_monitoring_schedule()."
             )
-            _LOGGER.error(message)
+            logger.error(message)
             raise ValueError(message)
 
         if (batch_transform_input is not None) ^ (endpoint_input is None):
@@ -579,9 +612,15 @@ class ModelBiasMonitor(ClarifyModelMonitor):
                 "Amazon Model Monitoring Schedule. "
                 "Please provide only one of the above required inputs"
             )
-            _LOGGER.error(message)
+            logger.error(message)
             raise ValueError(message)
 
+        self._check_monitoring_schedule_cron_validity(
+            schedule_cron_expression=schedule_cron_expression,
+            data_analysis_start_time=data_analysis_start_time,
+            data_analysis_end_time=data_analysis_end_time,
+        )
+
         # create job definition
         monitor_schedule_name = self._generate_monitoring_schedule_name(
             schedule_name=monitor_schedule_name
@@ -621,11 +660,14 @@ class ModelBiasMonitor(ClarifyModelMonitor):
                 monitor_schedule_name=monitor_schedule_name,
                 job_definition_name=new_job_definition_name,
                 schedule_cron_expression=schedule_cron_expression,
+                data_analysis_start_time=data_analysis_start_time,
+                data_analysis_end_time=data_analysis_end_time,
             )
             self.job_definition_name = new_job_definition_name
             self.monitoring_schedule_name = monitor_schedule_name
         except Exception:
-            _LOGGER.exception("Failed to create monitoring schedule.")
+            logger.exception("Failed to create monitoring schedule.")
+            self.monitoring_schedule_name = None
             # noinspection PyBroadException
             try:
                 self.sagemaker_session.sagemaker_client.delete_model_bias_job_definition(
@@ -633,7 +675,7 @@ class ModelBiasMonitor(ClarifyModelMonitor):
                 )
             except Exception:  # pylint: disable=W0703
                 message = "Failed to delete job definition {}.".format(new_job_definition_name)
-                _LOGGER.exception(message)
+                logger.exception(message)
             raise
 
     # noinspection PyMethodOverriding
@@ -656,6 +698,8 @@ class ModelBiasMonitor(ClarifyModelMonitor):
         env=None,
         network_config=None,
         batch_transform_input=None,
+        data_analysis_start_time=None,
+        data_analysis_end_time=None,
     ):
         """Updates the existing monitoring schedule.
 
@@ -712,7 +756,7 @@ class ModelBiasMonitor(ClarifyModelMonitor):
                 "Amazon Model Monitoring Schedule. "
                 "Please provide only one of the above required inputs"
             )
-            _LOGGER.error(message)
+            logger.error(message)
             raise ValueError(message)
 
         # Only need to update schedule expression
@@ -750,7 +794,12 @@ class ModelBiasMonitor(ClarifyModelMonitor):
         )
         self.sagemaker_session.sagemaker_client.create_model_bias_job_definition(**request_dict)
         try:
-            self._update_monitoring_schedule(new_job_definition_name, schedule_cron_expression)
+            self._update_monitoring_schedule(
+                new_job_definition_name,
+                schedule_cron_expression,
+                data_analysis_start_time=data_analysis_start_time,
+                data_analysis_end_time=data_analysis_end_time,
+            )
             self.job_definition_name = new_job_definition_name
             if role is not None:
                 self.role = role
@@ -771,7 +820,7 @@ class ModelBiasMonitor(ClarifyModelMonitor):
             if network_config is not None:
                 self.network_config = network_config
         except Exception:
-            _LOGGER.exception("Failed to update monitoring schedule.")
+            logger.exception("Failed to update monitoring schedule.")
             # noinspection PyBroadException
             try:
                 self.sagemaker_session.sagemaker_client.delete_model_bias_job_definition(
@@ -779,7 +828,7 @@ class ModelBiasMonitor(ClarifyModelMonitor):
                 )
             except Exception:  # pylint: disable=W0703
                 message = "Failed to delete job definition {}.".format(new_job_definition_name)
-                _LOGGER.exception(message)
+                logger.exception(message)
             raise
 
     def delete_monitoring_schedule(self):
@@ -789,7 +838,7 @@ class ModelBiasMonitor(ClarifyModelMonitor):
         message = "Deleting Model Bias Job Definition with name: {}".format(
             self.job_definition_name
         )
-        _LOGGER.info(message)
+        logger.info(message)
         self.sagemaker_session.sagemaker_client.delete_model_bias_job_definition(
             JobDefinitionName=self.job_definition_name
         )
@@ -960,6 +1009,8 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
         schedule_cron_expression=None,
         enable_cloudwatch_metrics=True,
         batch_transform_input=None,
+        data_analysis_start_time=None,
+        data_analysis_end_time=None,
     ):
         """Creates a monitoring schedule.
 
@@ -983,6 +1034,10 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
                 the baselining or monitoring jobs.
             batch_transform_input (sagemaker.model_monitor.BatchTransformInput): Inputs to
             run the monitoring schedule on the batch transform
+            data_analysis_start_time (str): Start time for the data analysis window
+                for the one time monitoring schedule (NOW), e.g. "-PT1H" (default: None)
+            data_analysis_end_time (str): End time for the data analysis window
+                for the one time monitoring schedule (NOW), e.g. "-PT1H" (default: None)
         """
         if self.job_definition_name is not None or self.monitoring_schedule_name is not None:
             message = (
@@ -990,7 +1045,7 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
                 "Monitoring Schedule. To create another, first delete the existing one "
                 "using my_monitor.delete_monitoring_schedule()."
             )
-            _LOGGER.error(message)
+            logger.error(message)
             raise ValueError(message)
 
         if (batch_transform_input is not None) ^ (endpoint_input is None):
@@ -999,9 +1054,15 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
                 "Amazon Model Monitoring Schedule."
                 "Please provide only one of the above required inputs"
             )
-            _LOGGER.error(message)
+            logger.error(message)
             raise ValueError(message)
 
+        self._check_monitoring_schedule_cron_validity(
+            schedule_cron_expression=schedule_cron_expression,
+            data_analysis_start_time=data_analysis_start_time,
+            data_analysis_end_time=data_analysis_end_time,
+        )
+
         # create job definition
         monitor_schedule_name = self._generate_monitoring_schedule_name(
             schedule_name=monitor_schedule_name
@@ -1042,11 +1103,14 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
                 monitor_schedule_name=monitor_schedule_name,
                 job_definition_name=new_job_definition_name,
                 schedule_cron_expression=schedule_cron_expression,
+                data_analysis_start_time=data_analysis_start_time,
+                data_analysis_end_time=data_analysis_end_time,
             )
             self.job_definition_name = new_job_definition_name
             self.monitoring_schedule_name = monitor_schedule_name
         except Exception:
-            _LOGGER.exception("Failed to create monitoring schedule.")
+            logger.exception("Failed to create monitoring schedule.")
+            self.monitoring_schedule_name = None
             # noinspection PyBroadException
             try:
                 self.sagemaker_session.sagemaker_client.delete_model_explainability_job_definition(
@@ -1054,7 +1118,7 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
                 )
             except Exception:  # pylint: disable=W0703
                 message = "Failed to delete job definition {}.".format(new_job_definition_name)
-                _LOGGER.exception(message)
+                logger.exception(message)
             raise
 
     # noinspection PyMethodOverriding
@@ -1076,6 +1140,8 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
         env=None,
         network_config=None,
         batch_transform_input=None,
+        data_analysis_start_time=None,
+        data_analysis_end_time=None,
     ):
         """Updates the existing monitoring schedule.
 
@@ -1116,6 +1182,10 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
                 inter-container traffic, security group IDs, and subnets.
             batch_transform_input (sagemaker.model_monitor.BatchTransformInput): Inputs to
                 run the monitoring schedule on the batch transform
+            data_analysis_start_time (str): Start time for the data analysis window
+                for the one time monitoring schedule (NOW), e.g. "-PT1H" (default: None)
+            data_analysis_end_time (str): End time for the data analysis window
+                for the one time monitoring schedule (NOW), e.g. "-PT1H" (default: None)
         """
         valid_args = {
             arg: value for arg, value in locals().items() if arg != "self" and value is not None
@@ -1131,7 +1201,7 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
                 "Amazon Model Monitoring Schedule. "
                 "Please provide only one of the above required inputs"
             )
-            _LOGGER.error(message)
+            logger.error(message)
             raise ValueError(message)
 
         # Only need to update schedule expression
@@ -1172,7 +1242,12 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
             **request_dict
         )
         try:
-            self._update_monitoring_schedule(new_job_definition_name, schedule_cron_expression)
+            self._update_monitoring_schedule(
+                new_job_definition_name,
+                schedule_cron_expression,
+                data_analysis_start_time=data_analysis_start_time,
+                data_analysis_end_time=data_analysis_end_time,
+            )
             self.job_definition_name = new_job_definition_name
             if role is not None:
                 self.role = role
@@ -1193,7 +1268,7 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
             if network_config is not None:
                 self.network_config = network_config
         except Exception:
-            _LOGGER.exception("Failed to update monitoring schedule.")
+            logger.exception("Failed to update monitoring schedule.")
             # noinspection PyBroadException
             try:
                 self.sagemaker_session.sagemaker_client.delete_model_explainability_job_definition(
@@ -1201,7 +1276,7 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
                 )
             except Exception:  # pylint: disable=W0703
                 message = "Failed to delete job definition {}.".format(new_job_definition_name)
-                _LOGGER.exception(message)
+                logger.exception(message)
             raise
 
     def delete_monitoring_schedule(self):
@@ -1211,7 +1286,7 @@ class ModelExplainabilityMonitor(ClarifyModelMonitor):
         message = "Deleting Model Explainability Job Definition with name: {}".format(
             self.job_definition_name
         )
-        _LOGGER.info(message)
+        logger.info(message)
         self.sagemaker_session.sagemaker_client.delete_model_explainability_job_definition(
             JobDefinitionName=self.job_definition_name
         )
