@@ -23,7 +23,7 @@ from sagemaker import local, s3
 from sagemaker.deprecations import removed_kwargs
 from sagemaker.model import Model
 from sagemaker.session import Session
-from sagemaker.utils import pop_out_unused_kwarg
+from sagemaker.utils import pop_out_unused_kwarg, format_tags
 from sagemaker.workflow.entities import PipelineVariable
 
 MULTI_MODEL_CONTAINER_MODE = "MultiModel"
@@ -99,6 +99,7 @@ class MultiDataModel(Model):
         self.model = model
         self.container_mode = MULTI_MODEL_CONTAINER_MODE
         self.sagemaker_session = sagemaker_session or Session()
+        self.endpoint_name = None
 
         if self.sagemaker_session.s3_client is None:
             self.s3_client = self.sagemaker_session.boto_session.client(
@@ -120,7 +121,12 @@ class MultiDataModel(Model):
             )
 
     def prepare_container_def(
-        self, instance_type=None, accelerator_type=None, serverless_inference_config=None
+        self,
+        instance_type=None,
+        accelerator_type=None,
+        serverless_inference_config=None,
+        accept_eula=None,
+        model_reference_arn=None,
     ):
         """Return a container definition set.
 
@@ -148,6 +154,8 @@ class MultiDataModel(Model):
             env=environment,
             model_data_url=self.model_data_prefix,
             container_mode=self.container_mode,
+            accept_eula=accept_eula,
+            model_reference_arn=model_reference_arn,
         )
 
     def deploy(
@@ -215,7 +223,7 @@ class MultiDataModel(Model):
                 Amazon SageMaker Model Monitoring. Default: None.
 
         Returns:
-            callable[string, sagemaker.session.Session] or None: Invocation of
+            Optional[Callable[[string, sagemaker.session.Session], Any]]: Invocation of
                 ``self.predictor_cls`` on the created endpoint name,
                 if ``self.predictor_cls``
                 is not None. Otherwise, return None.
@@ -239,6 +247,8 @@ class MultiDataModel(Model):
         if instance_type == "local" and not isinstance(self.sagemaker_session, local.LocalSession):
             self.sagemaker_session = local.LocalSession()
 
+        tags = format_tags(tags)
+
         container_def = self.prepare_container_def(instance_type, accelerator_type=accelerator_type)
         self.sagemaker_session.create_model(
             self.name,
