@@ -17,37 +17,51 @@ data pre-processing, post-processing, feature engineering, data validation, and
 and interpretation on Amazon SageMaker.
 """
 from __future__ import absolute_import
-
+import logging
 import os
 import pathlib
-import logging
+import re
+from copy import copy
 from textwrap import dedent
 from typing import Dict, List, Optional, Union
-from copy import copy
 
 import attr
-
 from six.moves.urllib.parse import urlparse
 from six.moves.urllib.request import url2pathname
+
 from sagemaker import s3
+from sagemaker.apiutils._base_types import ApiObject
+from sagemaker.config import (
+    PROCESSING_JOB_ENABLE_NETWORK_ISOLATION_PATH,
+    PROCESSING_JOB_ENVIRONMENT_PATH,
+    PROCESSING_JOB_INTER_CONTAINER_ENCRYPTION_PATH,
+    PROCESSING_JOB_KMS_KEY_ID_PATH,
+    PROCESSING_JOB_ROLE_ARN_PATH,
+    PROCESSING_JOB_SECURITY_GROUP_IDS_PATH,
+    PROCESSING_JOB_SUBNETS_PATH,
+    PROCESSING_JOB_VOLUME_KMS_KEY_ID_PATH,
+)
+from sagemaker.dataset_definition.inputs import DatasetDefinition, S3Input
 from sagemaker.job import _Job
 from sagemaker.local import LocalSession
 from sagemaker.network import NetworkConfig
+from sagemaker.s3 import S3Uploader
+from sagemaker.session import Session
 from sagemaker.utils import (
+    Tags,
     base_name_from_image,
+    check_and_get_run_experiment_config,
+    format_tags,
     get_config_value,
     name_from_base,
-    check_and_get_run_experiment_config,
+    resolve_class_attribute_from_config,
+    resolve_value_from_config,
 )
-from sagemaker.session import Session
 from sagemaker.workflow import is_pipeline_variable
+from sagemaker.workflow.entities import PipelineVariable
+from sagemaker.workflow.execution_variables import ExecutionVariables
 from sagemaker.workflow.functions import Join
 from sagemaker.workflow.pipeline_context import runnable_by_pipeline
-from sagemaker.workflow.execution_variables import ExecutionVariables
-from sagemaker.workflow.entities import PipelineVariable
-from sagemaker.dataset_definition.inputs import S3Input, DatasetDefinition
-from sagemaker.apiutils._base_types import ApiObject
-from sagemaker.s3 import S3Uploader
 
 logger = logging.getLogger(__name__)
 
@@ -59,10 +73,10 @@ class Processor(object):
 
     def __init__(
         self,
-        role: Union[str, PipelineVariable],
-        image_uri: Union[str, PipelineVariable],
-        instance_count: Union[int, PipelineVariable],
-        instance_type: Union[str, PipelineVariable],
+        role: str = None,
+        image_uri: Union[str, PipelineVariable] = None,
+        instance_count: Union[int, PipelineVariable] = None,
+        instance_type: Union[str, PipelineVariable] = None,
         entrypoint: Optional[List[Union[str, PipelineVariable]]] = None,
         volume_size_in_gb: Union[int, PipelineVariable] = 30,
         volume_kms_key: Optional[Union[str, PipelineVariable]] = None,
@@ -71,7 +85,7 @@ class Processor(object):
         base_job_name: Optional[str] = None,
         sagemaker_session: Optional[Session] = None,
         env: Optional[Dict[str, Union[str, PipelineVariable]]] = None,
-        tags: Optional[List[Dict[str, Union[str, PipelineVariable]]]] = None,
+        tags: Optional[Tags] = None,
         network_config: Optional[NetworkConfig] = None,
     ):
         """Initializes a ``Processor`` instance.
@@ -110,27 +124,21 @@ class Processor(object):
                 one using the default AWS configuration chain.
             env (dict[str, str] or dict[str, PipelineVariable]): Environment variables
                 to be passed to the processing jobs (default: None).
-            tags (list[dict[str, str] or list[dict[str, PipelineVariable]]): List of tags
-                to be passed to the processing job (default: None). For more, see
-                https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html.
+            tags (Optional[Tags]): Tags to be passed to the processing job (default: None).
+                For more, see https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html.
             network_config (:class:`~sagemaker.network.NetworkConfig`):
                 A :class:`~sagemaker.network.NetworkConfig`
                 object that configures network isolation, encryption of
                 inter-container traffic, security group IDs, and subnets.
         """
-        self.role = role
         self.image_uri = image_uri
         self.instance_count = instance_count
         self.instance_type = instance_type
         self.entrypoint = entrypoint
         self.volume_size_in_gb = volume_size_in_gb
-        self.volume_kms_key = volume_kms_key
-        self.output_kms_key = output_kms_key
         self.max_runtime_in_seconds = max_runtime_in_seconds
         self.base_job_name = base_job_name
-        self.env = env
-        self.tags = tags
-        self.network_config = network_config
+        self.tags = format_tags(tags)
 
         self.jobs = []
         self.latest_job = None
@@ -143,6 +151,55 @@ class Processor(object):
                 sagemaker_session = LocalSession(disable_local_code=True)
 
         self.sagemaker_session = sagemaker_session or Session()
+        self.output_kms_key = resolve_value_from_config(
+            output_kms_key, PROCESSING_JOB_KMS_KEY_ID_PATH, sagemaker_session=self.sagemaker_session
+        )
+        self.volume_kms_key = resolve_value_from_config(
+            volume_kms_key,
+            PROCESSING_JOB_VOLUME_KMS_KEY_ID_PATH,
+            sagemaker_session=self.sagemaker_session,
+        )
+        self.network_config = resolve_class_attribute_from_config(
+            NetworkConfig,
+            network_config,
+            "subnets",
+            PROCESSING_JOB_SUBNETS_PATH,
+            sagemaker_session=self.sagemaker_session,
+        )
+        self.network_config = resolve_class_attribute_from_config(
+            NetworkConfig,
+            self.network_config,
+            "security_group_ids",
+            PROCESSING_JOB_SECURITY_GROUP_IDS_PATH,
+            sagemaker_session=self.sagemaker_session,
+        )
+        self.network_config = resolve_class_attribute_from_config(
+            NetworkConfig,
+            self.network_config,
+            "enable_network_isolation",
+            PROCESSING_JOB_ENABLE_NETWORK_ISOLATION_PATH,
+            sagemaker_session=self.sagemaker_session,
+        )
+        self.network_config = resolve_class_attribute_from_config(
+            NetworkConfig,
+            self.network_config,
+            "encrypt_inter_container_traffic",
+            PROCESSING_JOB_INTER_CONTAINER_ENCRYPTION_PATH,
+            sagemaker_session=self.sagemaker_session,
+        )
+        self.role = resolve_value_from_config(
+            role, PROCESSING_JOB_ROLE_ARN_PATH, sagemaker_session=self.sagemaker_session
+        )
+        if not self.role:
+            # Originally IAM role was a required parameter.
+            # Now we marked that as Optional because we can fetch it from SageMakerConfig
+            # Because of marking that parameter as optional, we should validate if it is None, even
+            # after fetching the config.
+            raise ValueError("An AWS IAM role is required to create a Processing job.")
+
+        self.env = resolve_value_from_config(
+            env, PROCESSING_JOB_ENVIRONMENT_PATH, sagemaker_session=self.sagemaker_session
+        )
 
     @runnable_by_pipeline
     def run(
@@ -350,6 +407,7 @@ class Processor(object):
                         desired_s3_uri = s3.s3_path_join(
                             "s3://",
                             self.sagemaker_session.default_bucket(),
+                            self.sagemaker_session.default_bucket_prefix,
                             _pipeline_config.pipeline_name,
                             _pipeline_config.step_name,
                             "input",
@@ -359,6 +417,7 @@ class Processor(object):
                         desired_s3_uri = s3.s3_path_join(
                             "s3://",
                             self.sagemaker_session.default_bucket(),
+                            self.sagemaker_session.default_bucket_prefix,
                             self._current_job_name,
                             "input",
                             file_input.input_name,
@@ -413,6 +472,12 @@ class Processor(object):
                             values=[
                                 "s3:/",
                                 self.sagemaker_session.default_bucket(),
+                                *(
+                                    # don't include default_bucket_prefix if it is None or ""
+                                    [self.sagemaker_session.default_bucket_prefix]
+                                    if self.sagemaker_session.default_bucket_prefix
+                                    else []
+                                ),
                                 _pipeline_config.pipeline_name,
                                 ExecutionVariables.PIPELINE_EXECUTION_ID,
                                 _pipeline_config.step_name,
@@ -424,6 +489,7 @@ class Processor(object):
                         s3_uri = s3.s3_path_join(
                             "s3://",
                             self.sagemaker_session.default_bucket(),
+                            self.sagemaker_session.default_bucket_prefix,
                             self._current_job_name,
                             "output",
                             output.output_name,
@@ -438,11 +504,11 @@ class ScriptProcessor(Processor):
 
     def __init__(
         self,
-        role: Union[str, PipelineVariable],
-        image_uri: Union[str, PipelineVariable],
-        command: List[str],
-        instance_count: Union[int, PipelineVariable],
-        instance_type: Union[str, PipelineVariable],
+        role: Optional[Union[str, PipelineVariable]] = None,
+        image_uri: Union[str, PipelineVariable] = None,
+        command: List[str] = None,
+        instance_count: Union[int, PipelineVariable] = None,
+        instance_type: Union[str, PipelineVariable] = None,
         volume_size_in_gb: Union[int, PipelineVariable] = 30,
         volume_kms_key: Optional[Union[str, PipelineVariable]] = None,
         output_kms_key: Optional[Union[str, PipelineVariable]] = None,
@@ -450,7 +516,7 @@ class ScriptProcessor(Processor):
         base_job_name: Optional[str] = None,
         sagemaker_session: Optional[Session] = None,
         env: Optional[Dict[str, Union[str, PipelineVariable]]] = None,
-        tags: Optional[List[Dict[str, Union[str, PipelineVariable]]]] = None,
+        tags: Optional[Tags] = None,
         network_config: Optional[NetworkConfig] = None,
     ):
         """Initializes a ``ScriptProcessor`` instance.
@@ -490,9 +556,8 @@ class ScriptProcessor(Processor):
                 one using the default AWS configuration chain.
             env (dict[str, str] or dict[str, PipelineVariable])): Environment variables to
                 be passed to the processing jobs (default: None).
-            tags (list[dict[str, str] or list[dict[str, PipelineVariable]]): List of tags to
-                be passed to the processing job (default: None). For more, see
-                https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html.
+            tags (Optional[Tags]): Tags to be passed to the processing job (default: None).
+                For more, see https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html.
             network_config (:class:`~sagemaker.network.NetworkConfig`):
                 A :class:`~sagemaker.network.NetworkConfig`
                 object that configures network isolation, encryption of
@@ -514,7 +579,7 @@ class ScriptProcessor(Processor):
             base_job_name=base_job_name,
             sagemaker_session=sagemaker_session,
             env=env,
-            tags=tags,
+            tags=format_tags(tags),
             network_config=network_config,
         )
 
@@ -728,6 +793,7 @@ class ScriptProcessor(Processor):
             desired_s3_uri = s3.s3_path_join(
                 "s3://",
                 self.sagemaker_session.default_bucket(),
+                self.sagemaker_session.default_bucket_prefix,
                 _pipeline_config.pipeline_name,
                 self._CODE_CONTAINER_INPUT_NAME,
                 _pipeline_config.code_hash,
@@ -736,6 +802,7 @@ class ScriptProcessor(Processor):
             desired_s3_uri = s3.s3_path_join(
                 "s3://",
                 self.sagemaker_session.default_bucket(),
+                self.sagemaker_session.default_bucket_prefix,
                 self._current_job_name,
                 "input",
                 self._CODE_CONTAINER_INPUT_NAME,
@@ -1175,7 +1242,7 @@ class ProcessingInput(object):
             input_name (str or PipelineVariable): The name for the input. If a name
                 is not provided, one will be generated (eg. "input-1").
             s3_data_type (str or PipelineVariable): Valid options are "ManifestFile" or "S3Prefix".
-            s3_input_mode (str or PipelineVariable): Valid options are "Pipe" or "File".
+            s3_input_mode (str or PipelineVariable): Valid options are "Pipe", "File" or "FastFile".
             s3_data_distribution_type (str or PipelineVariable): Valid options are "FullyReplicated"
                 or "ShardedByS3Key".
             s3_compression_type (str or PipelineVariable): Valid options are "None" or "Gzip".
@@ -1348,7 +1415,7 @@ class RunArgs(object):
 class FeatureStoreOutput(ApiObject):
     """Configuration for processing job outputs in Amazon SageMaker Feature Store."""
 
-    feature_group_name = None
+    feature_group_name: Optional[str] = None
 
 
 class FrameworkProcessor(ScriptProcessor):
@@ -1361,9 +1428,9 @@ class FrameworkProcessor(ScriptProcessor):
         self,
         estimator_cls: type,
         framework_version: str,
-        role: Union[str, PipelineVariable],
-        instance_count: Union[int, PipelineVariable],
-        instance_type: Union[str, PipelineVariable],
+        role: Optional[Union[str, PipelineVariable]] = None,
+        instance_count: Union[int, PipelineVariable] = None,
+        instance_type: Union[str, PipelineVariable] = None,
         py_version: str = "py3",
         image_uri: Optional[Union[str, PipelineVariable]] = None,
         command: Optional[List[str]] = None,
@@ -1375,7 +1442,7 @@ class FrameworkProcessor(ScriptProcessor):
         base_job_name: Optional[str] = None,
         sagemaker_session: Optional[Session] = None,
         env: Optional[Dict[str, Union[str, PipelineVariable]]] = None,
-        tags: Optional[List[Dict[str, Union[str, PipelineVariable]]]] = None,
+        tags: Optional[Tags] = None,
         network_config: Optional[NetworkConfig] = None,
     ):
         """Initializes a ``FrameworkProcessor`` instance.
@@ -1397,7 +1464,7 @@ class FrameworkProcessor(ScriptProcessor):
             instance_type (str or PipelineVariable): The type of EC2 instance to use for
                 processing, for example, 'ml.c4.xlarge'.
             py_version (str): Python version you want to use for executing your
-                model training code. One of 'py2' or 'py3'. Defaults to 'py3'. Value
+                model training code. Ex `py38, py39, py310, py311`. Value
                 is ignored when ``image_uri`` is provided.
             image_uri (str or PipelineVariable): The URI of the Docker image to use for the
                 processing jobs (default: None).
@@ -1427,9 +1494,8 @@ class FrameworkProcessor(ScriptProcessor):
                 one using the default AWS configuration chain (default: None).
             env (dict[str, str] or dict[str, PipelineVariable]): Environment variables to
                 be passed to the processing jobs (default: None).
-            tags (list[dict[str, str] or list[dict[str, PipelineVariable]]): List of tags to
-                be passed to the processing job (default: None). For more, see
-                https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html.
+            tags (Optional[Tags]): Tags to be passed to the processing job (default: None).
+                For more, see https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html.
             network_config (:class:`~sagemaker.network.NetworkConfig`):
                 A :class:`~sagemaker.network.NetworkConfig`
                 object that configures network isolation, encryption of
@@ -1464,7 +1530,7 @@ class FrameworkProcessor(ScriptProcessor):
             base_job_name=base_job_name,
             sagemaker_session=sagemaker_session,
             env=env,
-            tags=tags,
+            tags=format_tags(tags),
             network_config=network_config,
         )
 
@@ -1514,6 +1580,7 @@ class FrameworkProcessor(ScriptProcessor):
             sagemaker_session=self.sagemaker_session,
             debugger_hook_config=False,
             disable_profiler=True,
+            output_kms_key=self.output_kms_key,
         )
 
     def get_run_args(
@@ -1591,6 +1658,7 @@ class FrameworkProcessor(ScriptProcessor):
         job_name: Optional[str] = None,
         experiment_config: Optional[Dict[str, str]] = None,
         kms_key: Optional[str] = None,
+        codeartifact_repo_arn: Optional[str] = None,
     ):
         """Runs a processing job.
 
@@ -1691,12 +1759,21 @@ class FrameworkProcessor(ScriptProcessor):
                 However, the value of `TrialComponentDisplayName` is honored for display in Studio.
             kms_key (str): The ARN of the KMS key that is used to encrypt the
                 user code file (default: None).
+            codeartifact_repo_arn (str): The ARN of the CodeArtifact repository that should be
+                logged into before installing dependencies (default: None).
         Returns:
             None or pipeline step arguments in case the Processor instance is built with
             :class:`~sagemaker.workflow.pipeline_context.PipelineSession`
         """
         s3_runproc_sh, inputs, job_name = self._pack_and_upload_code(
-            code, source_dir, dependencies, git_config, job_name, inputs, kms_key
+            code,
+            source_dir,
+            dependencies,
+            git_config,
+            job_name,
+            inputs,
+            kms_key,
+            codeartifact_repo_arn,
         )
 
         # Submit a processing job.
@@ -1713,7 +1790,15 @@ class FrameworkProcessor(ScriptProcessor):
         )
 
     def _pack_and_upload_code(
-        self, code, source_dir, dependencies, git_config, job_name, inputs, kms_key=None
+        self,
+        code,
+        source_dir,
+        dependencies,
+        git_config,
+        job_name,
+        inputs,
+        kms_key=None,
+        codeartifact_repo_arn=None,
     ):
         """Pack local code bundle and upload to Amazon S3."""
         if code.startswith("s3://"):
@@ -1752,11 +1837,55 @@ class FrameworkProcessor(ScriptProcessor):
             raise RuntimeError("S3 source_dir file must be named `sourcedir.tar.gz.`")
 
         script = estimator.uploaded_code.script_name
-        s3_runproc_sh = self._create_and_upload_runproc(script, kms_key, entrypoint_s3_uri)
+        evaluated_kms_key = kms_key if kms_key else self.output_kms_key
+        s3_runproc_sh = self._create_and_upload_runproc(
+            script, evaluated_kms_key, entrypoint_s3_uri, codeartifact_repo_arn
+        )
 
         return s3_runproc_sh, inputs, job_name
 
-    def _generate_framework_script(self, user_script: str) -> str:
+    def _get_codeartifact_command(self, codeartifact_repo_arn: str) -> str:
+        """Build an AWS CLI CodeArtifact command to configure pip.
+
+        The codeartifact_repo_arn property must follow the form
+        # `arn:${Partition}:codeartifact:${Region}:${Account}:repository/${Domain}/${Repository}`
+        https://docs.aws.amazon.com/codeartifact/latest/ug/python-configure-pip.html
+        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodeartifact.html#awscodeartifact-resources-for-iam-policies
+
+        Args:
+            codeartifact_repo_arn: arn of the codeartifact repository
+        Returns:
+            codeartifact command string
+        """
+
+        arn_regex = (
+            "arn:(?P<partition>[^:]+):codeartifact:(?P<region>[^:]+):(?P<account>[^:]+)"
+            ":repository/(?P<domain>[^/]+)/(?P<repository>.+)"
+        )
+        m = re.match(arn_regex, codeartifact_repo_arn)
+        if not m:
+            raise ValueError("invalid CodeArtifact repository arn {}".format(codeartifact_repo_arn))
+        domain = m.group("domain")
+        owner = m.group("account")
+        repository = m.group("repository")
+        region = m.group("region")
+
+        logger.info(
+            "configuring pip to use codeartifact "
+            "(domain: %s, domain owner: %s, repository: %s, region: %s)",
+            domain,
+            owner,
+            repository,
+            region,
+        )
+
+        return "aws codeartifact login --tool pip --domain {} --domain-owner {} --repository {} --region {}".format(  # noqa: E501 pylint: disable=line-too-long
+            domain, owner, repository, region
+        )
+
+    def _generate_framework_script(
+        self, user_script: str, codeartifact_repo_arn: str = None
+    ) -> str:
         """Generate the framework entrypoint file (as text) for a processing job.
 
         This script implements the "framework" functionality for setting up your code:
@@ -1767,7 +1896,16 @@ class FrameworkProcessor(ScriptProcessor):
         Args:
             user_script (str): Relative path to ```code``` in the source bundle
                 - e.g. 'process.py'.
+            codeartifact_repo_arn (str): The ARN of the CodeArtifact repository that should be
+                logged into before installing dependencies (default: None).
         """
+        if codeartifact_repo_arn:
+            codeartifact_login_command = self._get_codeartifact_command(codeartifact_repo_arn)
+        else:
+            codeartifact_login_command = (
+                "echo 'CodeArtifact repository not specified. Skipping login.'"
+            )
+
         return dedent(
             """\
             #!/bin/bash
@@ -1779,6 +1917,13 @@ class FrameworkProcessor(ScriptProcessor):
             set -e
 
             if [[ -f 'requirements.txt' ]]; then
+                # Optionally log into CodeArtifact
+                if ! hash aws 2>/dev/null; then
+                    echo "AWS CLI is not installed. Skipping CodeArtifact login."
+                else
+                    {codeartifact_login_command}
+                fi
+
                 # Some py3 containers has typing, which may breaks pip install
                 pip uninstall --yes typing
 
@@ -1788,6 +1933,7 @@ class FrameworkProcessor(ScriptProcessor):
             {entry_point_command} {entry_point} "$@"
         """
         ).format(
+            codeartifact_login_command=codeartifact_login_command,
             entry_point_command=" ".join(self.command),
             entry_point=user_script,
         )
@@ -1863,7 +2009,9 @@ class FrameworkProcessor(ScriptProcessor):
         )
         self.entrypoint = self.framework_entrypoint_command + [user_script_location]
 
-    def _create_and_upload_runproc(self, user_script, kms_key, entrypoint_s3_uri):
+    def _create_and_upload_runproc(
+        self, user_script, kms_key, entrypoint_s3_uri, codeartifact_repo_arn=None
+    ):
         """Create runproc shell script and upload to S3 bucket.
 
         If leveraging a pipeline session with optimized S3 artifact paths,
@@ -1879,11 +2027,16 @@ class FrameworkProcessor(ScriptProcessor):
         from sagemaker.workflow.utilities import _pipeline_config, hash_object
 
         if _pipeline_config and _pipeline_config.pipeline_name:
-            runproc_file_str = self._generate_framework_script(user_script)
+            runproc_file_str = self._generate_framework_script(user_script, codeartifact_repo_arn)
             runproc_file_hash = hash_object(runproc_file_str)
-            s3_uri = (
-                f"s3://{self.sagemaker_session.default_bucket()}/{_pipeline_config.pipeline_name}/"
-                f"code/{runproc_file_hash}/runproc.sh"
+            s3_uri = s3.s3_path_join(
+                "s3://",
+                self.sagemaker_session.default_bucket(),
+                self.sagemaker_session.default_bucket_prefix,
+                _pipeline_config.pipeline_name,
+                "code",
+                runproc_file_hash,
+                "runproc.sh",
             )
             s3_runproc_sh = S3Uploader.upload_string_as_file_body(
                 runproc_file_str,
@@ -1893,7 +2046,7 @@ class FrameworkProcessor(ScriptProcessor):
             )
         else:
             s3_runproc_sh = S3Uploader.upload_string_as_file_body(
-                self._generate_framework_script(user_script),
+                self._generate_framework_script(user_script, codeartifact_repo_arn),
                 desired_s3_uri=entrypoint_s3_uri,
                 kms_key=kms_key,
                 sagemaker_session=self.sagemaker_session,
