@@ -34,13 +34,14 @@ from copy import copy
 
 from typing import Union, List, Dict, Optional
 
-from sagemaker import image_uris
+from sagemaker import image_uris, s3
 from sagemaker.local.image import _ecr_login_if_needed, _pull_image
 from sagemaker.processing import ProcessingInput, ProcessingOutput, ScriptProcessor
 from sagemaker.s3 import S3Uploader
 from sagemaker.session import Session
 from sagemaker.network import NetworkConfig
 from sagemaker.spark import defaults
+from sagemaker.utils import format_tags, Tags
 
 from sagemaker.workflow import is_pipeline_variable
 from sagemaker.workflow.pipeline_context import runnable_by_pipeline
@@ -60,24 +61,6 @@ class _SparkProcessorBase(ScriptProcessor):
     _conf_container_base_path = "/opt/ml/processing/input/"
     _conf_container_input_name = "conf"
     _conf_file_name = "configuration.json"
-    _valid_configuration_keys = ["Classification", "Properties", "Configurations"]
-    _valid_configuration_classifications = [
-        "core-site",
-        "hadoop-env",
-        "hadoop-log4j",
-        "hive-env",
-        "hive-log4j",
-        "hive-exec-log4j",
-        "hive-site",
-        "spark-defaults",
-        "spark-env",
-        "spark-log4j",
-        "spark-hive-site",
-        "spark-metrics",
-        "yarn-env",
-        "yarn-site",
-        "export",
-    ]
 
     _submit_jars_input_channel_name = "jars"
     _submit_files_input_channel_name = "files"
@@ -94,9 +77,9 @@ class _SparkProcessorBase(ScriptProcessor):
 
     def __init__(
         self,
-        role,
-        instance_type,
-        instance_count,
+        role=None,
+        instance_type=None,
+        instance_count=None,
         framework_version=None,
         py_version=None,
         container_version=None,
@@ -104,6 +87,8 @@ class _SparkProcessorBase(ScriptProcessor):
         volume_size_in_gb=30,
         volume_kms_key=None,
         output_kms_key=None,
+        configuration_location: Optional[str] = None,
+        dependency_location: Optional[str] = None,
         max_runtime_in_seconds=None,
         base_job_name=None,
         sagemaker_session=None,
@@ -120,11 +105,11 @@ class _SparkProcessorBase(ScriptProcessor):
             framework_version (str): The version of SageMaker PySpark.
             py_version (str): The version of python.
             container_version (str): The version of spark container.
-            role (str): An AWS IAM role name or ARN. The Amazon SageMaker training jobs
-                and APIs that create Amazon SageMaker endpoints use this role
-                to access training data and model artifacts. After the endpoint
-                is created, the inference code might use the IAM role, if it
-                needs to access an AWS resource.
+            role (str): An AWS IAM role name or ARN. Amazon SageMaker Processing
+                uses this role to access AWS resources, such as
+                data stored in Amazon S3 (default: None).
+                If not specified, the value from the defaults configuration file
+                will be used.
             instance_type (str): Type of EC2 instance to use for
                 processing, for example, 'ml.c4.xlarge'.
             instance_count (int): The number of instances to run
@@ -134,6 +119,12 @@ class _SparkProcessorBase(ScriptProcessor):
             volume_kms_key (str): A KMS key for the processing
                 volume.
             output_kms_key (str): The KMS key id for all ProcessingOutputs.
+            configuration_location (str): The S3 prefix URI where the user-provided EMR
+                application configuration will be uploaded (default: None). If not specified,
+                the default ``configuration location`` is 's3://{sagemaker-default-bucket}'.
+            dependency_location (str): The S3 prefix URI where Spark dependencies will be
+                uploaded (default: None). If not specified, the default ``dependency location``
+                is 's3://{sagemaker-default-bucket}'.
             max_runtime_in_seconds (int): Timeout in seconds.
                 After this amount of time Amazon SageMaker terminates the job
                 regardless of its current status.
@@ -145,11 +136,13 @@ class _SparkProcessorBase(ScriptProcessor):
                 SageMaker APIs and any other AWS services needed. If not specified,
                 the processor creates one using the default AWS configuration chain.
             env (dict): Environment variables to be passed to the processing job.
-            tags ([dict]): List of tags to be passed to the processing job.
+            tags (Optional[Tags]): List of tags to be passed to the processing job.
             network_config (sagemaker.network.NetworkConfig): A NetworkConfig
                 object that configures network isolation, encryption of
                 inter-container traffic, security group IDs, and subnets.
         """
+        self.configuration_location = configuration_location
+        self.dependency_location = dependency_location
         self.history_server = None
         self._spark_event_logs_s3_uri = None
 
@@ -176,7 +169,7 @@ class _SparkProcessorBase(ScriptProcessor):
             base_job_name=base_job_name,
             sagemaker_session=session,
             env=env,
-            tags=tags,
+            tags=format_tags(tags),
             network_config=network_config,
         )
 
@@ -286,7 +279,7 @@ class _SparkProcessorBase(ScriptProcessor):
 
         if kwargs.get("spark_event_logs_s3_uri"):
             spark_event_logs_s3_uri = kwargs.get("spark_event_logs_s3_uri")
-            self._validate_s3_uri(spark_event_logs_s3_uri)
+            SparkConfigUtils.validate_s3_uri(spark_event_logs_s3_uri)
 
             self._spark_event_logs_s3_uri = spark_event_logs_s3_uri
             self.command.extend(
@@ -310,7 +303,7 @@ class _SparkProcessorBase(ScriptProcessor):
 
         if kwargs.get("configuration"):
             configuration = kwargs.get("configuration")
-            self._validate_configuration(configuration)
+            SparkConfigUtils.validate_configuration(configuration)
             extended_inputs.append(self._stage_configuration(configuration))
 
         return (
@@ -367,42 +360,6 @@ class _SparkProcessorBase(ScriptProcessor):
 
         return image_uri
 
-    def _validate_configuration(self, configuration):
-        """Validates the user-provided Hadoop/Spark/Hive configuration.
-
-        This ensures that the list or dictionary the user provides will serialize to
-        JSON matching the schema of EMR's application configuration:
-
-        https://docs.aws.amazon.com/emr/latest/ReleaseGuide/emr-configure-apps.html
-        """
-        emr_configure_apps_url = (
-            "https://docs.aws.amazon.com/emr/latest/ReleaseGuide/emr-configure-apps.html"
-        )
-        if isinstance(configuration, dict):
-            keys = configuration.keys()
-            if "Classification" not in keys or "Properties" not in keys:
-                raise ValueError(
-                    f"Missing one or more required keys in configuration dictionary "
-                    f"{configuration} Please see {emr_configure_apps_url} for more information"
-                )
-
-            for key in keys:
-                if key not in self._valid_configuration_keys:
-                    raise ValueError(
-                        f"Invalid key: {key}. Must be one of {self._valid_configuration_keys}. "
-                        f"Please see {emr_configure_apps_url} for more information."
-                    )
-                if key == "Classification":
-                    if configuration[key] not in self._valid_configuration_classifications:
-                        raise ValueError(
-                            f"Invalid classification: {key}. Must be one of "
-                            f"{self._valid_configuration_classifications}"
-                        )
-
-        if isinstance(configuration, list):
-            for item in configuration:
-                self._validate_configuration(item)
-
     def _stage_configuration(self, configuration):
         """Serializes and uploads the user-provided EMR application configuration to S3.
 
@@ -413,19 +370,31 @@ class _SparkProcessorBase(ScriptProcessor):
         """
         from sagemaker.workflow.utilities import _pipeline_config
 
+        if self.configuration_location:
+            if self.configuration_location.endswith("/"):
+                s3_prefix_uri = self.configuration_location[:-1]
+            else:
+                s3_prefix_uri = self.configuration_location
+        else:
+            s3_prefix_uri = s3.s3_path_join(
+                "s3://",
+                self.sagemaker_session.default_bucket(),
+                self.sagemaker_session.default_bucket_prefix,
+            )
+
         serialized_configuration = BytesIO(json.dumps(configuration).encode("utf-8"))
 
         if _pipeline_config and _pipeline_config.config_hash:
             s3_uri = (
-                f"s3://{self.sagemaker_session.default_bucket()}/{_pipeline_config.pipeline_name}/"
-                f"{_pipeline_config.step_name}/input/"
-                f"{self._conf_container_input_name}/{_pipeline_config.config_hash}/"
+                f"{s3_prefix_uri}/{_pipeline_config.pipeline_name}/{_pipeline_config.step_name}/"
+                f"input/{self._conf_container_input_name}/{_pipeline_config.config_hash}/"
                 f"{self._conf_file_name}"
             )
         else:
             s3_uri = (
-                f"s3://{self.sagemaker_session.default_bucket()}/{self._current_job_name}/"
-                f"input/{self._conf_container_input_name}/{self._conf_file_name}"
+                f"{s3_prefix_uri}/{self._current_job_name}/"
+                f"input/{self._conf_container_input_name}/"
+                f"{self._conf_file_name}"
             )
 
         S3Uploader.upload_string_as_file_body(
@@ -447,7 +416,7 @@ class _SparkProcessorBase(ScriptProcessor):
         This prepared list of paths is provided as `spark-submit` options.
         The submit_deps list may include a combination of S3 URIs and local paths.
         Any S3 URIs are appended to the `spark-submit` option value without modification.
-        Any local file paths are copied to a temp directory, uploaded to a default S3 URI,
+        Any local file paths are copied to a temp directory, uploaded to ``dependency location``,
         and included as a ProcessingInput channel to provide as local files to the SageMaker
         Spark container.
 
@@ -500,16 +469,26 @@ class _SparkProcessorBase(ScriptProcessor):
             if os.listdir(tmpdir):
                 from sagemaker.workflow.utilities import _pipeline_config
 
+                if self.dependency_location:
+                    if self.dependency_location.endswith("/"):
+                        s3_prefix_uri = self.dependency_location[:-1]
+                    else:
+                        s3_prefix_uri = self.dependency_location
+                else:
+                    s3_prefix_uri = s3.s3_path_join(
+                        "s3://",
+                        self.sagemaker_session.default_bucket(),
+                        self.sagemaker_session.default_bucket_prefix,
+                    )
+
                 if _pipeline_config and _pipeline_config.code_hash:
                     input_channel_s3_uri = (
-                        f"s3://{self.sagemaker_session.default_bucket()}"
-                        f"/{_pipeline_config.pipeline_name}/code/{_pipeline_config.code_hash}"
-                        f"/{input_channel_name}"
+                        f"{s3_prefix_uri}/{_pipeline_config.pipeline_name}/"
+                        f"code/{_pipeline_config.code_hash}/{input_channel_name}"
                     )
                 else:
                     input_channel_s3_uri = (
-                        f"s3://{self.sagemaker_session.default_bucket()}"
-                        f"/{self._current_job_name}/input/{input_channel_name}"
+                        f"{s3_prefix_uri}/{self._current_job_name}/input/{input_channel_name}"
                     )
                 logger.info(
                     "Uploading dependencies from tmpdir %s to S3 %s", tmpdir, input_channel_s3_uri
@@ -559,14 +538,14 @@ class _SparkProcessorBase(ScriptProcessor):
         history_server_env_variables = {}
 
         if spark_event_logs_s3_uri:
-            history_server_env_variables[
-                _HistoryServer.arg_event_logs_s3_uri
-            ] = spark_event_logs_s3_uri
+            history_server_env_variables[_HistoryServer.arg_event_logs_s3_uri] = (
+                spark_event_logs_s3_uri
+            )
         # this variable will be previously set by run() method
         elif self._spark_event_logs_s3_uri is not None:
-            history_server_env_variables[
-                _HistoryServer.arg_event_logs_s3_uri
-            ] = self._spark_event_logs_s3_uri
+            history_server_env_variables[_HistoryServer.arg_event_logs_s3_uri] = (
+                self._spark_event_logs_s3_uri
+            )
         else:
             raise ValueError(
                 "SPARK_EVENT_LOGS_S3_URI not present. You can specify spark_event_logs_s3_uri "
@@ -578,9 +557,9 @@ class _SparkProcessorBase(ScriptProcessor):
         history_server_env_variables["AWS_REGION"] = region
 
         if self._is_notebook_instance():
-            history_server_env_variables[
-                _HistoryServer.arg_remote_domain_name
-            ] = self._get_notebook_instance_domain()
+            history_server_env_variables[_HistoryServer.arg_remote_domain_name] = (
+                self._get_notebook_instance_domain()
+            )
 
         return history_server_env_variables
 
@@ -709,9 +688,9 @@ class PySparkProcessor(_SparkProcessorBase):
 
     def __init__(
         self,
-        role: str,
-        instance_type: Union[str, PipelineVariable],
-        instance_count: Union[int, PipelineVariable],
+        role: str = None,
+        instance_type: Union[str, PipelineVariable] = None,
+        instance_count: Union[int, PipelineVariable] = None,
         framework_version: Optional[str] = None,
         py_version: Optional[str] = None,
         container_version: Optional[str] = None,
@@ -719,11 +698,13 @@ class PySparkProcessor(_SparkProcessorBase):
         volume_size_in_gb: Union[int, PipelineVariable] = 30,
         volume_kms_key: Optional[Union[str, PipelineVariable]] = None,
         output_kms_key: Optional[Union[str, PipelineVariable]] = None,
+        configuration_location: Optional[str] = None,
+        dependency_location: Optional[str] = None,
         max_runtime_in_seconds: Optional[Union[int, PipelineVariable]] = None,
         base_job_name: Optional[str] = None,
         sagemaker_session: Optional[Session] = None,
         env: Optional[Dict[str, Union[str, PipelineVariable]]] = None,
-        tags: Optional[List[Dict[str, Union[str, PipelineVariable]]]] = None,
+        tags: Optional[Tags] = None,
         network_config: Optional[NetworkConfig] = None,
     ):
         """Initialize an ``PySparkProcessor`` instance.
@@ -735,11 +716,11 @@ class PySparkProcessor(_SparkProcessorBase):
             framework_version (str): The version of SageMaker PySpark.
             py_version (str): The version of python.
             container_version (str): The version of spark container.
-            role (str): An AWS IAM role name or ARN. The Amazon SageMaker training jobs
-                and APIs that create Amazon SageMaker endpoints use this role
-                to access training data and model artifacts. After the endpoint
-                is created, the inference code might use the IAM role, if it
-                needs to access an AWS resource.
+            role (str): An AWS IAM role name or ARN. Amazon SageMaker Processing
+                uses this role to access AWS resources, such as
+                data stored in Amazon S3 (default: None).
+                If not specified, the value from the defaults configuration file
+                will be used.
             instance_type (str or PipelineVariable): Type of EC2 instance to use for
                 processing, for example, 'ml.c4.xlarge'.
             instance_count (int or PipelineVariable): The number of instances to run
@@ -749,6 +730,12 @@ class PySparkProcessor(_SparkProcessorBase):
             volume_kms_key (str or PipelineVariable): A KMS key for the processing
                 volume.
             output_kms_key (str or PipelineVariable): The KMS key id for all ProcessingOutputs.
+            configuration_location (str): The S3 prefix URI where the user-provided EMR
+                application configuration will be uploaded (default: None). If not specified,
+                the default ``configuration location`` is 's3://{sagemaker-default-bucket}'.
+            dependency_location (str): The S3 prefix URI where Spark dependencies will be
+                uploaded (default: None). If not specified, the default ``dependency location``
+                is 's3://{sagemaker-default-bucket}'.
             max_runtime_in_seconds (int or PipelineVariable): Timeout in seconds.
                 After this amount of time Amazon SageMaker terminates the job
                 regardless of its current status.
@@ -761,7 +748,7 @@ class PySparkProcessor(_SparkProcessorBase):
                 using the default AWS configuration chain.
             env (dict[str, str] or dict[str, PipelineVariable]): Environment variables to
                 be passed to the processing job.
-            tags (list[dict[str, str] or list[dict[str, PipelineVariable]]): List of tags to
+            tags (Optional[Tags]): List of tags to
                 be passed to the processing job.
             network_config (sagemaker.network.NetworkConfig): A NetworkConfig
                 object that configures network isolation, encryption of
@@ -779,11 +766,13 @@ class PySparkProcessor(_SparkProcessorBase):
             volume_size_in_gb=volume_size_in_gb,
             volume_kms_key=volume_kms_key,
             output_kms_key=output_kms_key,
+            configuration_location=configuration_location,
+            dependency_location=dependency_location,
             max_runtime_in_seconds=max_runtime_in_seconds,
             base_job_name=base_job_name,
             sagemaker_session=sagemaker_session,
             env=env,
-            tags=tags,
+            tags=format_tags(tags),
             network_config=network_config,
         )
 
@@ -976,9 +965,9 @@ class SparkJarProcessor(_SparkProcessorBase):
 
     def __init__(
         self,
-        role: str,
-        instance_type: Union[str, PipelineVariable],
-        instance_count: Union[int, PipelineVariable],
+        role: str = None,
+        instance_type: Union[str, PipelineVariable] = None,
+        instance_count: Union[int, PipelineVariable] = None,
         framework_version: Optional[str] = None,
         py_version: Optional[str] = None,
         container_version: Optional[str] = None,
@@ -986,11 +975,13 @@ class SparkJarProcessor(_SparkProcessorBase):
         volume_size_in_gb: Union[int, PipelineVariable] = 30,
         volume_kms_key: Optional[Union[str, PipelineVariable]] = None,
         output_kms_key: Optional[Union[str, PipelineVariable]] = None,
+        configuration_location: Optional[str] = None,
+        dependency_location: Optional[str] = None,
         max_runtime_in_seconds: Optional[Union[int, PipelineVariable]] = None,
         base_job_name: Optional[str] = None,
         sagemaker_session: Optional[Session] = None,
         env: Optional[Dict[str, Union[str, PipelineVariable]]] = None,
-        tags: Optional[List[Dict[str, Union[str, PipelineVariable]]]] = None,
+        tags: Optional[Tags] = None,
         network_config: Optional[NetworkConfig] = None,
     ):
         """Initialize a ``SparkJarProcessor`` instance.
@@ -1002,11 +993,11 @@ class SparkJarProcessor(_SparkProcessorBase):
             framework_version (str): The version of SageMaker PySpark.
             py_version (str): The version of python.
             container_version (str): The version of spark container.
-            role (str): An AWS IAM role name or ARN. The Amazon SageMaker training jobs
-                and APIs that create Amazon SageMaker endpoints use this role
-                to access training data and model artifacts. After the endpoint
-                is created, the inference code might use the IAM role, if it
-                needs to access an AWS resource.
+            role (str): An AWS IAM role name or ARN. Amazon SageMaker Processing
+                uses this role to access AWS resources, such as
+                data stored in Amazon S3 (default: None).
+                If not specified, the value from the defaults configuration file
+                will be used.
             instance_type (str or PipelineVariable): Type of EC2 instance to use for
                 processing, for example, 'ml.c4.xlarge'.
             instance_count (int or PipelineVariable): The number of instances to run
@@ -1016,6 +1007,12 @@ class SparkJarProcessor(_SparkProcessorBase):
             volume_kms_key (str or PipelineVariable): A KMS key for the processing
                 volume.
             output_kms_key (str or PipelineVariable): The KMS key id for all ProcessingOutputs.
+            configuration_location (str): The S3 prefix URI where the user-provided EMR
+                application configuration will be uploaded (default: None). If not specified,
+                the default ``configuration location`` is 's3://{sagemaker-default-bucket}'.
+            dependency_location (str): The S3 prefix URI where Spark dependencies will be
+                uploaded (default: None). If not specified, the default ``dependency location``
+                is 's3://{sagemaker-default-bucket}'.
             max_runtime_in_seconds (int or PipelineVariable): Timeout in seconds.
                 After this amount of time Amazon SageMaker terminates the job
                 regardless of its current status.
@@ -1028,8 +1025,7 @@ class SparkJarProcessor(_SparkProcessorBase):
                 using the default AWS configuration chain.
             env (dict[str, str] or dict[str, PipelineVariable]): Environment variables to
                 be passed to the processing job.
-            tags (list[dict[str, str] or list[dict[str, PipelineVariable]]): List of tags to
-                be passed to the processing job.
+            tags (Optional[Tags]): Tags to be passed to the processing job.
             network_config (sagemaker.network.NetworkConfig): A NetworkConfig
                 object that configures network isolation, encryption of
                 inter-container traffic, security group IDs, and subnets.
@@ -1046,11 +1042,13 @@ class SparkJarProcessor(_SparkProcessorBase):
             volume_size_in_gb=volume_size_in_gb,
             volume_kms_key=volume_kms_key,
             output_kms_key=output_kms_key,
+            configuration_location=configuration_location,
+            dependency_location=dependency_location,
             max_runtime_in_seconds=max_runtime_in_seconds,
             base_job_name=base_job_name,
             sagemaker_session=sagemaker_session,
             env=env,
-            tags=tags,
+            tags=format_tags(tags),
             network_config=network_config,
         )
 
@@ -1293,3 +1291,89 @@ class FileType(Enum):
     JAR = 1
     PYTHON = 2
     FILE = 3
+
+
+class SparkConfigUtils:
+    """Util class for spark configurations"""
+
+    _valid_configuration_keys = ["Classification", "Properties", "Configurations"]
+    _valid_configuration_classifications = [
+        "core-site",
+        "hadoop-env",
+        "hadoop-log4j",
+        "hive-env",
+        "hive-log4j",
+        "hive-exec-log4j",
+        "hive-site",
+        "spark-defaults",
+        "spark-env",
+        "spark-log4j",
+        "spark-hive-site",
+        "spark-metrics",
+        "yarn-env",
+        "yarn-site",
+        "export",
+    ]
+
+    @staticmethod
+    def validate_configuration(configuration: Dict):
+        """Validates the user-provided Hadoop/Spark/Hive configuration.
+
+        This ensures that the list or dictionary the user provides will serialize to
+        JSON matching the schema of EMR's application configuration
+
+        Args:
+            configuration (Dict): A dict that contains the configuration overrides to
+                the default values. For more information, please visit:
+                https://docs.aws.amazon.com/emr/latest/ReleaseGuide/emr-configure-apps.html
+        """
+        emr_configure_apps_url = (
+            "https://docs.aws.amazon.com/emr/latest/ReleaseGuide/emr-configure-apps.html"
+        )
+        if isinstance(configuration, dict):
+            keys = configuration.keys()
+            if "Classification" not in keys or "Properties" not in keys:
+                raise ValueError(
+                    f"Missing one or more required keys in configuration dictionary "
+                    f"{configuration} Please see {emr_configure_apps_url} for more information"
+                )
+
+            for key in keys:
+                if key not in SparkConfigUtils._valid_configuration_keys:
+                    raise ValueError(
+                        f"Invalid key: {key}. "
+                        f"Must be one of {SparkConfigUtils._valid_configuration_keys}. "
+                        f"Please see {emr_configure_apps_url} for more information."
+                    )
+                if key == "Classification":
+                    if (
+                        configuration[key]
+                        not in SparkConfigUtils._valid_configuration_classifications
+                    ):
+                        raise ValueError(
+                            f"Invalid classification: {key}. Must be one of "
+                            f"{SparkConfigUtils._valid_configuration_classifications}"
+                        )
+
+        if isinstance(configuration, list):
+            for item in configuration:
+                SparkConfigUtils.validate_configuration(item)
+
+    # TODO (guoqioa@): method only checks urlparse scheme, need to perform deep s3 validation
+    @staticmethod
+    def validate_s3_uri(spark_output_s3_path):
+        """Validate whether the URI uses an S3 scheme.
+
+        In the future, this validation will perform deeper S3 validation.
+
+        Args:
+            spark_output_s3_path (str): The URI of the Spark output S3 Path.
+        """
+        if is_pipeline_variable(spark_output_s3_path):
+            return
+
+        if urlparse(spark_output_s3_path).scheme != "s3":
+            raise ValueError(
+                f"Invalid s3 path: {spark_output_s3_path}. Please enter something like "
+                "s3://bucket-name/folder-name"
+            )
