@@ -14,7 +14,7 @@
 from __future__ import absolute_import
 
 import logging
-from typing import Union, Optional, List, Dict
+from typing import Callable, Union, Optional, List, Dict
 
 import sagemaker
 from sagemaker import image_uris, s3, ModelMetrics
@@ -22,11 +22,17 @@ from sagemaker.deserializers import JSONDeserializer
 from sagemaker.deprecations import removed_kwargs
 from sagemaker.drift_check_baselines import DriftCheckBaselines
 from sagemaker.metadata_properties import MetadataProperties
+from sagemaker.model_card import (
+    ModelCard,
+    ModelPackageModelCard,
+)
 from sagemaker.predictor import Predictor
 from sagemaker.serializers import JSONSerializer
 from sagemaker.workflow import is_pipeline_variable
 from sagemaker.workflow.entities import PipelineVariable
 from sagemaker.workflow.pipeline_context import PipelineSession
+from sagemaker.utils import format_tags
+from sagemaker.model_life_cycle import ModelLifeCycle
 
 logger = logging.getLogger(__name__)
 
@@ -42,6 +48,7 @@ class TensorFlowPredictor(Predictor):
         deserializer=JSONDeserializer(),
         model_name=None,
         model_version=None,
+        component_name=None,
         **kwargs,
     ):
         """Initialize a ``TensorFlowPredictor``.
@@ -55,9 +62,9 @@ class TensorFlowPredictor(Predictor):
                 manages interactions with Amazon SageMaker APIs and any other
                 AWS services needed. If not specified, the estimator creates one
                 using the default AWS configuration chain.
-            serializer (callable): Optional. Default serializes input data to
+            serializer (Callable): Optional. Default serializes input data to
                 json. Handles dicts, lists, and numpy arrays.
-            deserializer (callable): Optional. Default parses the response using
+            deserializer (Callable): Optional. Default parses the response using
                 ``json.load(...)``.
             model_name (str): Optional. The name of the SavedModel model that
                 should handle the request. If not specified, the endpoint's
@@ -65,6 +72,8 @@ class TensorFlowPredictor(Predictor):
             model_version (str): Optional. The version of the SavedModel model
                 that should handle the request. If not specified, the latest
                 version of the model will be used.
+            component_name (str): Optional. Name of the Amazon SageMaker inference
+                component corresponding to the predictor.
         """
         removed_kwargs("content_type", kwargs)
         removed_kwargs("accept", kwargs)
@@ -73,6 +82,7 @@ class TensorFlowPredictor(Predictor):
             sagemaker_session,
             serializer,
             deserializer,
+            component_name=component_name,
         )
 
         attributes = []
@@ -131,12 +141,12 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
     def __init__(
         self,
         model_data: Union[str, PipelineVariable],
-        role: str,
+        role: str = None,
         entry_point: Optional[str] = None,
         image_uri: Optional[Union[str, PipelineVariable]] = None,
         framework_version: Optional[str] = None,
         container_log_level: Optional[int] = None,
-        predictor_cls: callable = TensorFlowPredictor,
+        predictor_cls: Optional[Callable] = TensorFlowPredictor,
         **kwargs,
     ):
         """Initialize a Model.
@@ -164,7 +174,7 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
             container_log_level (int): Log level to use within the container
                 (default: logging.ERROR). Valid values are defined in the Python
                 logging module.
-            predictor_cls (callable[str, sagemaker.session.Session]): A function
+            predictor_cls (Callable[[string, sagemaker.session.Session], Any]): A function
                 to call to create a predictor with an endpoint name and
                 SageMaker ``Session``. If specified, ``deploy()`` returns the
                 result of invoking this function on the created endpoint name.
@@ -185,6 +195,15 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
             )
         self.framework_version = framework_version
 
+        # Inference framework version is being introduced to accomodate the mismatch between
+        # tensorflow and tensorflow serving releases, wherein the TF and TFS might have different
+        # patch versions, but end up hosting the model of same TF version. For eg., the upstream
+        # TFS-2.12.0 release was a bad release and hence a new TFS-2.12.1 release was made to host
+        # models from TF-2.12.0.
+        training_inference_version_mismatch_dict = {"2.12.0": "2.12.1", "2.16.2": "2.16.1"}
+        self.inference_framework_version = training_inference_version_mismatch_dict.get(
+            framework_version, framework_version
+        )
         super(TensorFlowModel, self).__init__(
             model_data=model_data,
             role=role,
@@ -197,8 +216,8 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
 
     def register(
         self,
-        content_types: List[Union[str, PipelineVariable]],
-        response_types: List[Union[str, PipelineVariable]],
+        content_types: List[Union[str, PipelineVariable]] = None,
+        response_types: List[Union[str, PipelineVariable]] = None,
         inference_instances: Optional[List[Union[str, PipelineVariable]]] = None,
         transform_instances: Optional[List[Union[str, PipelineVariable]]] = None,
         model_package_name: Optional[Union[str, PipelineVariable]] = None,
@@ -218,6 +237,10 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
         framework_version: Optional[Union[str, PipelineVariable]] = None,
         nearest_model_name: Optional[Union[str, PipelineVariable]] = None,
         data_input_configuration: Optional[Union[str, PipelineVariable]] = None,
+        skip_model_validation: Optional[Union[str, PipelineVariable]] = None,
+        source_uri: Optional[Union[str, PipelineVariable]] = None,
+        model_card: Optional[Union[ModelPackageModelCard, ModelCard]] = None,
+        model_life_cycle: Optional[ModelLifeCycle] = None,
     ):
         """Creates a model package for creating SageMaker models or listing on Marketplace.
 
@@ -265,6 +288,13 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
                 benchmarked by Amazon SageMaker Inference Recommender (default: None).
             data_input_configuration (str or PipelineVariable): Input object for the model
                 (default: None).
+            skip_model_validation (str or PipelineVariable): Indicates if you want to skip model
+                validation. Values can be "All" or "None" (default: None).
+            source_uri (str or PipelineVariable): The URI of the source for the model package
+                (default: None).
+            model_card (ModeCard or ModelPackageModelCard): document contains qualitative and
+                quantitative information about a model (default: None).
+            model_life_cycle (ModelLifeCycle): ModelLifeCycle object (default: None).
 
         Returns:
             A `sagemaker.model.ModelPackage` instance.
@@ -303,6 +333,10 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
             framework_version=framework_version or self.framework_version,
             nearest_model_name=nearest_model_name,
             data_input_configuration=data_input_configuration,
+            skip_model_validation=skip_model_validation,
+            source_uri=source_uri,
+            model_card=model_card,
+            model_life_cycle=model_life_cycle,
         )
 
     def deploy(
@@ -317,16 +351,17 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
         kms_key=None,
         wait=True,
         data_capture_config=None,
-        update_endpoint=None,
         async_inference_config=None,
         serverless_inference_config=None,
         volume_size=None,
         model_data_download_timeout=None,
         container_startup_health_check_timeout=None,
         inference_recommendation_id=None,
+        explainer_config=None,
+        update_endpoint: Optional[bool] = False,
+        **kwargs,
     ):
         """Deploy a Tensorflow ``Model`` to a SageMaker ``Endpoint``."""
-
         if accelerator_type and not self._eia_supported():
             msg = "The TensorFlow version %s doesn't support EIA." % self.framework_version
             raise AttributeError(msg)
@@ -338,7 +373,7 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
             deserializer=deserializer,
             accelerator_type=accelerator_type,
             endpoint_name=endpoint_name,
-            tags=tags,
+            tags=format_tags(tags),
             kms_key=kms_key,
             wait=wait,
             data_capture_config=data_capture_config,
@@ -347,8 +382,10 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
             volume_size=volume_size,
             model_data_download_timeout=model_data_download_timeout,
             container_startup_health_check_timeout=container_startup_health_check_timeout,
-            update_endpoint=update_endpoint,
             inference_recommendation_id=inference_recommendation_id,
+            explainer_config=explainer_config,
+            update_endpoint=update_endpoint,
+            **kwargs,
         )
 
     def _eia_supported(self):
@@ -361,7 +398,12 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
         )
 
     def prepare_container_def(
-        self, instance_type=None, accelerator_type=None, serverless_inference_config=None
+        self,
+        instance_type=None,
+        accelerator_type=None,
+        serverless_inference_config=None,
+        accept_eula=None,
+        model_reference_arn=None,
     ):
         """Prepare the container definition.
 
@@ -371,6 +413,11 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
             serverless_inference_config (sagemaker.serverless.ServerlessInferenceConfig):
                 Specifies configuration related to serverless endpoint. Instance type is
                 not provided in serverless inference. So this is used to find image URIs.
+            accept_eula (bool): For models that require a Model Access Config, specify True or
+                False to indicate whether model terms of use have been accepted.
+                The `accept_eula` value must be explicitly defined as `True` in order to
+                accept the end-user license agreement (EULA) that some
+                models require. (Default: None).
 
         Returns:
             A container definition for deploying a ``Model`` to an ``Endpoint``.
@@ -385,8 +432,14 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
             instance_type, accelerator_type, serverless_inference_config=serverless_inference_config
         )
         env = self._get_container_env()
-        key_prefix = sagemaker.fw_utils.model_code_key_prefix(self.key_prefix, self.name, image_uri)
-        bucket = self.bucket or self.sagemaker_session.default_bucket()
+
+        bucket, key_prefix = s3.determine_bucket_and_prefix(
+            bucket=self.bucket,
+            key_prefix=sagemaker.fw_utils.model_code_key_prefix(
+                self.key_prefix, self.name, image_uri
+            ),
+            sagemaker_session=self.sagemaker_session,
+        )
 
         if self.entry_point and not is_pipeline_variable(self.model_data):
             model_data = s3.s3_path_join("s3://", bucket, key_prefix, "model.tar.gz")
@@ -422,7 +475,13 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
         else:
             model_data = self.model_data
 
-        return sagemaker.container_def(image_uri, model_data, env)
+        return sagemaker.container_def(
+            image_uri,
+            model_data,
+            env,
+            accept_eula=accept_eula,
+            model_reference_arn=model_reference_arn,
+        )
 
     def _get_container_env(self):
         """Placeholder docstring."""
@@ -455,7 +514,7 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
         return image_uris.retrieve(
             self._framework_name,
             region_name or self.sagemaker_session.boto_region_name,
-            version=self.framework_version,
+            version=self.inference_framework_version,
             instance_type=instance_type,
             accelerator_type=accelerator_type,
             image_scope="inference",
