@@ -13,12 +13,21 @@
 """Placeholder docstring"""
 from __future__ import absolute_import
 
-from typing import Union, Optional, List, Dict
+from typing import Union, Optional, Dict
 import logging
 import copy
 import time
 
 from botocore import exceptions
+
+from sagemaker import s3
+from sagemaker.config import (
+    TRANSFORM_JOB_ENVIRONMENT_PATH,
+    TRANSFORM_OUTPUT_KMS_KEY_ID_PATH,
+    TRANSFORM_JOB_KMS_KEY_ID_PATH,
+    TRANSFORM_RESOURCES_VOLUME_KMS_KEY_ID_PATH,
+    PIPELINE_ROLE_ARN_PATH,
+)
 from sagemaker.job import _Job
 from sagemaker.session import Session, get_execution_role
 from sagemaker.inputs import BatchDataCaptureConfig
@@ -31,6 +40,10 @@ from sagemaker.utils import (
     base_name_from_image,
     name_from_base,
     check_and_get_run_experiment_config,
+    resolve_value_from_config,
+    resolve_class_attribute_from_config,
+    format_tags,
+    Tags,
 )
 
 
@@ -51,7 +64,7 @@ class Transformer(object):
         accept: Optional[Union[str, PipelineVariable]] = None,
         max_concurrent_transforms: Optional[Union[int, PipelineVariable]] = None,
         max_payload: Optional[Union[int, PipelineVariable]] = None,
-        tags: Optional[List[Dict[str, Union[str, PipelineVariable]]]] = None,
+        tags: Optional[Tags] = None,
         env: Optional[Dict[str, Union[str, PipelineVariable]]] = None,
         base_transform_job_name: Optional[str] = None,
         sagemaker_session: Optional[Session] = None,
@@ -81,9 +94,9 @@ class Transformer(object):
                 to be made to each individual transform container at one time.
             max_payload (int or PipelineVariable): Maximum size of the payload in a single HTTP
                 request to the container in MB.
-            tags (list[dict[str, str] or list[dict[str, PipelineVariable]]): List of tags for
-                labeling a transform job (default: None). For more, see the SageMaker API
-                documentation for `Tag <https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html>`_.
+            tags (Optional[Tags]): Tags for labeling a transform job (default: None).
+                For more, see the SageMaker API documentation for
+                `Tag <https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html>`_.
             env (dict[str, str] or dict[str, PipelineVariable]): Environment variables to be set
                 for use during the transform job (default: None).
             base_transform_job_name (str): Prefix for the transform job when the
@@ -100,20 +113,17 @@ class Transformer(object):
         """
         self.model_name = model_name
         self.strategy = strategy
-        self.env = env
 
         self.output_path = output_path
-        self.output_kms_key = output_kms_key
         self.accept = accept
         self.assemble_with = assemble_with
 
         self.instance_count = instance_count
         self.instance_type = instance_type
-        self.volume_kms_key = volume_kms_key
 
         self.max_concurrent_transforms = max_concurrent_transforms
         self.max_payload = max_payload
-        self.tags = tags
+        self.tags = format_tags(tags)
 
         self.base_transform_job_name = base_transform_job_name
         self._current_job_name = None
@@ -121,6 +131,21 @@ class Transformer(object):
         self._reset_output_path = False
 
         self.sagemaker_session = sagemaker_session or Session()
+        self.volume_kms_key = resolve_value_from_config(
+            volume_kms_key,
+            TRANSFORM_RESOURCES_VOLUME_KMS_KEY_ID_PATH,
+            sagemaker_session=self.sagemaker_session,
+        )
+        self.output_kms_key = resolve_value_from_config(
+            output_kms_key,
+            TRANSFORM_OUTPUT_KMS_KEY_ID_PATH,
+            sagemaker_session=self.sagemaker_session,
+        )
+        self.env = resolve_value_from_config(
+            env,
+            TRANSFORM_JOB_ENVIRONMENT_PATH,
+            sagemaker_session=self.sagemaker_session,
+        )
 
     @runnable_by_pipeline
     def transform(
@@ -244,18 +269,36 @@ class Transformer(object):
                     values=[
                         "s3:/",
                         self.sagemaker_session.default_bucket(),
+                        *(
+                            # don't include default_bucket_prefix if it is None or ""
+                            [self.sagemaker_session.default_bucket_prefix]
+                            if self.sagemaker_session.default_bucket_prefix
+                            else []
+                        ),
                         _pipeline_config.pipeline_name,
                         ExecutionVariables.PIPELINE_EXECUTION_ID,
                         _pipeline_config.step_name,
                     ],
                 )
             else:
-                self.output_path = "s3://{}/{}".format(
-                    self.sagemaker_session.default_bucket(), self._current_job_name
+                self.output_path = s3.s3_path_join(
+                    "s3://",
+                    self.sagemaker_session.default_bucket(),
+                    self.sagemaker_session.default_bucket_prefix,
+                    self._current_job_name,
                 )
             self._reset_output_path = True
 
         experiment_config = check_and_get_run_experiment_config(experiment_config)
+
+        batch_data_capture_config = resolve_class_attribute_from_config(
+            None,
+            batch_data_capture_config,
+            "kms_key_id",
+            TRANSFORM_JOB_KMS_KEY_ID_PATH,
+            sagemaker_session=self.sagemaker_session,
+        )
+
         self.latest_transform_job = _TransformJob.start_new(
             self,
             data,
@@ -294,6 +337,7 @@ class Transformer(object):
         wait: bool = True,
         pipeline_name: str = None,
         role: str = None,
+        fail_on_violation: bool = True,
     ):
         """Runs a transform job with monitoring job.
 
@@ -309,7 +353,6 @@ class Transformer(object):
             ]): the monitoring configuration used for run model monitoring.
             monitoring_resource_config (`sagemaker.workflow.check_job_config.CheckJobConfig`):
                 the check job (processing job) cluster resource configuration.
-            transform_step_args (_JobStepArguments): the transform step transform arguments.
             data (str): Input data location in S3 for the transform job
             data_type (str): What the S3 location defines (default: 'S3Prefix').
                 Valid values:
@@ -357,8 +400,6 @@ class Transformer(object):
             monitor_before_transform (bgool): If to run data quality
                 or model explainability monitoring type,
                 a true value of this flag indicates running the check step before the transform job.
-            fail_on_violation (Union[bool, PipelineVariable]): A opt-out flag to not to fail the
-                check step when a violation is detected.
             supplied_baseline_statistics (Union[str, PipelineVariable]): The S3 path
                 to the supplied statistics object representing the statistics JSON file
                 which will be used for drift to check (default: None).
@@ -368,6 +409,8 @@ class Transformer(object):
             wait (bool): To determine if needed to wait for the pipeline execution to complete
             pipeline_name (str): The name of the Pipeline for the monitoring and transfrom step
             role (str): Execution role
+            fail_on_violation (Union[bool, PipelineVariable]): A opt-out flag to not to fail the
+                check step when a violation is detected.
         """
 
         transformer = self
@@ -378,6 +421,14 @@ class Transformer(object):
             transformer.sagemaker_session = PipelineSession()
             self.sagemaker_session = sagemaker_session
 
+        batch_data_capture_config = resolve_class_attribute_from_config(
+            None,
+            batch_data_capture_config,
+            "kms_key_id",
+            TRANSFORM_JOB_KMS_KEY_ID_PATH,
+            sagemaker_session=self.sagemaker_session,
+        )
+
         transform_step_args = transformer.transform(
             data=data,
             data_type=data_type,
@@ -403,6 +454,7 @@ class Transformer(object):
             monitor_before_transform=monitor_before_transform,
             supplied_baseline_constraints=supplied_baseline_constraints,
             supplied_baseline_statistics=supplied_baseline_statistics,
+            fail_on_violation=fail_on_violation,
         )
 
         pipeline_name = (
@@ -416,7 +468,16 @@ class Transformer(object):
             steps=[monitoring_batch_step],
             sagemaker_session=transformer.sagemaker_session,
         )
-        pipeline.upsert(role_arn=role if role else get_execution_role())
+        pipeline_role_arn = (
+            role
+            if role
+            else resolve_value_from_config(
+                get_execution_role(),
+                PIPELINE_ROLE_ARN_PATH,
+                sagemaker_session=transformer.sagemaker_session,
+            )
+        )
+        pipeline.upsert(pipeline_role_arn)
         execution = pipeline.start()
         if wait:
             logging.info("Waiting for transform with monitoring to execute ...")
