@@ -14,6 +14,7 @@
 from __future__ import absolute_import
 
 from sagemaker.workflow.entities import Expression
+from sagemaker.workflow.parameters import ParameterString
 
 
 def is_pipeline_variable(var: object) -> bool:
@@ -29,3 +30,14 @@ def is_pipeline_variable(var: object) -> bool:
     # as well as PipelineExperimentConfigProperty and PropertyFile
     # TODO: We should deprecate the Expression and replace it with PipelineVariable
     return isinstance(var, Expression)
+
+
+def is_pipeline_parameter_string(var: object) -> bool:
+    """Check if the variable is a pipeline parameter string
+
+    Args:
+        var (object): The variable to be verified.
+    Returns:
+         bool: True if it is, False otherwise.
+    """
+    return isinstance(var, ParameterString)
