@@ -32,15 +32,21 @@ from sagemaker.workflow.steps import (
     Step,
     ConfigurableRetryStep,
 )
-from sagemaker.utils import _save_model, download_file_from_url
+from sagemaker.utils import (
+    _save_model,
+    download_file_from_url,
+    format_tags,
+    custom_extractall_tarfile,
+)
 from sagemaker.workflow.retry import RetryPolicy
+from sagemaker.workflow.utilities import trim_request_dict
 
 if TYPE_CHECKING:
     from sagemaker.workflow.step_collections import StepCollection
 
 logger = logging.getLogger(__name__)
 
-FRAMEWORK_VERSION = "0.23-1"
+FRAMEWORK_VERSION = "1.2-1"
 INSTANCE_TYPE = "ml.m5.large"
 REPACK_SCRIPT = "_repack_model.py"
 REPACK_SCRIPT_LAUNCHER = "_repack_script_launcher.sh"
@@ -171,8 +177,8 @@ class _RepackModelStep(TrainingStep):
 
         # the real estimator and inputs
         repacker = SKLearn(
-            framework_version=FRAMEWORK_VERSION,
-            instance_type=INSTANCE_TYPE,
+            framework_version=kwargs.pop("framework_version", None) or FRAMEWORK_VERSION,
+            instance_type=kwargs.pop("instance_type", None) or INSTANCE_TYPE,
             entry_point=REPACK_SCRIPT_LAUNCHER,
             source_dir=self._source_dir,
             dependencies=self._dependencies,
@@ -256,7 +262,7 @@ class _RepackModelStep(TrainingStep):
                 download_file_from_url(self._source_dir, old_targz_path, self.sagemaker_session)
 
                 with tarfile.open(name=old_targz_path, mode="r:gz") as t:
-                    t.extractall(path=targz_contents_dir)
+                    custom_extractall_tarfile(t, targz_contents_dir)
 
                 shutil.copy2(fname, os.path.join(targz_contents_dir, REPACK_SCRIPT))
                 with open(
@@ -321,6 +327,10 @@ class _RegisterModelStep(ConfigurableRetryStep):
         domain=None,
         sample_payload_url=None,
         task=None,
+        skip_model_validation=None,
+        source_uri=None,
+        model_card=None,
+        model_life_cycle=None,
         **kwargs,
     ):
         """Constructor of a register model step.
@@ -357,7 +367,7 @@ class _RegisterModelStep(ConfigurableRetryStep):
                 depends on (default: None).
             retry_policies (List[RetryPolicy]): The list of retry policies for the current step
                 (default: None).
-            tags (List[dict[str, str]]): A list of dictionaries containing key-value pairs used to
+            tags (Optional[Tags]): A list of dictionaries containing key-value pairs used to
                 configure the create model package request (default: None).
             container_def_list (list): A list of container definitions (default: None).
             drift_check_baselines (DriftCheckBaselines): DriftCheckBaselines object (default: None).
@@ -370,6 +380,12 @@ class _RegisterModelStep(ConfigurableRetryStep):
             task (str): Task values which are supported by Inference Recommender are "FILL_MASK",
                 "IMAGE_CLASSIFICATION", "OBJECT_DETECTION", "TEXT_GENERATION", "IMAGE_SEGMENTATION",
                 "CLASSIFICATION", "REGRESSION", "OTHER" (default: None).
+            skip_model_validation (str): Indicates if you want to skip model validation.
+                Values can be "All" or "None" (default: None).
+            source_uri (str): The URI of the source for the model package (default: None).
+            model_card (ModeCard or ModelPackageModelCard): document contains qualitative and
+                quantitative information about a model (default: None).
+            model_life_cycle (ModelLifeCycle): ModelLifeCycle object (default: None).
             **kwargs: additional arguments to `create_model`.
         """
         super(_RegisterModelStep, self).__init__(
@@ -391,7 +407,7 @@ class _RegisterModelStep(ConfigurableRetryStep):
         self.inference_instances = inference_instances
         self.transform_instances = transform_instances
         self.model_package_group_name = model_package_group_name
-        self.tags = tags
+        self.tags = format_tags(tags)
         self.model_metrics = model_metrics
         self.drift_check_baselines = drift_check_baselines
         self.customer_metadata_properties = customer_metadata_properties
@@ -403,15 +419,22 @@ class _RegisterModelStep(ConfigurableRetryStep):
         self.image_uri = image_uri
         self.compile_model_family = compile_model_family
         self.description = description
-        self.tags = tags
         self.kwargs = kwargs
         self.container_def_list = container_def_list
+        self.skip_model_validation = skip_model_validation
+        self.source_uri = source_uri
+        self.model_card = model_card
+        self.model_life_cycle = model_life_cycle
 
-        self._properties = Properties(step_name=name, shape_name="DescribeModelPackageOutput")
+        self._properties = Properties(
+            step_name=name, step=self, shape_name="DescribeModelPackageOutput"
+        )
 
     @property
     def arguments(self) -> RequestType:
         """The arguments dict that are used to call `create_model_package`."""
+        from sagemaker.workflow.utilities import _pipeline_config
+
         model_name = self.name
 
         if self.step_args:
@@ -436,9 +459,6 @@ class _RegisterModelStep(ConfigurableRetryStep):
                         model = self.estimator.create_model(**self.kwargs)
                         self.image_uri = model.image_uri
 
-                    if self.model_data is None:
-                        self.model_data = model.model_data
-
                     # reset placeholder
                     self.estimator.output_path = output_path
 
@@ -478,6 +498,10 @@ class _RegisterModelStep(ConfigurableRetryStep):
                 domain=self.domain,
                 sample_payload_url=self.sample_payload_url,
                 task=self.task,
+                skip_model_validation=self.skip_model_validation,
+                source_uri=self.source_uri,
+                model_card=self.model_card,
+                model_life_cycle=self.model_life_cycle,
             )
 
             request_dict = get_create_model_package_request(**model_package_args)
@@ -492,9 +516,9 @@ class _RegisterModelStep(ConfigurableRetryStep):
         if "Description" in request_dict:
             request_dict.pop("Description")
             logger.warning(warn_msg_template, "Description")
-        if "ModelPackageName" in request_dict:
-            request_dict.pop("ModelPackageName")
-            logger.warning(warn_msg_template, "ModelPackageName")
+
+        # Continue to pop job name if not explicitly opted-in via config
+        request_dict = trim_request_dict(request_dict, "ModelPackageName", _pipeline_config)
 
         return request_dict
 
