@@ -22,6 +22,7 @@ from sagemaker.amazon import amazon_estimator
 from sagemaker.tensorflow import TensorFlow
 from sagemaker.estimator import EstimatorBase
 from sagemaker.processing import Processor
+from sagemaker.utils import format_tags
 
 
 def prepare_framework(estimator, s3_operations):
@@ -37,12 +38,17 @@ def prepare_framework(estimator, s3_operations):
     """
     if estimator.code_location is not None:
         bucket, key = s3.parse_s3_url(estimator.code_location)
-        key = os.path.join(key, estimator._current_job_name, "source", "sourcedir.tar.gz")
+        key = s3.s3_path_join(key, estimator._current_job_name, "source", "sourcedir.tar.gz")
     elif estimator.uploaded_code is not None:
         bucket, key = s3.parse_s3_url(estimator.uploaded_code.s3_prefix)
     else:
-        bucket = estimator.sagemaker_session._default_bucket
-        key = os.path.join(estimator._current_job_name, "source", "sourcedir.tar.gz")
+        bucket = estimator.sagemaker_session.default_bucket
+        key = s3.s3_path_join(
+            estimator.sagemaker_session.default_bucket_prefix,
+            estimator._current_job_name,
+            "source",
+            "sourcedir.tar.gz",
+        )
 
     script = os.path.basename(estimator.entry_point)
 
@@ -62,13 +68,13 @@ def prepare_framework(estimator, s3_operations):
         ]
     estimator._hyperparameters[sagemaker.model.DIR_PARAM_NAME] = code_dir
     estimator._hyperparameters[sagemaker.model.SCRIPT_PARAM_NAME] = script
-    estimator._hyperparameters[
-        sagemaker.model.CONTAINER_LOG_LEVEL_PARAM_NAME
-    ] = estimator.container_log_level
+    estimator._hyperparameters[sagemaker.model.CONTAINER_LOG_LEVEL_PARAM_NAME] = (
+        estimator.container_log_level
+    )
     estimator._hyperparameters[sagemaker.model.JOB_NAME_PARAM_NAME] = estimator._current_job_name
-    estimator._hyperparameters[
-        sagemaker.model.SAGEMAKER_REGION_PARAM_NAME
-    ] = estimator.sagemaker_session.boto_region_name
+    estimator._hyperparameters[sagemaker.model.SAGEMAKER_REGION_PARAM_NAME] = (
+        estimator.sagemaker_session.boto_region_name
+    )
 
 
 def prepare_amazon_algorithm_estimator(estimator, inputs, mini_batch_size=None):
@@ -159,8 +165,12 @@ def training_base_config(estimator, inputs=None, job_name=None, mini_batch_size=
         estimator._current_job_name = utils.name_from_base(base_name)
 
     if estimator.output_path is None:
-        default_bucket = estimator.sagemaker_session.default_bucket()
-        estimator.output_path = "s3://{}/".format(default_bucket)
+        estimator.output_path = s3.s3_path_join(
+            "s3://",
+            estimator.sagemaker_session.default_bucket(),
+            estimator.sagemaker_session.default_bucket_prefix,
+            with_end_slash=True,
+        )
 
     if isinstance(estimator, sagemaker.estimator.Framework):
         prepare_framework(estimator, s3_operations)
@@ -412,7 +422,7 @@ def _extract_training_config_list_from_estimator_dict(
     )
 
     train_config_dict = {}
-    for (estimator_name, estimator) in tuner.estimator_dict.items():
+    for estimator_name, estimator in tuner.estimator_dict.items():
         train_config_dict[estimator_name] = training_base_config(
             estimator=estimator,
             inputs=inputs.get(estimator_name) if inputs else None,
@@ -429,9 +439,9 @@ def _extract_training_config_list_from_estimator_dict(
         train_config.pop("HyperParameters", None)
         train_config["StaticHyperParameters"] = tuner.static_hyperparameters_dict[estimator_name]
 
-        train_config["AlgorithmSpecification"][
-            "MetricDefinitions"
-        ] = tuner.metric_definitions_dict.get(estimator_name)
+        train_config["AlgorithmSpecification"]["MetricDefinitions"] = (
+            tuner.metric_definitions_dict.get(estimator_name)
+        )
 
         train_config["DefinitionName"] = estimator_name
         train_config["TuningObjective"] = {
@@ -451,7 +461,7 @@ def _merge_s3_operations(s3_operations_list):
     """Merge a list of S3 operation dictionaries into one"""
     s3_operations_merged = {}
     for s3_operations in s3_operations_list:
-        for (key, operations) in s3_operations.items():
+        for key, operations in s3_operations.items():
             if key not in s3_operations_merged:
                 s3_operations_merged[key] = []
             for operation in operations:
@@ -543,7 +553,12 @@ def prepare_framework_container_def(model, instance_type, s3_operations):
     base_name = utils.base_name_from_image(deploy_image)
     model.name = model.name or utils.name_from_base(base_name)
 
-    bucket = model.bucket or model.sagemaker_session._default_bucket
+    bucket, key_prefix = s3.determine_bucket_and_prefix(
+        bucket=model.bucket,
+        key_prefix=None,
+        sagemaker_session=model.sagemaker_session,
+    )
+
     if model.entry_point is not None:
         script = os.path.basename(model.entry_point)
         key = "{}/source/sourcedir.tar.gz".format(model.name)
@@ -552,7 +567,7 @@ def prepare_framework_container_def(model, instance_type, s3_operations):
             code_dir = model.source_dir
             model.uploaded_code = fw_utils.UploadedCode(s3_prefix=code_dir, script_name=script)
         else:
-            code_dir = "s3://{}/{}".format(bucket, key)
+            code_dir = s3.s3_path_join("s3://", bucket, key_prefix, key)
             model.uploaded_code = fw_utils.UploadedCode(s3_prefix=code_dir, script_name=script)
             s3_operations["S3Upload"] = [
                 {"Path": model.source_dir or script, "Bucket": bucket, "Key": key, "Tar": True}
@@ -757,8 +772,11 @@ def transform_config(
         )
 
     if transformer.output_path is None:
-        transformer.output_path = "s3://{}/{}".format(
-            transformer.sagemaker_session.default_bucket(), transformer._current_job_name
+        transformer.output_path = s3.s3_path_join(
+            "s3://",
+            transformer.sagemaker_session.default_bucket(),
+            transformer.sagemaker_session.default_bucket_prefix,
+            transformer._current_job_name,
         )
 
     job_config = sagemaker.transformer._TransformJob._load_config(
@@ -881,7 +899,7 @@ def transform_config_from_estimator(
             be made to each individual transform container at one time.
         max_payload (int): Maximum size of the payload in a single HTTP request
             to the container in MB.
-        tags (list[dict]): List of tags for labeling a transform job. If none
+        tags (Optional[Tags]): List of tags for labeling a transform job. If none
             specified, then the tags used for the training job are used for the
             transform job.
         role (str): The ``ExecutionRoleArn`` IAM Role ARN for the ``Model``,
@@ -952,7 +970,7 @@ def transform_config_from_estimator(
             env,
             max_concurrent_transforms,
             max_payload,
-            tags,
+            format_tags(tags),
             role,
             model_server_workers,
             volume_kms_key,
@@ -969,7 +987,7 @@ def transform_config_from_estimator(
             env,
             max_concurrent_transforms,
             max_payload,
-            tags,
+            format_tags(tags),
             role,
             volume_kms_key,
         )
@@ -1048,7 +1066,7 @@ def deploy_config_from_estimator(
     model_name=None,
     endpoint_name=None,
     tags=None,
-    **kwargs
+    **kwargs,
 ):
     """Export Airflow deploy config from a SageMaker estimator
 
