@@ -29,6 +29,7 @@ from sagemaker.clarify import (
     ModelConfig,
     ModelPredictedLabelConfig,
     SHAPConfig,
+    ProcessingOutputHandler,
     _upload_analysis_config,
     SageMakerClarifyProcessor,
     _set,
@@ -43,6 +44,7 @@ from sagemaker.workflow.properties import Properties
 from sagemaker.workflow.step_collections import StepCollection
 from sagemaker.workflow.steps import Step, StepTypeEnum, CacheConfig
 from sagemaker.workflow.check_job_config import CheckJobConfig
+from sagemaker.workflow.utilities import trim_request_dict
 
 _DATA_BIAS_TYPE = "DATA_BIAS"
 _MODEL_BIAS_TYPE = "MODEL_BIAS"
@@ -130,8 +132,10 @@ class ModelExplainabilityCheckConfig(ClarifyCheckConfig):
 
     Attributes:
         model_config (ModelConfig): Config of the model and its endpoint to be created.
-        explainability_config (SHAPConfig): Config of the specific explainability method.
-            Currently, only SHAP is supported.
+        explainability_config (SHAPConfig or PDPConfig): Config of the explainability method.
+            Supports SHAP or PDP.
+            For `PDPConfig`, `features` must be specified.
+            `top_k_features` based on SHAP is currently not supported.
         model_scores (str or int or ModelPredictedLabelConfig): Index or JMESPath expression
             to locate the predicted scores in the model output (default: None).
             This is not required if the model output is a single score. Alternatively,
@@ -155,15 +159,19 @@ class ClarifyCheckStep(Step):
         skip_check: Union[bool, PipelineVariable] = False,
         fail_on_violation: Union[bool, PipelineVariable] = True,
         register_new_baseline: Union[bool, PipelineVariable] = False,
-        model_package_group_name: Union[str, PipelineVariable] = None,
-        supplied_baseline_constraints: Union[str, PipelineVariable] = None,
-        display_name: str = None,
-        description: str = None,
-        cache_config: CacheConfig = None,
+        model_package_group_name: Optional[Union[str, PipelineVariable]] = None,
+        supplied_baseline_constraints: Optional[Union[str, PipelineVariable]] = None,
+        display_name: Optional[str] = None,
+        description: Optional[str] = None,
+        cache_config: Optional[CacheConfig] = None,
         depends_on: Optional[List[Union[str, Step, StepCollection]]] = None,
     ):
         """Constructs a ClarifyCheckStep.
 
+        To understand the `skip_check`, `fail_on_violation`, `register_new_baseline`
+        and `supplied_baseline_constraints` parameters, check the following documentation:
+        https://docs.aws.amazon.com/sagemaker/latest/dg/pipelines-quality-clarify-baseline-lifecycle.html
+
         Args:
             name (str): The name of the ClarifyCheckStep step.
             clarify_check_config (ClarifyCheckConfig): A ClarifyCheckConfig instance.
@@ -240,18 +248,20 @@ class ClarifyCheckStep(Step):
             self._generate_processing_job_analysis_config(), self._baselining_processor
         )
 
-        root_prop = Properties(step_name=name)
+        root_prop = Properties(step_name=name, step=self)
         root_prop.__dict__["CalculatedBaselineConstraints"] = Properties(
-            step_name=name, path="CalculatedBaselineConstraints"
+            step_name=name, step=self, path="CalculatedBaselineConstraints"
         )
         root_prop.__dict__["BaselineUsedForDriftCheckConstraints"] = Properties(
-            step_name=name, path="BaselineUsedForDriftCheckConstraints"
+            step_name=name, step=self, path="BaselineUsedForDriftCheckConstraints"
         )
         self._properties = root_prop
 
     @property
     def arguments(self) -> RequestType:
         """The arguments dict that is used to define the ClarifyCheck step."""
+        from sagemaker.workflow.utilities import _pipeline_config
+
         normalized_inputs, normalized_outputs = self._baselining_processor._normalize_args(
             inputs=[self._processing_params["config_input"], self._processing_params["data_input"]],
             outputs=[self._processing_params["result_output"]],
@@ -265,8 +275,8 @@ class ClarifyCheckStep(Step):
         request_dict = self._baselining_processor.sagemaker_session._get_process_request(
             **process_args
         )
-        if "ProcessingJobName" in request_dict:
-            request_dict.pop("ProcessingJobName")
+        # Continue to pop job name if not explicitly opted-in via config
+        request_dict = trim_request_dict(request_dict, "ProcessingJobName", _pipeline_config)
 
         return request_dict
 
@@ -296,9 +306,9 @@ class ClarifyCheckStep(Step):
         if isinstance(
             self.clarify_check_config, (ModelBiasCheckConfig, ModelExplainabilityCheckConfig)
         ):
-            request_dict[
-                "ModelName"
-            ] = self.clarify_check_config.model_config.get_predictor_config()["model_name"]
+            request_dict["ModelName"] = (
+                self.clarify_check_config.model_config.get_predictor_config()["model_name"]
+            )
         return request_dict
 
     def _generate_processing_job_analysis_config(self) -> dict:
@@ -338,9 +348,9 @@ class ClarifyCheckStep(Step):
                 predictor_config.update(predicted_label_config)
             else:
                 _set(model_scores, "label", predictor_config)
-            analysis_config[
-                "methods"
-            ] = self.clarify_check_config.explainability_config.get_explainability_config()
+            analysis_config["methods"] = (
+                self.clarify_check_config.explainability_config.get_explainability_config()
+            )
             analysis_config["predictor"] = predictor_config
         return analysis_config
 
@@ -391,7 +401,7 @@ class ClarifyCheckStep(Step):
                 source=SageMakerClarifyProcessor._CLARIFY_OUTPUT,
                 destination=data_config.s3_output_path,
                 output_name="analysis_result",
-                s3_upload_mode="EndOfJob",
+                s3_upload_mode=ProcessingOutputHandler.get_s3_upload_mode(analysis_config),
             )
         return dict(config_input=config_input, data_input=data_input, result_output=result_output)
 
@@ -431,7 +441,7 @@ class ClarifyCheckStep(Step):
             job_definition_name = name_from_base(f"{_BIAS_MONITORING_CFG_BASE_NAME}-config")
 
         return self._model_monitor._upload_analysis_config(
-            analysis_config, output_s3_uri, job_definition_name
+            analysis_config, output_s3_uri, job_definition_name, self.clarify_check_config.kms_key
         )
 
     def _get_s3_base_uri_for_monitoring_analysis_config(self) -> str:
@@ -455,6 +465,7 @@ class ClarifyCheckStep(Step):
         return s3.s3_path_join(
             "s3://",
             self._model_monitor.sagemaker_session.default_bucket(),
+            self._model_monitor.sagemaker_session.default_bucket_prefix,
             _MODEL_MONITOR_S3_PATH,
             monitoring_cfg_base_name,
         )
