@@ -21,8 +21,9 @@ from sagemaker.workflow.entities import (
 from sagemaker.workflow.properties import (
     Properties,
 )
+from sagemaker.workflow.retry import StepRetryPolicy
 from sagemaker.workflow.step_collections import StepCollection
-from sagemaker.workflow.steps import Step, StepTypeEnum, CacheConfig
+from sagemaker.workflow.steps import ConfigurableRetryStep, Step, StepTypeEnum, CacheConfig
 
 
 class EMRStepConfig:
@@ -97,13 +98,21 @@ ERR_STR_WITH_BOTH_CLUSTER_ID_AND_CLUSTER_CFG = (
     "must be explicitly set to None."
 )
 
+ERR_STR_WITH_EXEC_ROLE_ARN_AND_WITHOUT_CLUSTER_ID = (
+    "EMRStep {step_name} cannot have execution_role_arn"
+    "without cluster_id."
+    "To use EMRStep with "
+    "execution_role_arn, cluster_id "
+    "must not be None."
+)
+
 ERR_STR_WITHOUT_CLUSTER_ID_AND_CLUSTER_CFG = (
     "EMRStep {step_name} must have either cluster_id or cluster_config"
 )
 
 
-class EMRStep(Step):
-    """EMR step for workflow."""
+class EMRStep(ConfigurableRetryStep):
+    """EMR step for workflow with configurable retry policies."""
 
     def _validate_cluster_config(self, cluster_config, step_name):
         """Validates user provided cluster_config.
@@ -153,8 +162,10 @@ class EMRStep(Step):
         cluster_id: str,
         step_config: EMRStepConfig,
         depends_on: Optional[List[Union[str, Step, StepCollection]]] = None,
-        cache_config: CacheConfig = None,
-        cluster_config: Dict[str, Any] = None,
+        cache_config: Optional[CacheConfig] = None,
+        cluster_config: Optional[Dict[str, Any]] = None,
+        execution_role_arn: Optional[str] = None,
+        retry_policies: Optional[List[StepRetryPolicy]] = None,
     ):
         """Constructs an `EMRStep`.
 
@@ -185,12 +196,23 @@ class EMRStep(Step):
                 https://docs.aws.amazon.com/emr/latest/APIReference/API_RunJobFlow.html.
                 Note that if you want to use ``cluster_config``, then you have to set
                 ``cluster_id`` as None.
-
+            execution_role_arn(str): The ARN of the runtime role assumed by this `EMRStep`. The
+                job submitted to your EMR cluster uses this role to access AWS resources. This
+                value is passed as ExecutionRoleArn to the AddJobFlowSteps request (an EMR request)
+                called on the cluster specified by ``cluster_id``, so you can only include this
+                field if ``cluster_id`` is not None.
         """
-        super(EMRStep, self).__init__(name, display_name, description, StepTypeEnum.EMR, depends_on)
+        super().__init__(
+            name=name,
+            step_type=StepTypeEnum.EMR,
+            display_name=display_name,
+            description=description,
+            depends_on=depends_on,
+            retry_policies=retry_policies,
+        )
 
         emr_step_args = {"StepConfig": step_config.to_request()}
-        root_property = Properties(step_name=name, shape_name="Step", service_name="emr")
+        root_property = Properties(step_name=name, step=self, shape_name="Step", service_name="emr")
 
         if cluster_id is None and cluster_config is None:
             raise ValueError(ERR_STR_WITHOUT_CLUSTER_ID_AND_CLUSTER_CFG.format(step_name=name))
@@ -198,9 +220,18 @@ class EMRStep(Step):
         if cluster_id is not None and cluster_config is not None:
             raise ValueError(ERR_STR_WITH_BOTH_CLUSTER_ID_AND_CLUSTER_CFG.format(step_name=name))
 
+        if execution_role_arn is not None and cluster_id is None:
+            raise ValueError(
+                ERR_STR_WITH_EXEC_ROLE_ARN_AND_WITHOUT_CLUSTER_ID.format(step_name=name)
+            )
+
         if cluster_id is not None:
             emr_step_args["ClusterId"] = cluster_id
             root_property.__dict__["ClusterId"] = cluster_id
+
+            if execution_role_arn is not None:
+                emr_step_args["ExecutionRoleArn"] = execution_role_arn
+                root_property.__dict__["ExecutionRoleArn"] = execution_role_arn
         elif cluster_config is not None:
             self._validate_cluster_config(cluster_config, name)
             emr_step_args["ClusterConfig"] = cluster_config
@@ -226,7 +257,7 @@ class EMRStep(Step):
         return self._properties
 
     def to_request(self) -> RequestType:
-        """Updates the dictionary with cache configuration."""
+        """Updates the dictionary with cache configuration and retry policies"""
         request_dict = super().to_request()
         if self.cache_config:
             request_dict.update(self.cache_config.config)
