@@ -16,7 +16,10 @@ from __future__ import absolute_import
 import abc
 
 from enum import EnumMeta
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Union, TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from sagemaker.workflow.steps import Step
 
 PrimitiveType = Union[str, int, bool, float, None]
 RequestType = Union[Dict[str, Any], List[Dict[str, Any]]]
@@ -68,6 +71,7 @@ class PipelineVariable(Expression):
     :class:`~sagemaker.workflow.functions.Join`,
     :class:`~sagemaker.workflow.functions.JsonGet`,
     :class:`~sagemaker.workflow.execution_variables.ExecutionVariable`.
+    :class:`~sagemaker.workflow.step_outputs.StepOutput`.
     """
 
     def __add__(self, other: Union[Expression, PrimitiveType]):
@@ -85,7 +89,7 @@ class PipelineVariable(Expression):
         """Override built-in String function for PipelineVariable"""
         raise TypeError(
             "Pipeline variables do not support __str__ operation. "
-            "Please use `.to_string()` to convert it to string type in execution time"
+            "Please use `.to_string()` to convert it to string type in execution time "
             "or use `.expr` to translate it to Json for display purpose in Python SDK."
         )
 
@@ -108,7 +112,12 @@ class PipelineVariable(Expression):
     def expr(self) -> RequestType:
         """Get the expression structure for workflow service calls."""
 
+    @property
+    def _pickleable(self):
+        """A pickleable object that can be used in a function step."""
+        raise NotImplementedError
+
     @property
     @abc.abstractmethod
-    def _referenced_steps(self) -> List[str]:
-        """List of step names that this function depends on."""
+    def _referenced_steps(self) -> List[Union["Step", str]]:
+        """List of steps that this variable is generated from."""
