@@ -20,6 +20,7 @@ from typing import Dict, Optional, Callable
 
 from sagemaker.session import Session, SessionSettings
 from sagemaker.local import LocalSession
+from sagemaker.workflow.pipeline_definition_config import PipelineDefinitionConfig
 
 
 class _StepArguments:
@@ -80,20 +81,65 @@ class _ModelStepArguments(_StepArguments):
 
 
 class _PipelineConfig:
-    """Config object that associates a step with its containing pipeline
+    """Context for building a step.
 
     Args:
         pipeline_name (str): pipeline name
         step_name (str): step name
+        sagemaker_session (Session): a SageMaker Session
         code_hash (str): a hash of the code artifact for the particular step
         config_hash (str): a hash of the config artifact for the particular step (Processing)
+        pipeline_definition_config (PipelineDefinitionConfig): a configuration used to toggle
+            feature flags persistent in a pipeline definition
+        upload_runtime_scripts (bool): flag used to manage upload of runtime scripts to s3 for
+          a _FunctionStep in pipeline
+        upload_workspace (bool): flag used to manage the upload of workspace to s3 for a
+          _FunctionStep in pipeline
     """
 
-    def __init__(self, pipeline_name, step_name, code_hash, config_hash):
-        self.pipeline_name = pipeline_name
-        self.step_name = step_name
+    def __init__(
+        self,
+        pipeline_name: str,
+        step_name: str,
+        sagemaker_session: Session,
+        code_hash: str,
+        config_hash: str,
+        pipeline_definition_config: PipelineDefinitionConfig,
+        pipeline_build_time: str = None,
+        upload_runtime_scripts: bool = True,
+        upload_workspace: bool = True,
+        function_step_secret_token: Optional[str] = None,
+    ):
+        self._pipeline_name = pipeline_name
+        self._step_name = step_name
+        self._sagemaker_session = sagemaker_session
         self.code_hash = code_hash
         self.config_hash = config_hash
+        self.pipeline_definition_config = pipeline_definition_config
+        self.upload_runtime_scripts = upload_runtime_scripts
+        self.upload_workspace = upload_workspace
+        self._function_step_secret_token = function_step_secret_token
+        self.pipeline_build_time = pipeline_build_time
+
+    @property
+    def pipeline_name(self):
+        """str: pipeline name"""
+        return self._pipeline_name
+
+    @property
+    def step_name(self):
+        """str: step name"""
+        return self._step_name
+
+    @property
+    def sagemaker_session(self):
+        """Session: a SageMaker Session"""
+        return self._sagemaker_session
+
+    @property
+    def function_step_secret_token(self):
+        """str: a secret token for a function step"""
+        return self._function_step_secret_token
 
 
 class PipelineSession(Session):
@@ -112,6 +158,8 @@ class PipelineSession(Session):
         sagemaker_client=None,
         default_bucket=None,
         settings=SessionSettings(),
+        sagemaker_config: dict = None,
+        default_bucket_prefix: str = None,
     ):
         """Initialize a ``PipelineSession``.
 
@@ -131,12 +179,28 @@ class PipelineSession(Session):
                 Example: "sagemaker-my-custom-bucket".
             settings (sagemaker.session_settings.SessionSettings): Optional. Set of optional
                 parameters to apply to the session.
+            sagemaker_config: A dictionary containing default values for the
+                SageMaker Python SDK. (default: None). The dictionary must adhere to the schema
+                defined at `~sagemaker.config.config_schema.SAGEMAKER_PYTHON_SDK_CONFIG_SCHEMA`.
+                If sagemaker_config is not provided and configuration files exist (at the default
+                paths for admins and users, or paths set through the environment variables
+                SAGEMAKER_ADMIN_CONFIG_OVERRIDE and SAGEMAKER_USER_CONFIG_OVERRIDE),
+                a new dictionary will be generated from those configuration files. Alternatively,
+                this dictionary can be generated by calling
+                :func:`~sagemaker.config.load_sagemaker_config` and then be provided to the
+                Session.
+            default_bucket_prefix (str): The default prefix to use for S3 Object Keys. When
+                objects are saved to the Session's default_bucket, the Object Key used will
+                start with the default_bucket_prefix. If not provided here or within
+                sagemaker_config, no additional prefix will be added.
         """
         super().__init__(
             boto_session=boto_session,
             sagemaker_client=sagemaker_client,
             default_bucket=default_bucket,
             settings=settings,
+            sagemaker_config=sagemaker_config,
+            default_bucket_prefix=default_bucket_prefix,
         )
         self._context = None
 
@@ -185,7 +249,12 @@ class LocalPipelineSession(LocalSession, PipelineSession):
     """
 
     def __init__(
-        self, boto_session=None, default_bucket=None, s3_endpoint_url=None, disable_local_code=False
+        self,
+        boto_session=None,
+        default_bucket=None,
+        s3_endpoint_url=None,
+        disable_local_code=False,
+        default_bucket_prefix=None,
     ):
         """Initialize a ``LocalPipelineSession``.
 
@@ -204,6 +273,10 @@ class LocalPipelineSession(LocalSession, PipelineSession):
             disable_local_code (bool): Set to True to override the default AWS configuration chain
                 to disable the `local.local_code` setting, which may not be supported for some SDK
                 features (default: False).
+            default_bucket_prefix (str): The default prefix to use for S3 Object Keys. When
+                objects are saved to the Session's default_bucket, the Object Key used will
+                start with the default_bucket_prefix. If not provided here or within
+                sagemaker_config, no additional prefix will be added.
         """
 
         super().__init__(
@@ -211,6 +284,7 @@ class LocalPipelineSession(LocalSession, PipelineSession):
             default_bucket=default_bucket,
             s3_endpoint_url=s3_endpoint_url,
             disable_local_code=disable_local_code,
+            default_bucket_prefix=default_bucket_prefix,
         )
 
 
