@@ -18,7 +18,6 @@ import warnings
 
 from enum import Enum
 from typing import Dict, List, Set, Union, Optional, Any, TYPE_CHECKING
-from urllib.parse import urlparse
 
 import attr
 
@@ -35,10 +34,8 @@ from sagemaker.processing import (
 )
 from sagemaker.transformer import Transformer, _TransformJob
 from sagemaker.tuner import HyperparameterTuner, _TuningJob
-from sagemaker.workflow.conditions import Condition
 from sagemaker.workflow import is_pipeline_variable
 from sagemaker.workflow.entities import (
-    DefaultEnumMeta,
     Entity,
     RequestType,
 )
@@ -50,12 +47,14 @@ from sagemaker.workflow.properties import (
 from sagemaker.workflow.entities import PipelineVariable
 from sagemaker.workflow.functions import Join, JsonGet
 from sagemaker.workflow.retry import RetryPolicy
+from sagemaker.workflow.step_outputs import StepOutput
+from sagemaker.workflow.utilities import trim_request_dict
 
 if TYPE_CHECKING:
     from sagemaker.workflow.step_collections import StepCollection
 
 
-class StepTypeEnum(Enum, metaclass=DefaultEnumMeta):
+class StepTypeEnum(Enum):
     """Enum of `Step` types."""
 
     CONDITION = "Condition"
@@ -74,25 +73,51 @@ class StepTypeEnum(Enum, metaclass=DefaultEnumMeta):
     AUTOML = "AutoML"
 
 
-@attr.s
 class Step(Entity):
-    """Pipeline `Step` for SageMaker Pipelines Workflows.
+    """Pipeline `Step` for SageMaker Pipelines Workflows."""
 
-    Attributes:
-        name (str): The name of the `Step`.
-        display_name (str): The display name of the `Step`.
-        description (str): The description of the `Step`.
-        step_type (StepTypeEnum): The type of the `Step`.
-        depends_on (List[Union[str, Step, StepCollection]]): The list of `Step`/`StepCollection`
-            names or `Step` instances or `StepCollection` instances that the current `Step`
-            depends on.
-    """
+    def __init__(
+        self,
+        name: str,
+        display_name: Optional[str] = None,
+        description: Optional[str] = None,
+        step_type: StepTypeEnum = None,
+        depends_on: Optional[List[Union[str, "Step", "StepCollection", StepOutput]]] = None,
+    ):
+        """Initialize a Step
 
-    name: str = attr.ib(factory=str)
-    display_name: Optional[str] = attr.ib(default=None)
-    description: Optional[str] = attr.ib(default=None)
-    step_type: StepTypeEnum = attr.ib(factory=StepTypeEnum.factory)
-    depends_on: Optional[List[Union[str, "Step", "StepCollection"]]] = attr.ib(default=None)
+        Args:
+            name (str): The name of the `Step`.
+            display_name (str): The display name of the `Step`.
+            description (str): The description of the `Step`.
+            step_type (StepTypeEnum): The type of the `Step`.
+            depends_on (List[Union[str, Step, StepCollection]]): The list of `Step`/`StepCollection`
+                names or `Step` or `StepCollection`, `StepOutput` instances that the current `Step`
+                depends on.
+        """
+        self.name = name
+        self.display_name = display_name
+        self.description = description
+        self.step_type = step_type
+        if depends_on is not None:
+            self._depends_on = depends_on
+        else:
+            self._depends_on = None
+
+    @property
+    def depends_on(self) -> Optional[List[Union[str, "Step", "StepCollection", StepOutput]]]:
+        """The list of steps the current `Step` depends on."""
+
+        return self._depends_on
+
+    @depends_on.setter
+    def depends_on(self, depends_on: List[Union[str, "Step", "StepCollection", StepOutput]]):
+        """Set the list of  steps the current step explicitly depends on."""
+
+        if depends_on is not None:
+            self._depends_on = depends_on
+        else:
+            self._depends_on = None
 
     @property
     @abc.abstractmethod
@@ -121,7 +146,7 @@ class Step(Entity):
             "Arguments": self.arguments,
         }
         if self.depends_on:
-            request_dict["DependsOn"] = self._resolve_depends_on(self.depends_on)
+            request_dict["DependsOn"] = list(self.depends_on)
         if self.display_name:
             request_dict["DisplayName"] = self.display_name
         if self.description:
@@ -129,44 +154,27 @@ class Step(Entity):
 
         return request_dict
 
-    def add_depends_on(self, step_names: List[Union[str, "Step", "StepCollection"]]):
+    def add_depends_on(self, step_names: List[Union[str, "Step", "StepCollection", StepOutput]]):
         """Add `Step` names or `Step` instances to the current `Step` depends on list."""
 
         if not step_names:
             return
 
-        if not self.depends_on:
-            self.depends_on = []
-        self.depends_on.extend(step_names)
+        if not self._depends_on:
+            self._depends_on = []
+
+        self._depends_on.extend(step_names)
 
     @property
     def ref(self) -> Dict[str, str]:
         """Gets a reference dictionary for `Step` instances."""
         return {"Name": self.name}
 
-    @staticmethod
-    def _resolve_depends_on(
-        depends_on_list: List[Union[str, "Step", "StepCollection"]]
-    ) -> List[str]:
-        """Resolve the `Step` depends on list."""
-        from sagemaker.workflow.step_collections import StepCollection
-
-        depends_on = []
-        for step in depends_on_list:
-            # As for StepCollection, the names of its sub steps will be interpolated
-            # when generating the pipeline definition
-            if isinstance(step, (Step, StepCollection)):
-                depends_on.append(step.name)
-            elif isinstance(step, str):
-                depends_on.append(step)
-            else:
-                raise ValueError(f"Invalid input step type: {type(step)}")
-        return depends_on
-
+    # TODO: move this method to CompiledStep
     def _find_step_dependencies(
         self, step_map: Dict[str, Union["Step", "StepCollection"]]
     ) -> List[str]:
-        """Find the all step names this step is dependent on."""
+        """Find all step names this step is dependent on."""
         step_dependencies = set()
         if self.depends_on:
             step_dependencies.update(self._find_dependencies_in_depends_on_list(step_map))
@@ -198,36 +206,45 @@ class Step(Entity):
     ):
         """Find the step dependencies referenced in the arguments of this step."""
         dependencies = set()
-        if isinstance(obj, dict):
-            for value in obj.values():
-                if isinstance(value, (PipelineVariable, Condition)):
-                    for referenced_step in value._referenced_steps:
-                        dependencies.add(self._get_step_name_from_str(referenced_step, step_map))
-                    if isinstance(value, JsonGet):
-                        self._validate_json_get_function(value, step_map)
-                dependencies.update(self._find_dependencies_in_step_arguments(value, step_map))
-        elif isinstance(obj, list):
-            for item in obj:
-                if isinstance(item, (PipelineVariable, Condition)):
-                    for referenced_step in item._referenced_steps:
-                        dependencies.add(self._get_step_name_from_str(referenced_step, step_map))
-                    if isinstance(item, JsonGet):
-                        self._validate_json_get_function(item, step_map)
-                dependencies.update(self._find_dependencies_in_step_arguments(item, step_map))
+        pipeline_variables = Step._find_pipeline_variables_in_step_arguments(obj)
+        for pipeline_variable in pipeline_variables:
+            for referenced_step in pipeline_variable._referenced_steps:
+                if isinstance(referenced_step, Step):
+                    dependencies.add(referenced_step.name)
+                else:
+                    dependencies.add(self._get_step_name_from_str(referenced_step, step_map))
+
+            from sagemaker.workflow.function_step import DelayedReturn
+
+            # TODO: we can remove the if-elif once move the validators to JsonGet constructor
+            if isinstance(pipeline_variable, JsonGet):
+                self._validate_json_get_function(pipeline_variable, step_map)
+            elif isinstance(pipeline_variable, DelayedReturn):
+                # DelayedReturn showing up in arguments, meaning that it's data referenced
+                # We should convert it to JsonGet and validate the JsonGet object
+                self._validate_json_get_function(pipeline_variable._to_json_get(), step_map)
+
         return dependencies
 
     def _validate_json_get_function(
         self, json_get: JsonGet, step_map: Dict[str, Union["Step", "StepCollection"]]
     ):
         """Validate the JsonGet function inputs."""
+        if json_get.property_file:
+            self._validate_json_get_property_file_reference(json_get=json_get, step_map=step_map)
+
+    # TODO: move it to JsonGet constructor
+    def _validate_json_get_property_file_reference(self, json_get: JsonGet, step_map: dict):
+        """Validate the property file reference in JsonGet"""
         property_file_reference = json_get.property_file
         processing_step = step_map[json_get.step_name]
         property_file = None
         if isinstance(property_file_reference, str):
-            if not isinstance(processing_step, ProcessingStep):
+            if not processing_step.step_type == StepTypeEnum.PROCESSING:
                 raise ValueError(
-                    f"Invalid JsonGet function {json_get.expr} in step '{self.name}'. JsonGet "
-                    f"function can only be evaluated on processing step outputs."
+                    f"Invalid JsonGet function {json_get.expr} in step '{self.name}'. "
+                    f"JsonGet function (with property_file) can only be evaluated "
+                    f"on processing step outputs."
                 )
             for file in processing_step.property_files:
                 if file.name == property_file_reference:
@@ -252,6 +269,26 @@ class Step(Entity):
                 f"'{property_file.name}' not found in processing step '{processing_step.name}'."
             )
 
+    @staticmethod
+    def _find_pipeline_variables_in_step_arguments(obj: RequestType) -> List[PipelineVariable]:
+        """Recursively find all the pipeline variables in the step arguments."""
+        pipeline_variables = list()
+        if isinstance(obj, dict):
+            for value in obj.values():
+                if isinstance(value, PipelineVariable):
+                    pipeline_variables.append(value)
+                else:
+                    pipeline_variables.extend(
+                        Step._find_pipeline_variables_in_step_arguments(value)
+                    )
+        elif isinstance(obj, list):
+            for item in obj:
+                if isinstance(item, PipelineVariable):
+                    pipeline_variables.append(item)
+                else:
+                    pipeline_variables.extend(Step._find_pipeline_variables_in_step_arguments(item))
+        return pipeline_variables
+
     @staticmethod
     def _get_step_name_from_str(
         str_input: str, step_map: Dict[str, Union["Step", "StepCollection"]]
@@ -324,10 +361,10 @@ class ConfigurableRetryStep(Step):
         self,
         name: str,
         step_type: StepTypeEnum,
-        display_name: str = None,
-        description: str = None,
+        display_name: Optional[str] = None,
+        description: Optional[str] = None,
         depends_on: Optional[List[Union[str, Step, "StepCollection"]]] = None,
-        retry_policies: List[RetryPolicy] = None,
+        retry_policies: Optional[List[RetryPolicy]] = None,
     ):
         super().__init__(
             name=name,
@@ -366,14 +403,14 @@ class TrainingStep(ConfigurableRetryStep):
     def __init__(
         self,
         name: str,
-        step_args: _JobStepArguments = None,
-        estimator: EstimatorBase = None,
-        display_name: str = None,
-        description: str = None,
-        inputs: Union[TrainingInput, dict, str, FileSystemInput] = None,
-        cache_config: CacheConfig = None,
+        step_args: Optional[_JobStepArguments] = None,
+        estimator: Optional[EstimatorBase] = None,
+        display_name: Optional[str] = None,
+        description: Optional[str] = None,
+        inputs: Optional[Union[TrainingInput, dict, str, FileSystemInput]] = None,
+        cache_config: Optional[CacheConfig] = None,
         depends_on: Optional[List[Union[str, Step, "StepCollection"]]] = None,
-        retry_policies: List[RetryPolicy] = None,
+        retry_policies: Optional[List[RetryPolicy]] = None,
     ):
         """Construct a `TrainingStep`, given an `EstimatorBase` instance.
 
@@ -427,8 +464,11 @@ class TrainingStep(ConfigurableRetryStep):
         self.step_args = step_args
         self.estimator = estimator
         self.inputs = inputs
+        self.job_name = None
 
-        self._properties = Properties(step_name=name, shape_name="DescribeTrainingJobResponse")
+        self._properties = Properties(
+            step_name=name, step=self, shape_name="DescribeTrainingJobResponse"
+        )
         self.cache_config = cache_config
 
         if self.cache_config:
@@ -453,27 +493,15 @@ class TrainingStep(ConfigurableRetryStep):
                 DeprecationWarning,
             )
 
-        self.job_name = None
-        if estimator and (estimator.source_dir or estimator.entry_point):
-            # By default, `Estimator` will upload the local code to an S3 path
-            # containing a timestamp. This causes cache misses whenever a
-            # pipeline is updated, even if the underlying script hasn't changed.
-            # To avoid this, hash the contents of the training script and include it
-            # in the `job_name` passed to the `Estimator`, which will be used
-            # instead of the timestamped path.
-            if not is_pipeline_variable(estimator.source_dir) and not is_pipeline_variable(
-                estimator.entry_point
-            ):
-                self.job_name = self._generate_code_upload_path()
-
     @property
     def arguments(self) -> RequestType:
         """The arguments dictionary that is used to call `create_training_job`.
 
         NOTE: The `CreateTrainingJob` request is not quite the args list that workflow needs.
-        The `TrainingJobName` and `ExperimentConfig` attributes cannot be included.
+        `ExperimentConfig` attribute cannot be included.
         """
         from sagemaker.workflow.utilities import execute_job_functions
+        from sagemaker.workflow.utilities import _pipeline_config
 
         if self.step_args:
             # execute fit function with saved parameters,
@@ -493,7 +521,9 @@ class TrainingStep(ConfigurableRetryStep):
         if "HyperParameters" in request_dict:
             request_dict["HyperParameters"].pop("sagemaker_job_name", None)
 
-        request_dict.pop("TrainingJobName", None)
+        # Continue to pop job name if not explicitly opted-in via config
+        request_dict = trim_request_dict(request_dict, "TrainingJobName", _pipeline_config)
+
         Step._trim_experiment_config(request_dict)
 
         return request_dict
@@ -511,26 +541,6 @@ class TrainingStep(ConfigurableRetryStep):
 
         return request_dict
 
-    def _generate_code_upload_path(self) -> str or None:
-        """Generate an upload path for local training scripts based on their content."""
-        from sagemaker.workflow.utilities import hash_files_or_dirs
-
-        if self.estimator.source_dir:
-            source_dir_url = urlparse(self.estimator.source_dir)
-            if source_dir_url.scheme == "" or source_dir_url.scheme == "file":
-                code_hash = hash_files_or_dirs(
-                    [self.estimator.source_dir] + self.estimator.dependencies
-                )
-                return f"{self.name}-{code_hash}"[:1024]
-        elif self.estimator.entry_point:
-            entry_point_url = urlparse(self.estimator.entry_point)
-            if entry_point_url.scheme == "" or entry_point_url.scheme == "file":
-                code_hash = hash_files_or_dirs(
-                    [self.estimator.entry_point] + self.estimator.dependencies
-                )
-                return f"{self.name}-{code_hash}"[:1024]
-        return None
-
 
 class CreateModelStep(ConfigurableRetryStep):
     """`CreateModelStep` for SageMaker Pipelines Workflows."""
@@ -577,7 +587,7 @@ class CreateModelStep(ConfigurableRetryStep):
         self.model = model
         self.inputs = inputs or CreateModelInput()
 
-        self._properties = Properties(step_name=name, shape_name="DescribeModelOutput")
+        self._properties = Properties(step_name=name, step=self, shape_name="DescribeModelOutput")
 
         warnings.warn(
             (
@@ -595,13 +605,14 @@ class CreateModelStep(ConfigurableRetryStep):
         """The arguments dictionary that is used to call `create_model`.
 
         NOTE: The `CreateModelRequest` is not quite the args list that workflow needs.
-        `ModelName` cannot be included in the arguments.
         """
+        from sagemaker.workflow.utilities import _pipeline_config
 
         if self.step_args:
             request_dict = self.step_args
         else:
             if isinstance(self.model, PipelineModel):
+                self.model._init_sagemaker_session_if_does_not_exist()
                 request_dict = self.model.sagemaker_session._create_model_request(
                     name="",
                     role=self.model.role,
@@ -610,6 +621,7 @@ class CreateModelStep(ConfigurableRetryStep):
                     enable_network_isolation=self.model.enable_network_isolation,
                 )
             else:
+                self.model._init_sagemaker_session_if_does_not_exist()
                 request_dict = self.model.sagemaker_session._create_model_request(
                     name="",
                     role=self.model.role,
@@ -620,7 +632,9 @@ class CreateModelStep(ConfigurableRetryStep):
                     vpc_config=self.model.vpc_config,
                     enable_network_isolation=self.model.enable_network_isolation(),
                 )
-        request_dict.pop("ModelName", None)
+
+        # Continue to pop job name if not explicitly opted-in via config
+        request_dict = trim_request_dict(request_dict, "ModelName", _pipeline_config)
 
         return request_dict
 
@@ -636,14 +650,14 @@ class TransformStep(ConfigurableRetryStep):
     def __init__(
         self,
         name: str,
-        step_args: _JobStepArguments = None,
-        transformer: Transformer = None,
-        inputs: TransformInput = None,
-        display_name: str = None,
-        description: str = None,
-        cache_config: CacheConfig = None,
+        step_args: Optional[_JobStepArguments] = None,
+        transformer: Optional[Transformer] = None,
+        inputs: Optional[TransformInput] = None,
+        display_name: Optional[str] = None,
+        description: Optional[str] = None,
+        cache_config: Optional[CacheConfig] = None,
         depends_on: Optional[List[Union[str, Step, "StepCollection"]]] = None,
-        retry_policies: List[RetryPolicy] = None,
+        retry_policies: Optional[List[RetryPolicy]] = None,
     ):
         """Constructs a `TransformStep`, given a `Transformer` instance.
 
@@ -684,7 +698,9 @@ class TransformStep(ConfigurableRetryStep):
         self.transformer = transformer
         self.inputs = inputs
         self.cache_config = cache_config
-        self._properties = Properties(step_name=name, shape_name="DescribeTransformJobResponse")
+        self._properties = Properties(
+            step_name=name, step=self, shape_name="DescribeTransformJobResponse"
+        )
 
         if not self.step_args:
             if inputs is None:
@@ -702,9 +718,10 @@ class TransformStep(ConfigurableRetryStep):
         """The arguments dictionary that is used to call `create_transform_job`.
 
         NOTE: The `CreateTransformJob` request is not quite the args list that workflow needs.
-        `TransformJobName` and `ExperimentConfig` cannot be included in the arguments.
+        `ExperimentConfig` cannot be included in the arguments.
         """
         from sagemaker.workflow.utilities import execute_job_functions
+        from sagemaker.workflow.utilities import _pipeline_config
 
         if self.step_args:
             # execute transform function with saved parameters,
@@ -733,7 +750,9 @@ class TransformStep(ConfigurableRetryStep):
                 **transform_args
             )
 
-        request_dict.pop("TransformJobName", None)
+        # Continue to pop job name if not explicitly opted-in via config
+        request_dict = trim_request_dict(request_dict, "TransformJobName", _pipeline_config)
+
         Step._trim_experiment_config(request_dict)
 
         return request_dict
@@ -758,19 +777,19 @@ class ProcessingStep(ConfigurableRetryStep):
     def __init__(
         self,
         name: str,
-        step_args: _JobStepArguments = None,
-        processor: Processor = None,
-        display_name: str = None,
-        description: str = None,
-        inputs: List[ProcessingInput] = None,
-        outputs: List[ProcessingOutput] = None,
-        job_arguments: List[str] = None,
-        code: str = None,
-        property_files: List[PropertyFile] = None,
-        cache_config: CacheConfig = None,
+        step_args: Optional[_JobStepArguments] = None,
+        processor: Optional[Processor] = None,
+        display_name: Optional[str] = None,
+        description: Optional[str] = None,
+        inputs: Optional[List[ProcessingInput]] = None,
+        outputs: Optional[List[ProcessingOutput]] = None,
+        job_arguments: Optional[List[str]] = None,
+        code: Optional[str] = None,
+        property_files: Optional[List[PropertyFile]] = None,
+        cache_config: Optional[CacheConfig] = None,
         depends_on: Optional[List[Union[str, Step, "StepCollection"]]] = None,
-        retry_policies: List[RetryPolicy] = None,
-        kms_key=None,
+        retry_policies: Optional[List[RetryPolicy]] = None,
+        kms_key: Optional[str] = None,
     ):
         """Construct a `ProcessingStep`, given a `Processor` instance.
 
@@ -827,7 +846,9 @@ class ProcessingStep(ConfigurableRetryStep):
         self.job_name = None
         self.kms_key = kms_key
         self.cache_config = cache_config
-        self._properties = Properties(step_name=name, shape_name="DescribeProcessingJobResponse")
+        self._properties = Properties(
+            step_name=name, step=self, shape_name="DescribeProcessingJobResponse"
+        )
 
         if not self.step_args:
             # Examine why run method in `sagemaker.processing.Processor`
@@ -841,16 +862,6 @@ class ProcessingStep(ConfigurableRetryStep):
                         "code argument has to be a valid S3 URI or local file path "
                         + "rather than a pipeline variable"
                     )
-                code_url = urlparse(code)
-                if code_url.scheme == "" or code_url.scheme == "file":
-                    # By default, `Processor` will upload the local code to an S3 path
-                    # containing a timestamp. This causes cache misses whenever a
-                    # pipeline is updated, even if the underlying script hasn't changed.
-                    # To avoid this, hash the contents of the script and include it
-                    # in the `job_name` passed to the `Processor`, which will be used
-                    # instead of the timestamped path.
-                    self.job_name = self._generate_code_upload_path()
-
             warnings.warn(
                 (
                     'We are deprecating the instantiation of ProcessingStep using "processor".'
@@ -864,9 +875,10 @@ class ProcessingStep(ConfigurableRetryStep):
         """The arguments dictionary that is used to call `create_processing_job`.
 
         NOTE: The `CreateProcessingJob` request is not quite the args list that workflow needs.
-        `ProcessingJobName` and `ExperimentConfig` cannot be included in the arguments.
+        `ExperimentConfig` cannot be included in the arguments.
         """
         from sagemaker.workflow.utilities import execute_job_functions
+        from sagemaker.workflow.utilities import _pipeline_config
 
         if self.step_args:
             # execute run function with saved parameters,
@@ -890,7 +902,9 @@ class ProcessingStep(ConfigurableRetryStep):
             )
             request_dict = self.processor.sagemaker_session._get_process_request(**process_args)
 
-        request_dict.pop("ProcessingJobName", None)
+        # Continue to pop job name if not explicitly opted-in via config
+        request_dict = trim_request_dict(request_dict, "ProcessingJobName", _pipeline_config)
+
         Step._trim_experiment_config(request_dict)
 
         return request_dict
@@ -925,15 +939,15 @@ class TuningStep(ConfigurableRetryStep):
     def __init__(
         self,
         name: str,
-        step_args: _JobStepArguments = None,
-        tuner: HyperparameterTuner = None,
-        display_name: str = None,
-        description: str = None,
+        step_args: Optional[_JobStepArguments] = None,
+        tuner: Optional[HyperparameterTuner] = None,
+        display_name: Optional[str] = None,
+        description: Optional[str] = None,
         inputs=None,
-        job_arguments: List[str] = None,
-        cache_config: CacheConfig = None,
+        job_arguments: Optional[List[str]] = None,
+        cache_config: Optional[CacheConfig] = None,
         depends_on: Optional[List[Union[str, Step, "StepCollection"]]] = None,
-        retry_policies: List[RetryPolicy] = None,
+        retry_policies: Optional[List[RetryPolicy]] = None,
     ):
         """Construct a `TuningStep`, given a `HyperparameterTuner` instance.
 
@@ -1003,6 +1017,7 @@ class TuningStep(ConfigurableRetryStep):
         self.job_arguments = job_arguments
         self._properties = Properties(
             step_name=name,
+            step=self,
             shape_names=[
                 "DescribeHyperParameterTuningJobResponse",
                 "ListTrainingJobsForHyperParameterTuningJobResponse",
@@ -1025,9 +1040,9 @@ class TuningStep(ConfigurableRetryStep):
 
         NOTE: The `CreateHyperParameterTuningJob` request is not quite the
             args list that workflow needs.
-        The `HyperParameterTuningJobName` attribute cannot be included.
         """
         from sagemaker.workflow.utilities import execute_job_functions
+        from sagemaker.workflow.utilities import _pipeline_config
 
         if self.step_args:
             # execute fit function with saved parameters,
@@ -1048,7 +1063,11 @@ class TuningStep(ConfigurableRetryStep):
             tuner_args = _TuningJob._get_tuner_args(self.tuner, self.inputs)
             request_dict = self.tuner.sagemaker_session._get_tuning_request(**tuner_args)
 
-        request_dict.pop("HyperParameterTuningJobName", None)
+        # Continue to pop job name if not explicitly opted-in via config
+        request_dict = trim_request_dict(
+            request_dict, "HyperParameterTuningJobName", _pipeline_config
+        )
+
         return request_dict
 
     @property
