@@ -24,6 +24,7 @@ from sagemaker.network import NetworkConfig
 from sagemaker.processing import FrameworkProcessor
 from sagemaker.xgboost.estimator import XGBoost
 from sagemaker.workflow.entities import PipelineVariable
+from sagemaker.utils import format_tags, Tags
 
 
 class XGBoostProcessor(FrameworkProcessor):
@@ -34,9 +35,9 @@ class XGBoostProcessor(FrameworkProcessor):
     def __init__(
         self,
         framework_version: str,  # New arg
-        role: str,
-        instance_count: Union[int, PipelineVariable],
-        instance_type: Union[str, PipelineVariable],
+        role: str = None,
+        instance_count: Union[int, PipelineVariable] = None,
+        instance_type: Union[str, PipelineVariable] = None,
         py_version: str = "py3",  # New kwarg
         image_uri: Optional[Union[str, PipelineVariable]] = None,
         command: Optional[List[str]] = None,
@@ -48,7 +49,7 @@ class XGBoostProcessor(FrameworkProcessor):
         base_job_name: Optional[str] = None,
         sagemaker_session: Optional[Session] = None,
         env: Optional[Dict[str, Union[str, PipelineVariable]]] = None,
-        tags: Optional[List[Dict[str, Union[str, PipelineVariable]]]] = None,
+        tags: Optional[Tags] = None,
         network_config: Optional[NetworkConfig] = None,
     ):
         """This processor executes a Python script in an XGBoost execution environment.
@@ -81,6 +82,6 @@ class XGBoostProcessor(FrameworkProcessor):
             base_job_name,
             sagemaker_session,
             env,
-            tags,
+            format_tags(tags),
             network_config,
         )
